Class: Google::Apis::ContaineranalysisV1beta1::Artifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Artifact describes a build product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Artifact

Returns a new instance of Artifact.



133
134
135
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checksumString

Hash or checksum value of a binary, or Docker Registry 2.0 digest of a container. Corresponds to the JSON property checksum

Returns:

  • (String)


116
117
118
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 116

def checksum
  @checksum
end

#idString

Artifact ID, if any; for container images, this will be a URL by digest like gcr.io/projectID/imagename@sha256:123456. Corresponds to the JSON property id

Returns:

  • (String)


122
123
124
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 122

def id
  @id
end

#namesArray<String>

Related artifact names. This may be the path to a binary or jar file, or in the case of a container build, the name used to push the container image to Google Container Registry, as presented to docker push. Note that a single Artifact ID can have multiple names, for example if two tags are applied to one image. Corresponds to the JSON property names

Returns:

  • (Array<String>)


131
132
133
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 131

def names
  @names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



138
139
140
141
142
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 138

def update!(**args)
  @checksum = args[:checksum] if args.key?(:checksum)
  @id = args[:id] if args.key?(:id)
  @names = args[:names] if args.key?(:names)
end