Class: Google::Apis::ContaineranalysisV1beta1::Attestation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Attestation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for look-up (how to find this attestation if you already know the authority and artifact to be verified) and intent (which authority was this attestation intended to sign for).
Instance Attribute Summary collapse
-
#generic_signed_attestation ⇒ Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
An attestation wrapper that uses the Grafeas
Signaturemessage. -
#pgp_signed_attestation ⇒ Google::Apis::ContaineranalysisV1beta1::PgpSignedAttestation
An attestation wrapper with a PGP-compatible signature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Attestation
constructor
A new instance of Attestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Attestation
Returns a new instance of Attestation.
296 297 298 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_signed_attestation ⇒ Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
An attestation wrapper that uses the Grafeas Signature message. This
attestation must define the serialized_payload that the signatures verify
and any metadata necessary to interpret that plaintext. The signatures should
always be over the serialized_payload bytestring.
Corresponds to the JSON property genericSignedAttestation
287 288 289 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 287 def generic_signed_attestation @generic_signed_attestation end |
#pgp_signed_attestation ⇒ Google::Apis::ContaineranalysisV1beta1::PgpSignedAttestation
An attestation wrapper with a PGP-compatible signature. This message only
supports ATTACHED signatures, where the payload that is signed is included
alongside the signature itself in the same file.
Corresponds to the JSON property pgpSignedAttestation
294 295 296 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 294 def pgp_signed_attestation @pgp_signed_attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
301 302 303 304 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 301 def update!(**args) @generic_signed_attestation = args[:generic_signed_attestation] if args.key?(:generic_signed_attestation) @pgp_signed_attestation = args[:pgp_signed_attestation] if args.key?(:pgp_signed_attestation) end |