Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Generic artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact.



1483
1484
1485
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderString

Required. Path to the generic artifact in the build's workspace to be uploaded to Artifact Registry. Corresponds to the JSON property folder

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1474

def folder
  @folder
end

#registry_pathString

Required. Registry path to upload the generic artifact to, in the form projects/$PROJECT/locations/$LOCATION/repositories/$REPO/packages/$PACKAGE/ versions/$VERSION Corresponds to the JSON property registryPath

Returns:

  • (String)


1481
1482
1483
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1481

def registry_path
  @registry_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1488
1489
1490
1491
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1488

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @registry_path = args[:registry_path] if args.key?(:registry_path)
end