Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.



1595
1596
1597
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Maven artifactId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property artifactId

Returns:

  • (String)


1560
1561
1562
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1560

def artifact_id
  @artifact_id
end

#deploy_folderString

Optional. Path to a folder containing the files to upload to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/target/, or a relative path from /workspace, e.g. my-app/target/. This field is mutually exclusive with the path field. Corresponds to the JSON property deployFolder

Returns:

  • (String)


1568
1569
1570
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1568

def deploy_folder
  @deploy_folder
end

#group_idString

Maven groupId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property groupId

Returns:

  • (String)


1573
1574
1575
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1573

def group_id
  @group_id
end

#pathString

Optional. Path to an artifact in the build's workspace to be uploaded to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/ target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/ target/my-app-1.0.SNAPSHOT.jar. Corresponds to the JSON property path

Returns:

  • (String)


1581
1582
1583
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1581

def path
  @path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1588

def repository
  @repository
end

#versionString

Maven version value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property version

Returns:

  • (String)


1593
1594
1595
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1593

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1600
1601
1602
1603
1604
1605
1606
1607
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1600

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder)
  @group_id = args[:group_id] if args.key?(:group_id)
  @path = args[:path] if args.key?(:path)
  @repository = args[:repository] if args.key?(:repository)
  @version = args[:version] if args.key?(:version)
end