Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Npm package to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage.



1495
1496
1497
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#package_pathString

Optional. Path to the package.json. e.g. workspace/path/to/package Only one of archive or package_path can be specified. Corresponds to the JSON property packagePath

Returns:

  • (String)


1486
1487
1488
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1486

def package_path
  @package_path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-npm.pkg.dev/$ PROJECT/$REPOSITORY" Npm package in the workspace specified by path will be zipped and uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1493

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1500
1501
1502
1503
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1500

def update!(**args)
  @package_path = args[:package_path] if args.key?(:package_path)
  @repository = args[:repository] if args.key?(:repository)
end