Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Python package to upload to Artifact Registry upon successful completion of all build steps. A package can encapsulate multiple objects to be uploaded to a single repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage.



1698
1699
1700
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathsArray<String>

Path globs used to match files in the build's workspace. For Python/ Twine, this is usually dist/*, and sometimes additionally an .asc file. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


1689
1690
1691
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1689

def paths
  @paths
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-python.pkg.dev/$ PROJECT/$REPOSITORY" Files in the workspace matching any path pattern will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


1696
1697
1698
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1696

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1703
1704
1705
1706
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1703

def update!(**args)
  @paths = args[:paths] if args.key?(:paths)
  @repository = args[:repository] if args.key?(:repository)
end