Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.



1945
1946
1947
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


1938
1939
1940
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1938

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


1943
1944
1945
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1943

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1950
1951
1952
1953
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1950

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end