Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Location of the source in a 2nd-gen Google Cloud Build repository resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository.



2248
2249
2250
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Optional. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2234
2235
2236
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2234

def dir
  @dir
end

#repositoryString

Required. Name of the Google Cloud Build repository, formatted as projects/*/ locations/*/connections/*/repositories/*. Corresponds to the JSON property repository

Returns:

  • (String)


2240
2241
2242
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2240

def repository
  @repository
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2246
2247
2248
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2246

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2253
2254
2255
2256
2257
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2253

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end