Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.



2502
2503
2504
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2479
2480
2481
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2479

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2484
2485
2486
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2484

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2489
2490
2491
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2489

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2495
2496
2497
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2495

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2500

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2507
2508
2509
2510
2511
2512
2513
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2507

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end