Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1SecretManagerSecret

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1SecretManagerSecret

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1SecretManagerSecret.



2998
2999
3000
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envString

Environment variable name to associate with the secret. Secret environment variables must be unique across all of a build's secrets, and must be used by at least one build step. Corresponds to the JSON property env

Returns:

  • (String)


2991
2992
2993
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2991

def env
  @env
end

#version_nameString

Resource name of the SecretVersion. In format: projects//secrets//versions/* Corresponds to the JSON property versionName

Returns:

  • (String)


2996
2997
2998
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2996

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3003
3004
3005
3006
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3003

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @version_name = args[:version_name] if args.key?(:version_name)
end