Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Location of the source in a supported storage service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Source

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Source.



3076
3077
3078
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoryGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property connectedRepository



3047
3048
3049
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3047

def connected_repository
  @connected_repository
end

#developer_connect_configGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig

This config defines the location of a source through Developer Connect. Corresponds to the JSON property developerConnectConfig



3052
3053
3054
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3052

def developer_connect_config
  @developer_connect_config
end

#git_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property gitSource



3057
3058
3059
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3057

def git_source
  @git_source
end

#repo_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property repoSource



3062
3063
3064
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3062

def repo_source
  @repo_source
end

#storage_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property storageSource



3067
3068
3069
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3067

def storage_source
  @storage_source
end

#storage_source_manifestGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property storageSourceManifest



3074
3075
3076
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3074

def storage_source_manifest
  @storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3081
3082
3083
3084
3085
3086
3087
3088
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3081

def update!(**args)
  @connected_repository = args[:connected_repository] if args.key?(:connected_repository)
  @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config)
  @git_source = args[:git_source] if args.key?(:git_source)
  @repo_source = args[:repo_source] if args.key?(:repo_source)
  @storage_source = args[:storage_source] if args.key?(:storage_source)
  @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest)
end