Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Provenance of the source. Ways to find the original source, or verify that some source was used for this build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance.



3128
3129
3130
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashesHash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>

Output only. Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build. Note that FileHashes will only be populated if BuildOptions has requested a SourceProvenanceHash. The keys to this map are file paths used as build source and the values contain the hash values for those files. If the build source came in a single package such as a gzipped tarfile (.tar.gz), the FileHash will be for the single path to that file. Corresponds to the JSON property fileHashes



3099
3100
3101
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3099

def file_hashes
  @file_hashes
end

#resolved_connected_repositoryGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property resolvedConnectedRepository



3104
3105
3106
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3104

def resolved_connected_repository
  @resolved_connected_repository
end

#resolved_git_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property resolvedGitSource



3109
3110
3111
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3109

def resolved_git_source
  @resolved_git_source
end

#resolved_repo_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property resolvedRepoSource



3114
3115
3116
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3114

def resolved_repo_source
  @resolved_repo_source
end

#resolved_storage_sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property resolvedStorageSource



3119
3120
3121
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3119

def resolved_storage_source
  @resolved_storage_source
end

#resolved_storage_source_manifestGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property resolvedStorageSourceManifest



3126
3127
3128
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3126

def resolved_storage_source_manifest
  @resolved_storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3133

def update!(**args)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository)
  @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source)
  @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source)
  @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source)
  @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest)
end