Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule.
3354 3355 3356 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3336 3337 3338 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3336 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3342 3343 3344 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3342 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3347 3348 3349 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3347 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
3352 3353 3354 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3352 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3359 3360 3361 3362 3363 3364 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3359 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |