Class: Google::Apis::ContaineranalysisV1beta1::CvsSv3
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::CvsSv3
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Deprecated. Common Vulnerability Scoring System version 3. For details, see https://www.first.org/cvss/specification-document
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
Corresponds to the JSON property
attackComplexity. -
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments.
-
#availability_impact ⇒ String
Corresponds to the JSON property
availabilityImpact. -
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
Corresponds to the JSON property
confidentialityImpact. -
#exploitability_score ⇒ Float
Corresponds to the JSON property
exploitabilityScore. -
#impact_score ⇒ Float
Corresponds to the JSON property
impactScore. -
#integrity_impact ⇒ String
Corresponds to the JSON property
integrityImpact. -
#privileges_required ⇒ String
Corresponds to the JSON property
privilegesRequired. -
#scope ⇒ String
Corresponds to the JSON property
scope. -
#user_interaction ⇒ String
Corresponds to the JSON property
userInteraction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CvsSv3
constructor
A new instance of CvsSv3.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CvsSv3
Returns a new instance of CvsSv3.
1171 1172 1173 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
Corresponds to the JSON property attackComplexity
1118 1119 1120 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1118 def attack_complexity @attack_complexity end |
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that
are constant over time and across user environments.
Corresponds to the JSON property attackVector
1124 1125 1126 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1124 def attack_vector @attack_vector end |
#availability_impact ⇒ String
Corresponds to the JSON property availabilityImpact
1129 1130 1131 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1129 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
1134 1135 1136 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1134 def base_score @base_score end |
#confidentiality_impact ⇒ String
Corresponds to the JSON property confidentialityImpact
1139 1140 1141 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1139 def confidentiality_impact @confidentiality_impact end |
#exploitability_score ⇒ Float
Corresponds to the JSON property exploitabilityScore
1144 1145 1146 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1144 def exploitability_score @exploitability_score end |
#impact_score ⇒ Float
Corresponds to the JSON property impactScore
1149 1150 1151 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1149 def impact_score @impact_score end |
#integrity_impact ⇒ String
Corresponds to the JSON property integrityImpact
1154 1155 1156 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1154 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
Corresponds to the JSON property privilegesRequired
1159 1160 1161 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1159 def privileges_required @privileges_required end |
#scope ⇒ String
Corresponds to the JSON property scope
1164 1165 1166 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1164 def scope @scope end |
#user_interaction ⇒ String
Corresponds to the JSON property userInteraction
1169 1170 1171 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1169 def user_interaction @user_interaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1176 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score) @impact_score = args[:impact_score] if args.key?(:impact_score) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) end |