Class: Google::Apis::ContaineranalysisV1beta1::Deployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

The period during which some deployable was active in a runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deployment

Returns a new instance of Deployment.



3558
3559
3560
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address of the runtime element hosting this deployment. Corresponds to the JSON property address

Returns:

  • (String)


3525
3526
3527
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3525

def address
  @address
end

#configString

Configuration used to create this deployment. Corresponds to the JSON property config

Returns:

  • (String)


3530
3531
3532
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3530

def config
  @config
end

#deploy_timeString

Required. Beginning of the lifetime of this deployment. Corresponds to the JSON property deployTime

Returns:

  • (String)


3535
3536
3537
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3535

def deploy_time
  @deploy_time
end

#platformString

Platform hosting this deployment. Corresponds to the JSON property platform

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3540

def platform
  @platform
end

#resource_uriArray<String>

Output only. Resource URI for the artifact being deployed taken from the deployable field with the same name. Corresponds to the JSON property resourceUri

Returns:

  • (Array<String>)


3546
3547
3548
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3546

def resource_uri
  @resource_uri
end

#undeploy_timeString

End of the lifetime of this deployment. Corresponds to the JSON property undeployTime

Returns:

  • (String)


3551
3552
3553
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3551

def undeploy_time
  @undeploy_time
end

#user_emailString

Identity of the user that triggered this deployment. Corresponds to the JSON property userEmail

Returns:

  • (String)


3556
3557
3558
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3556

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3563
3564
3565
3566
3567
3568
3569
3570
3571
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3563

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @config = args[:config] if args.key?(:config)
  @deploy_time = args[:deploy_time] if args.key?(:deploy_time)
  @platform = args[:platform] if args.key?(:platform)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time)
  @user_email = args[:user_email] if args.key?(:user_email)
end