Class: Google::Apis::ContaineranalysisV1beta1::Derived

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Derived describes the derived image portion (Occurrence) of the DockerImage relationship. This image would be produced from a Dockerfile with FROM .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Derived

Returns a new instance of Derived.



3560
3561
3562
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_resource_urlString

Output only. This contains the base image URL for the derived image occurrence. Corresponds to the JSON property baseResourceUrl

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3540

def base_resource_url
  @base_resource_url
end

#distanceFixnum

Output only. The number of layers by which this image differs from the associated image basis. Corresponds to the JSON property distance

Returns:

  • (Fixnum)


3546
3547
3548
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3546

def distance
  @distance
end

#fingerprintGoogle::Apis::ContaineranalysisV1beta1::Fingerprint

A set of properties that uniquely identify a given Docker image. Corresponds to the JSON property fingerprint



3551
3552
3553
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3551

def fingerprint
  @fingerprint
end

#layer_infoArray<Google::Apis::ContaineranalysisV1beta1::Layer>

This contains layer-specific metadata, if populated it has length "distance" and is ordered with [distance] being the layer immediately following the base image and [1] being the final layer. Corresponds to the JSON property layerInfo



3558
3559
3560
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3558

def layer_info
  @layer_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3565
3566
3567
3568
3569
3570
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3565

def update!(**args)
  @base_resource_url = args[:base_resource_url] if args.key?(:base_resource_url)
  @distance = args[:distance] if args.key?(:distance)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @layer_info = args[:layer_info] if args.key?(:layer_info)
end