Class: Google::Apis::ContaineranalysisV1beta1::Detail
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Detail
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Identifies all appearances of this vulnerability in the package for a specific distro/location. For example: glibc in cpe:/o:debian:debian_linux:8 for versions 2.1 - 2.2
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
Required.
-
#description ⇒ String
A vendor-specific description of this note.
-
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
-
#is_obsolete ⇒ Boolean
(also: #is_obsolete?)
Whether this detail is obsolete.
-
#max_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
-
#min_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
-
#package ⇒ String
Required.
-
#package_type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages etc).
-
#severity_name ⇒ String
The severity (eg: distro assigned severity) for this vulnerability.
-
#source ⇒ String
The source from which the information in this Detail was obtained.
-
#source_update_time ⇒ String
The time this information was last changed at the source.
-
#vendor ⇒ String
The name of the vendor of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Detail
constructor
A new instance of Detail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Detail
Returns a new instance of Detail.
3700 3701 3702 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
Required. The CPE URI in cpe format in
which the vulnerability manifests. Examples include distro or storage location
for vulnerable jar.
Corresponds to the JSON property cpeUri
3638 3639 3640 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3638 def cpe_uri @cpe_uri end |
#description ⇒ String
A vendor-specific description of this note.
Corresponds to the JSON property description
3643 3644 3645 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3643 def description @description end |
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
Corresponds to the JSON property fixedLocation
3648 3649 3650 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3648 def fixed_location @fixed_location end |
#is_obsolete ⇒ Boolean Also known as: is_obsolete?
Whether this detail is obsolete. Occurrences are expected not to point to
obsolete details.
Corresponds to the JSON property isObsolete
3654 3655 3656 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3654 def is_obsolete @is_obsolete end |
#max_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property maxAffectedVersion
3660 3661 3662 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3660 def max_affected_version @max_affected_version end |
#min_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property minAffectedVersion
3665 3666 3667 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3665 def min_affected_version @min_affected_version end |
#package ⇒ String
Required. The name of the package where the vulnerability was found.
Corresponds to the JSON property package
3670 3671 3672 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3670 def package @package end |
#package_type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages
etc).
Corresponds to the JSON property packageType
3676 3677 3678 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3676 def package_type @package_type end |
#severity_name ⇒ String
The severity (eg: distro assigned severity) for this vulnerability.
Corresponds to the JSON property severityName
3681 3682 3683 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3681 def severity_name @severity_name end |
#source ⇒ String
The source from which the information in this Detail was obtained.
Corresponds to the JSON property source
3686 3687 3688 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3686 def source @source end |
#source_update_time ⇒ String
The time this information was last changed at the source. This is an upstream
timestamp from the underlying information source - e.g. Ubuntu security
tracker.
Corresponds to the JSON property sourceUpdateTime
3693 3694 3695 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3693 def source_update_time @source_update_time end |
#vendor ⇒ String
The name of the vendor of the product.
Corresponds to the JSON property vendor
3698 3699 3700 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3698 def vendor @vendor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3705 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @fixed_location = args[:fixed_location] if args.key?(:fixed_location) @is_obsolete = args[:is_obsolete] if args.key?(:is_obsolete) @max_affected_version = args[:max_affected_version] if args.key?(:max_affected_version) @min_affected_version = args[:min_affected_version] if args.key?(:min_affected_version) @package = args[:package] if args.key?(:package) @package_type = args[:package_type] if args.key?(:package_type) @severity_name = args[:severity_name] if args.key?(:severity_name) @source = args[:source] if args.key?(:source) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @vendor = args[:vendor] if args.key?(:vendor) end |