Class: Google::Apis::ContaineranalysisV1beta1::Details

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Details of an attestation occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Details

Returns a new instance of Details.



3736
3737
3738
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestationGoogle::Apis::ContaineranalysisV1beta1::Attestation

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for look-up (how to find this attestation if you already know the authority and artifact to be verified) and intent (which authority was this attestation intended to sign for). Corresponds to the JSON property attestation



3734
3735
3736
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3734

def attestation
  @attestation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3741
3742
3743
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3741

def update!(**args)
  @attestation = args[:attestation] if args.key?(:attestation)
end