Class: Google::Apis::ContaineranalysisV1beta1::Distribution

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This represents a particular channel of distribution for a given package. E.g., Debian's jessie-backports dpkg mirror.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Distribution

Returns a new instance of Distribution.



3899
3900
3901
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The CPU architecture for which packages in this distribution channel were built. Corresponds to the JSON property architecture

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3871

def architecture
  @architecture
end

#cpe_uriString

Required. The cpe_uri in CPE format denoting the package manager version distributing a package. Corresponds to the JSON property cpeUri

Returns:

  • (String)


3877
3878
3879
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3877

def cpe_uri
  @cpe_uri
end

#descriptionString

The distribution channel-specific description of this package. Corresponds to the JSON property description

Returns:

  • (String)


3882
3883
3884
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3882

def description
  @description
end

#latest_versionGoogle::Apis::ContaineranalysisV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property latestVersion



3887
3888
3889
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3887

def latest_version
  @latest_version
end

#maintainerString

A freeform string denoting the maintainer of this package. Corresponds to the JSON property maintainer

Returns:

  • (String)


3892
3893
3894
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3892

def maintainer
  @maintainer
end

#urlString

The distribution channel-specific homepage for this package. Corresponds to the JSON property url

Returns:

  • (String)


3897
3898
3899
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3897

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3904
3905
3906
3907
3908
3909
3910
3911
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3904

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @latest_version = args[:latest_version] if args.key?(:latest_version)
  @maintainer = args[:maintainer] if args.key?(:maintainer)
  @url = args[:url] if args.key?(:url)
end