Class: Google::Apis::ContaineranalysisV1beta1::ExportSbomResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ExportSbomResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
The response from a call to ExportSBOM
Instance Attribute Summary collapse
-
#discovery_occurrence_id ⇒ String
The name of the discovery occurrence in the form "projects/
project_id/ occurrences/OCCURRENCE_IDIt can be used to track the progression of the SBOM export.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportSbomResponse
constructor
A new instance of ExportSbomResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportSbomResponse
Returns a new instance of ExportSbomResponse.
4139 4140 4141 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovery_occurrence_id ⇒ String
The name of the discovery occurrence in the form "projects/project_id/
occurrences/OCCURRENCE_ID It can be used to track the progression of the
SBOM export.
Corresponds to the JSON property discoveryOccurrenceId
4137 4138 4139 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4137 def discovery_occurrence_id @discovery_occurrence_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4144 4145 4146 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4144 def update!(**args) @discovery_occurrence_id = args[:discovery_occurrence_id] if args.key?(:discovery_occurrence_id) end |