Class: Google::Apis::ContaineranalysisV1beta1::Expr

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Expr

Returns a new instance of Expr.



4190
4191
4192
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI. Corresponds to the JSON property description

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4171

def description
  @description
end

#expressionString

Textual representation of an expression in Common Expression Language syntax. Corresponds to the JSON property expression

Returns:

  • (String)


4176
4177
4178
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4176

def expression
  @expression
end

#locationString

Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file. Corresponds to the JSON property location

Returns:

  • (String)


4182
4183
4184
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4182

def location
  @location
end

#titleString

Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression. Corresponds to the JSON property title

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4188

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4195
4196
4197
4198
4199
4200
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4195

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expression = args[:expression] if args.key?(:expression)
  @location = args[:location] if args.key?(:location)
  @title = args[:title] if args.key?(:title)
end