Class: Google::Apis::ContaineranalysisV1beta1::FileNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

FileNote represents an SPDX File Information section: https://spdx.github.io/ spdx-spec/4-file-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileNote

Returns a new instance of FileNote.



4005
4006
4007
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checksumArray<String>

Provide a unique identifier to match analysis information on each specific file in a package Corresponds to the JSON property checksum

Returns:

  • (Array<String>)


3992
3993
3994
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3992

def checksum
  @checksum
end

#file_typeString

This field provides information about the type of file identified Corresponds to the JSON property fileType

Returns:

  • (String)


3997
3998
3999
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3997

def file_type
  @file_type
end

#titleString

Identify the full path and filename that corresponds to the file information in this section Corresponds to the JSON property title

Returns:

  • (String)


4003
4004
4005
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4003

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4010
4011
4012
4013
4014
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4010

def update!(**args)
  @checksum = args[:checksum] if args.key?(:checksum)
  @file_type = args[:file_type] if args.key?(:file_type)
  @title = args[:title] if args.key?(:title)
end