Class: Google::Apis::ContaineranalysisV1beta1::Fingerprint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A set of properties that uniquely identify a given Docker image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Fingerprint

Returns a new instance of Fingerprint.



4502
4503
4504
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#v1_nameString

Required. The layer ID of the final layer in the Docker image's v1 representation. Corresponds to the JSON property v1Name

Returns:

  • (String)


4488
4489
4490
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4488

def v1_name
  @v1_name
end

#v2_blobArray<String>

Required. The ordered list of v2 blobs that represent a given image. Corresponds to the JSON property v2Blob

Returns:

  • (Array<String>)


4493
4494
4495
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4493

def v2_blob
  @v2_blob
end

#v2_nameString

Output only. The name of the image's v2 blobs computed via: [bottom] := v2_blobbottom := sha256(v2_blob[N] + " " + v2_name[N+1]) Only the name of the final blob is kept. Corresponds to the JSON property v2Name

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4500

def v2_name
  @v2_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4507
4508
4509
4510
4511
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4507

def update!(**args)
  @v1_name = args[:v1_name] if args.key?(:v1_name)
  @v2_blob = args[:v2_blob] if args.key?(:v2_blob)
  @v2_name = args[:v2_name] if args.key?(:v2_name)
end