Class: Google::Apis::ContaineranalysisV1beta1::FixableTotalByDigest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Per resource and severity counts of fixable and total vulnerabilities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixableTotalByDigest

Returns a new instance of FixableTotalByDigest.



4478
4479
4480
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixable_countFixnum

The number of fixable vulnerabilities associated with this resource. Corresponds to the JSON property fixableCount

Returns:

  • (Fixnum)


4460
4461
4462
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4460

def fixable_count
  @fixable_count
end

#resourceGoogle::Apis::ContaineranalysisV1beta1::Resource

An entity that can have metadata. For example, a Docker image. Corresponds to the JSON property resource



4465
4466
4467
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4465

def resource
  @resource
end

#severityString

The severity for this count. SEVERITY_UNSPECIFIED indicates total across all severities. Corresponds to the JSON property severity

Returns:

  • (String)


4471
4472
4473
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4471

def severity
  @severity
end

#total_countFixnum

The total number of vulnerabilities associated with this resource. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


4476
4477
4478
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4476

def total_count
  @total_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4483
4484
4485
4486
4487
4488
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4483

def update!(**args)
  @fixable_count = args[:fixable_count] if args.key?(:fixable_count)
  @resource = args[:resource] if args.key?(:resource)
  @severity = args[:severity] if args.key?(:severity)
  @total_count = args[:total_count] if args.key?(:total_count)
end