Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#hashes ⇒ Google::Apis::ContaineranalysisV1beta1::ArtifactHashes
Defines a hash object for use in Materials and Products.
-
#resource_uri ⇒ String
Corresponds to the JSON property
resourceUri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1beta1IntotoArtifact
constructor
A new instance of GrafeasV1beta1IntotoArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1beta1IntotoArtifact
Returns a new instance of GrafeasV1beta1IntotoArtifact.
4468 4469 4470 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hashes ⇒ Google::Apis::ContaineranalysisV1beta1::ArtifactHashes
Defines a hash object for use in Materials and Products.
Corresponds to the JSON property hashes
4461 4462 4463 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4461 def hashes @hashes end |
#resource_uri ⇒ String
Corresponds to the JSON property resourceUri
4466 4467 4468 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4466 def resource_uri @resource_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4473 4474 4475 4476 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4473 def update!(**args) @hashes = args[:hashes] if args.key?(:hashes) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) end |