Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This corresponds to a signed in-toto link - it is made up of one or more signatures and the in-toto link itself. This is used for occurrences of a Grafeas in-toto note.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1beta1IntotoDetails

Returns a new instance of GrafeasV1beta1IntotoDetails.



4489
4490
4491
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signaturesArray<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoSignature>

Corresponds to the JSON property signatures



4482
4483
4484
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4482

def signatures
  @signatures
end

#signedGoogle::Apis::ContaineranalysisV1beta1::Link

This corresponds to an in-toto link. Corresponds to the JSON property signed



4487
4488
4489
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4487

def signed
  @signed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4494
4495
4496
4497
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4494

def update!(**args)
  @signatures = args[:signatures] if args.key?(:signatures)
  @signed = args[:signed] if args.key?(:signed)
end