Class: Google::Apis::ContaineranalysisV1beta1::License

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

License information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ License

Returns a new instance of License.



5302
5303
5304
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentsString

Comments Corresponds to the JSON property comments

Returns:

  • (String)


5292
5293
5294
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5292

def comments
  @comments
end

#expressionString

Often a single license can be used to represent the licensing terms. Sometimes it is necessary to include a choice of one or more licenses or some combination of license identifiers. Examples: "LGPL-2.1-only OR MIT", "LGPL-2. 1-only AND MIT", "GPL-2.0-or-later WITH Bison-exception-2.2". Corresponds to the JSON property expression

Returns:

  • (String)


5300
5301
5302
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5300

def expression
  @expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5307
5308
5309
5310
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5307

def update!(**args)
  @comments = args[:comments] if args.key?(:comments)
  @expression = args[:expression] if args.key?(:expression)
end