Class: Google::Apis::ContaineranalysisV1beta1::LicensesSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Per license count

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicensesSummary

Returns a new instance of LicensesSummary.



5316
5317
5318
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The number of fixable vulnerabilities associated with this resource. Corresponds to the JSON property count

Returns:

  • (Fixnum)


5307
5308
5309
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5307

def count
  @count
end

#licenseString

The license of the package. Note that the format of this value is not guaranteed. It may be nil, an empty string, a boolean value (A | B), a differently formed boolean value (A OR B), etc... Corresponds to the JSON property license

Returns:

  • (String)


5314
5315
5316
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5314

def license
  @license
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5321
5322
5323
5324
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5321

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @license = args[:license] if args.key?(:license)
end