Class: Google::Apis::ContaineranalysisV1beta1::Location

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

An occurrence of a particular package installation found within a system's filesystem. E.g., glibc was found in /var/lib/dpkg/status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



5584
5585
5586
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

Deprecated. The CPE URI in CPE format denoting the package manager version distributing a package. Corresponds to the JSON property cpeUri

Returns:

  • (String)


5572
5573
5574
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5572

def cpe_uri
  @cpe_uri
end

#pathString

The path from which we gathered that this package/version is installed. Corresponds to the JSON property path

Returns:

  • (String)


5577
5578
5579
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5577

def path
  @path
end

#versionGoogle::Apis::ContaineranalysisV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property version



5582
5583
5584
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5582

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5589
5590
5591
5592
5593
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5589

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @path = args[:path] if args.key?(:path)
  @version = args[:version] if args.key?(:version)
end