Class: Google::Apis::ContaineranalysisV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



5988
5989
5990
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_skill_analysisGoogle::Apis::ContaineranalysisV1beta1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



5863
5864
5865
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5863

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::ContaineranalysisV1beta1::Details

Details of an attestation occurrence. Corresponds to the JSON property attestation



5868
5869
5870
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5868

def attestation
  @attestation
end

#buildGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails

Details of a build occurrence. Corresponds to the JSON property build



5873
5874
5875
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5873

def build
  @build
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5878
5879
5880
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5878

def create_time
  @create_time
end

#deploymentGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DeploymentDetails

Details of a deployment occurrence. Corresponds to the JSON property deployment



5883
5884
5885
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5883

def deployment
  @deployment
end

#derived_imageGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1ImageDetails

Details of an image occurrence. Corresponds to the JSON property derivedImage



5888
5889
5890
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5888

def derived_image
  @derived_image
end

#discoveredGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DiscoveryDetails

Details of a discovery occurrence. Corresponds to the JSON property discovered



5893
5894
5895
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5893

def discovered
  @discovered
end

#envelopeGoogle::Apis::ContaineranalysisV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



5899
5900
5901
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5899

def envelope
  @envelope
end

#installationGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1PackageDetails

Details of a package occurrence. Corresponds to the JSON property installation



5904
5905
5906
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5904

def installation
  @installation
end

#intotoGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoDetails

This corresponds to a signed in-toto link - it is made up of one or more signatures and the in-toto link itself. This is used for occurrences of a Grafeas in-toto note. Corresponds to the JSON property intoto



5911
5912
5913
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5911

def intoto
  @intoto
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


5917
5918
5919
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5917

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


5923
5924
5925
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5923

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


5930
5931
5932
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5930

def note_name
  @note_name
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


5935
5936
5937
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5935

def remediation
  @remediation
end

#resourceGoogle::Apis::ContaineranalysisV1beta1::Resource

An entity that can have metadata. For example, a Docker image. Corresponds to the JSON property resource



5940
5941
5942
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5940

def resource
  @resource
end

#sbomGoogle::Apis::ContaineranalysisV1beta1::DocumentOccurrence

DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property sbom



5946
5947
5948
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5946

def sbom
  @sbom
end

#sbom_referenceGoogle::Apis::ContaineranalysisV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



5953
5954
5955
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5953

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::ContaineranalysisV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



5958
5959
5960
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5958

def secret
  @secret
end

#spdx_fileGoogle::Apis::ContaineranalysisV1beta1::FileOccurrence

FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/ Corresponds to the JSON property spdxFile



5964
5965
5966
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5964

def spdx_file
  @spdx_file
end

#spdx_packageGoogle::Apis::ContaineranalysisV1beta1::PackageInfoOccurrence

PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/ Corresponds to the JSON property spdxPackage



5970
5971
5972
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5970

def spdx_package
  @spdx_package
end

#spdx_relationshipGoogle::Apis::ContaineranalysisV1beta1::RelationshipOccurrence

RelationshipOccurrence represents an SPDX Relationship section: https://spdx. github.io/spdx-spec/7-relationships-between-SPDX-elements/ Corresponds to the JSON property spdxRelationship



5976
5977
5978
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5976

def spdx_relationship
  @spdx_relationship
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5981
5982
5983
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5981

def update_time
  @update_time
end

#vulnerabilityGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails

Details of a vulnerability Occurrence. Corresponds to the JSON property vulnerability



5986
5987
5988
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5986

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5993

def update!(**args)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @derived_image = args[:derived_image] if args.key?(:derived_image)
  @discovered = args[:discovered] if args.key?(:discovered)
  @envelope = args[:envelope] if args.key?(:envelope)
  @installation = args[:installation] if args.key?(:installation)
  @intoto = args[:intoto] if args.key?(:intoto)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource = args[:resource] if args.key?(:resource)
  @sbom = args[:sbom] if args.key?(:sbom)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @spdx_file = args[:spdx_file] if args.key?(:spdx_file)
  @spdx_package = args[:spdx_package] if args.key?(:spdx_package)
  @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end