Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoNote

Returns a new instance of PackageInfoNote.



6211
6212
6213
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzedBoolean Also known as: analyzed?

Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property analyzed

Returns:

  • (Boolean)


6113
6114
6115
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6113

def analyzed
  @analyzed
end

#attributionString

A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attribution

Returns:

  • (String)


6120
6121
6122
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6120

def attribution
  @attribution
end

#checksumString

Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property checksum

Returns:

  • (String)


6127
6128
6129
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6127

def checksum
  @checksum
end

Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


6132
6133
6134
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6132

def copyright
  @copyright
end

#detailed_descriptionString

A more detailed description of the package Corresponds to the JSON property detailedDescription

Returns:

  • (String)


6137
6138
6139
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6137

def detailed_description
  @detailed_description
end

#download_locationString

This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property downloadLocation

Returns:

  • (String)


6144
6145
6146
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6144

def download_location
  @download_location
end

#external_refsArray<Google::Apis::ContaineranalysisV1beta1::ExternalRef>

ExternalRef Corresponds to the JSON property externalRefs



6149
6150
6151
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6149

def external_refs
  @external_refs
end

#files_license_infoArray<String>

Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package. The relationship between licenses (i.e., conjunctive, disjunctive) is not specified in this field – it is simply a listing of all licenses found Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


6157
6158
6159
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6157

def files_license_info
  @files_license_info
end

#home_pageString

Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6163
6164
6165
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6163

def home_page
  @home_page
end

#license_declaredGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseDeclared



6168
6169
6170
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6168

def license_declared
  @license_declared
end

#originatorString

If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property originator

Returns:

  • (String)


6175
6176
6177
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6175

def originator
  @originator
end

#package_typeString

The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6180
6181
6182
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6180

def package_type
  @package_type
end

#summary_descriptionString

A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6185
6186
6187
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6185

def summary_description
  @summary_description
end

#supplierString

Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property supplier

Returns:

  • (String)


6191
6192
6193
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6191

def supplier
  @supplier
end

#titleString

Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6196
6197
6198
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6196

def title
  @title
end

#verification_codeString

This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property verificationCode

Returns:

  • (String)


6204
6205
6206
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6204

def verification_code
  @verification_code
end

#versionString

Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6209
6210
6211
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6209

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6216

def update!(**args)
  @analyzed = args[:analyzed] if args.key?(:analyzed)
  @attribution = args[:attribution] if args.key?(:attribution)
  @checksum = args[:checksum] if args.key?(:checksum)
  @copyright = args[:copyright] if args.key?(:copyright)
  @detailed_description = args[:detailed_description] if args.key?(:detailed_description)
  @download_location = args[:download_location] if args.key?(:download_location)
  @external_refs = args[:external_refs] if args.key?(:external_refs)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @home_page = args[:home_page] if args.key?(:home_page)
  @license_declared = args[:license_declared] if args.key?(:license_declared)
  @originator = args[:originator] if args.key?(:originator)
  @package_type = args[:package_type] if args.key?(:package_type)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @supplier = args[:supplier] if args.key?(:supplier)
  @title = args[:title] if args.key?(:title)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
  @version = args[:version] if args.key?(:version)
end