Class: Google::Apis::ContaineranalysisV1beta1::PackagesSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A summary of the packages found within the given resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackagesSummaryResponse

Returns a new instance of PackagesSummaryResponse.



6273
6274
6275
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licenses_summaryArray<Google::Apis::ContaineranalysisV1beta1::LicensesSummary>

A listing by license name of each of the licenses and their counts. Corresponds to the JSON property licensesSummary



6266
6267
6268
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6266

def licenses_summary
  @licenses_summary
end

#resource_urlString

The unique URL of the image or the container for which this summary applies. Corresponds to the JSON property resourceUrl

Returns:

  • (String)


6271
6272
6273
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6271

def resource_url
  @resource_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6278
6279
6280
6281
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6278

def update!(**args)
  @licenses_summary = args[:licenses_summary] if args.key?(:licenses_summary)
  @resource_url = args[:resource_url] if args.key?(:resource_url)
end