Class: Google::Apis::ContaineranalysisV1beta1::RelationshipOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

RelationshipOccurrence represents an SPDX Relationship section: https://spdx. github.io/spdx-spec/7-relationships-between-SPDX-elements/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelationshipOccurrence

Returns a new instance of RelationshipOccurrence.



6770
6771
6772
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

A place for the SPDX file creator to record any general comments about the relationship Corresponds to the JSON property comment

Returns:

  • (String)


6748
6749
6750
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6748

def comment
  @comment
end

#sourceString

Also referred to as SPDXRef-A The source SPDX element (file, package, etc) Corresponds to the JSON property source

Returns:

  • (String)


6753
6754
6755
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6753

def source
  @source
end

#targetString

Also referred to as SPDXRef-B The target SPDC element (file, package, etc) In cases where there are "known unknowns", the use of the keyword NOASSERTION can be used The keywords NONE can be used to indicate that an SPDX element ( package/file/snippet) has no other elements connected by some relationship to it Corresponds to the JSON property target

Returns:

  • (String)


6762
6763
6764
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6762

def target
  @target
end

#typeString

Output only. The type of relationship between the source and target SPDX elements Corresponds to the JSON property type

Returns:

  • (String)


6768
6769
6770
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6768

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6775
6776
6777
6778
6779
6780
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6775

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @source = args[:source] if args.key?(:source)
  @target = args[:target] if args.key?(:target)
  @type = args[:type] if args.key?(:type)
end