Class: Google::Apis::ContaineranalysisV1beta1::RepoId
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::RepoId
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A unique identifier for a Cloud Repo.
Instance Attribute Summary collapse
-
#project_repo_id ⇒ Google::Apis::ContaineranalysisV1beta1::ProjectRepoId
Selects a repo using a Google Cloud Platform project ID (e.g., winged-cargo-31) and a repo name within that project.
-
#uid ⇒ String
A server-assigned, globally unique identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RepoId
constructor
A new instance of RepoId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RepoId
Returns a new instance of RepoId.
6705 6706 6707 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_repo_id ⇒ Google::Apis::ContaineranalysisV1beta1::ProjectRepoId
Selects a repo using a Google Cloud Platform project ID (e.g., winged-cargo-31)
and a repo name within that project.
Corresponds to the JSON property projectRepoId
6698 6699 6700 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6698 def project_repo_id @project_repo_id end |
#uid ⇒ String
A server-assigned, globally unique identifier.
Corresponds to the JSON property uid
6703 6704 6705 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6703 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6710 6711 6712 6713 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6710 def update!(**args) @project_repo_id = args[:project_repo_id] if args.key?(:project_repo_id) @uid = args[:uid] if args.key?(:uid) end |