Class: Google::Apis::ContaineranalysisV1beta1::SbomReferenceIntotoPayload
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::SbomReferenceIntotoPayload
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
The actual payload that contains the SBOM Reference data. The payload follows the intoto statement specification. See https://github.com/in-toto/attestation/ blob/main/spec/v1.0/statement.md for more details.
Instance Attribute Summary collapse
-
#_type ⇒ String
Identifier for the schema of the Statement.
-
#predicate ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
-
#predicate_type ⇒ String
URI identifying the type of the Predicate.
-
#subject ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Subject>
Set of software artifacts that the attestation applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SbomReferenceIntotoPayload
constructor
A new instance of SbomReferenceIntotoPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SbomReferenceIntotoPayload
Returns a new instance of SbomReferenceIntotoPayload.
6539 6540 6541 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#_type ⇒ String
Identifier for the schema of the Statement.
Corresponds to the JSON property _type
6521 6522 6523 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6521 def _type @_type end |
#predicate ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceIntotoPredicate
A predicate which describes the SBOM being referenced.
Corresponds to the JSON property predicate
6526 6527 6528 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6526 def predicate @predicate end |
#predicate_type ⇒ String
URI identifying the type of the Predicate.
Corresponds to the JSON property predicateType
6531 6532 6533 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6531 def predicate_type @predicate_type end |
#subject ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Subject>
Set of software artifacts that the attestation applies to. Each element
represents a single software artifact.
Corresponds to the JSON property subject
6537 6538 6539 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6537 def subject @subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6544 6545 6546 6547 6548 6549 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6544 def update!(**args) @_type = args[:_type] if args.key?(:_type) @predicate = args[:predicate] if args.key?(:predicate) @predicate_type = args[:predicate_type] if args.key?(:predicate_type) @subject = args[:subject] if args.key?(:subject) end |