Class: Google::Apis::ContaineranalysisV1beta1::SecretLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::SecretLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
The location of the secret.
Instance Attribute Summary collapse
-
#file_location ⇒ Google::Apis::ContaineranalysisV1beta1::FileLocation
Indicates the location at which a package was found.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretLocation
constructor
A new instance of SecretLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretLocation
Returns a new instance of SecretLocation.
6586 6587 6588 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_location ⇒ Google::Apis::ContaineranalysisV1beta1::FileLocation
Indicates the location at which a package was found.
Corresponds to the JSON property fileLocation
6584 6585 6586 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6584 def file_location @file_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6591 6592 6593 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6591 def update!(**args) @file_location = args[:file_location] if args.key?(:file_location) end |