Class: Google::Apis::ContaineranalysisV1beta1::Subject
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Subject
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Set of software artifacts that the attestation applies to. Each element represents a single software artifact.
Instance Attribute Summary collapse
-
#digest ⇒ Hash<String,String>
"": ""Algorithms can be e.g. -
#name ⇒ String
Identifier to distinguish this artifact from others within the subject.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subject
constructor
A new instance of Subject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subject
Returns a new instance of Subject.
7438 7439 7440 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#digest ⇒ Hash<String,String>
"": "" Algorithms can be e.g. sha256, sha512 See https://github.com/in-toto/
attestation/blob/main/spec/field_types.md#DigestSet
Corresponds to the JSON property digest
7431 7432 7433 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7431 def digest @digest end |
#name ⇒ String
Identifier to distinguish this artifact from others within the subject.
Corresponds to the JSON property name
7436 7437 7438 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7436 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7443 7444 7445 7446 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7443 def update!(**args) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) end |