Class: Google::Apis::ContaineranalysisV1beta1::VulnerabilityOccurrencesSummary
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::VulnerabilityOccurrencesSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A summary of how many vulnerability occurrences there are per resource and severity type.
Instance Attribute Summary collapse
-
#counts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::FixableTotalByDigest>
A listing by resource of the number of fixable and total vulnerabilities.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityOccurrencesSummary
constructor
A new instance of VulnerabilityOccurrencesSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityOccurrencesSummary
Returns a new instance of VulnerabilityOccurrencesSummary.
7437 7438 7439 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#counts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::FixableTotalByDigest>
A listing by resource of the number of fixable and total vulnerabilities.
Corresponds to the JSON property counts
7428 7429 7430 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7428 def counts @counts end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable regions. Populated for requests from the global
region when return_partial_success is set. Format: projects/[PROJECT_ID]/
locations/[LOCATION]
Corresponds to the JSON property unreachable
7435 7436 7437 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7435 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7442 7443 7444 7445 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7442 def update!(**args) @counts = args[:counts] if args.key?(:counts) @unreachable = args[:unreachable] if args.key?(:unreachable) end |