Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.



1330
1331
1332
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_timeString

Output only. The time when the approval decision was made. Corresponds to the JSON property approvalTime

Returns:

  • (String)


1304
1305
1306
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1304

def approval_time
  @approval_time
end

#approver_accountString

Output only. Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called. Corresponds to the JSON property approverAccount

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1310

def 
  @approver_account
end

#commentString

Optional. An optional comment for this manual approval result. Corresponds to the JSON property comment

Returns:

  • (String)


1315
1316
1317
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1315

def comment
  @comment
end

#decisionString

Required. The decision of this manual approval. Corresponds to the JSON property decision

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1320

def decision
  @decision
end

#urlString

Optional. An optional URL tied to this manual approval result. This field is essentially the same as comment, except that it will be rendered by the UI differently. An example use case is a link to an external job that approved this Build. Corresponds to the JSON property url

Returns:

  • (String)


1328
1329
1330
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1328

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
1338
1339
1340
1341
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1335

def update!(**args)
  @approval_time = args[:approval_time] if args.key?(:approval_time)
  @approver_account = args[:approver_account] if args.key?(:approver_account)
  @comment = args[:comment] if args.key?(:comment)
  @decision = args[:decision] if args.key?(:decision)
  @url = args[:url] if args.key?(:url)
end