Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.



1288
1289
1290
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_timeString

Output only. The time when the approval decision was made. Corresponds to the JSON property approvalTime

Returns:

  • (String)


1262
1263
1264
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1262

def approval_time
  @approval_time
end

#approver_accountString

Output only. Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called. Corresponds to the JSON property approverAccount

Returns:

  • (String)


1268
1269
1270
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1268

def 
  @approver_account
end

#commentString

Optional. An optional comment for this manual approval result. Corresponds to the JSON property comment

Returns:

  • (String)


1273
1274
1275
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1273

def comment
  @comment
end

#decisionString

Required. The decision of this manual approval. Corresponds to the JSON property decision

Returns:

  • (String)


1278
1279
1280
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1278

def decision
  @decision
end

#urlString

Optional. An optional URL tied to this manual approval result. This field is essentially the same as comment, except that it will be rendered by the UI differently. An example use case is a link to an external job that approved this Build. Corresponds to the JSON property url

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1286

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1293
1294
1295
1296
1297
1298
1299
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1293

def update!(**args)
  @approval_time = args[:approval_time] if args.key?(:approval_time)
  @approver_account = args[:approver_account] if args.key?(:approver_account)
  @comment = args[:comment] if args.key?(:comment)
  @decision = args[:decision] if args.key?(:decision)
  @url = args[:url] if args.key?(:url)
end