Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
Instance Attribute Summary collapse
-
#approval_time ⇒ String
Output only.
-
#approver_account ⇒ String
Output only.
-
#comment ⇒ String
Optional.
-
#decision ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ApprovalResult.
1244 1245 1246 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_time ⇒ String
Output only. The time when the approval decision was made.
Corresponds to the JSON property approvalTime
1218 1219 1220 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1218 def approval_time @approval_time end |
#approver_account ⇒ String
Output only. Email of the user that called the ApproveBuild API to approve or
reject a build at the time that the API was called.
Corresponds to the JSON property approverAccount
1224 1225 1226 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1224 def approver_account @approver_account end |
#comment ⇒ String
Optional. An optional comment for this manual approval result.
Corresponds to the JSON property comment
1229 1230 1231 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1229 def comment @comment end |
#decision ⇒ String
Required. The decision of this manual approval.
Corresponds to the JSON property decision
1234 1235 1236 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1234 def decision @decision end |
#url ⇒ String
Optional. An optional URL tied to this manual approval result. This field is
essentially the same as comment, except that it will be rendered by the UI
differently. An example use case is a link to an external job that approved
this Build.
Corresponds to the JSON property url
1242 1243 1244 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1242 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1249 1250 1251 1252 1253 1254 1255 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1249 def update!(**args) @approval_time = args[:approval_time] if args.key?(:approval_time) @approver_account = args[:approver_account] if args.key?(:approver_account) @comment = args[:comment] if args.key?(:comment) @decision = args[:decision] if args.key?(:decision) @url = args[:url] if args.key?(:url) end |