Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.



1371
1372
1373
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_artifactsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>

Optional. A list of generic artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property genericArtifacts



1312
1313
1314
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1312

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



1319
1320
1321
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1319

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


1328
1329
1330
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1328

def images
  @images
end

#maven_artifactsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



1337
1338
1339
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1337

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



1346
1347
1348
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1346

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



1352
1353
1354
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1352

def objects
  @objects
end

#ociArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>

Optional. A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps. OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property oci



1361
1362
1363
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1361

def oci
  @oci
end

#python_packagesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



1369
1370
1371
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1369

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1376

def update!(**args)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @oci = args[:oci] if args.key?(:oci)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end