Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>
Optional.
-
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>
Optional.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#objects ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
-
#oci ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>
Optional.
-
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.
1365 1366 1367 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGenericArtifact>
Optional. A list of generic artifacts to be uploaded to Artifact Registry upon
successful completion of all build steps. If any artifacts fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property genericArtifacts
1306 1307 1308 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1306 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>
Optional. A list of Go modules to be uploaded to Artifact Registry upon
successful completion of all build steps. If any objects fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property goModules
1313 1314 1315 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1313 def go_modules @go_modules end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images will be pushed using the builder service account's
credentials. The digests of the pushed images will be stored in the Build
resource's results field. If any of the images fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property images
1322 1323 1324 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1322 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful
completion of all build steps. Artifacts in the workspace matching specified
paths globs will be uploaded to the specified Artifact Registry repository
using the builder service account's credentials. If any artifacts fail to be
pushed, the build is marked FAILURE.
Corresponds to the JSON property mavenArtifacts
1331 1332 1333 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1331 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful
completion of all build steps. Npm packages in the specified paths will be
uploaded to the specified Artifact Registry repository using the builder
service account's credentials. If any packages fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property npmPackages
1340 1341 1342 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1340 def npm_packages @npm_packages end |
#objects ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion
of all build steps.
Corresponds to the JSON property objects
1346 1347 1348 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1346 def objects @objects end |
#oci ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsOci>
Optional. A list of OCI images to be uploaded to Artifact Registry upon
successful completion of all build steps. OCI images in the specified paths
will be uploaded to the specified Artifact Registry repository using the
builder service account's credentials. If any images fail to be pushed, the
build is marked FAILURE.
Corresponds to the JSON property oci
1355 1356 1357 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1355 def oci @oci end |
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful
completion of all build steps. The build service account credentials will be
used to perform the upload. If any objects fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property pythonPackages
1363 1364 1365 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1363 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1370 def update!(**args) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @objects = args[:objects] if args.key?(:objects) @oci = args[:oci] if args.key?(:oci) @python_packages = args[:python_packages] if args.key?(:python_packages) end |