Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts.



1311
1312
1313
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#go_modulesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsGoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



1268
1269
1270
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1268

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


1277
1278
1279
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1277

def images
  @images
end

#maven_artifactsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



1286
1287
1288
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1286

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsNpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



1295
1296
1297
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1295

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



1301
1302
1303
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1301

def objects
  @objects
end

#python_packagesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsPythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



1309
1310
1311
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1309

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1316
1317
1318
1319
1320
1321
1322
1323
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1316

def update!(**args)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end