Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Maven
artifactIdvalue used when uploading the artifact to Artifact Registry. -
#deploy_folder ⇒ String
Optional.
-
#group_id ⇒ String
Maven
groupIdvalue used when uploading the artifact to Artifact Registry. -
#path ⇒ String
Optional.
-
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix.
-
#version ⇒ String
Maven
versionvalue used when uploading the artifact to Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1ArtifactsMavenArtifact.
1462 1463 1464 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Maven artifactId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property artifactId
1427 1428 1429 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1427 def artifact_id @artifact_id end |
#deploy_folder ⇒ String
Optional. Path to a folder containing the files to upload to Artifact Registry.
This can be either an absolute path, e.g. /workspace/my-app/target/, or a
relative path from /workspace, e.g. my-app/target/. This field is mutually
exclusive with the path field.
Corresponds to the JSON property deployFolder
1435 1436 1437 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1435 def deploy_folder @deploy_folder end |
#group_id ⇒ String
Maven groupId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property groupId
1440 1441 1442 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1440 def group_id @group_id end |
#path ⇒ String
Optional. Path to an artifact in the build's workspace to be uploaded to
Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/
target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/
target/my-app-1.0.SNAPSHOT.jar.
Corresponds to the JSON property path
1448 1449 1450 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1448 def path @path end |
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$
PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be
uploaded to Artifact Registry with this location as a prefix.
Corresponds to the JSON property repository
1455 1456 1457 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1455 def repository @repository end |
#version ⇒ String
Maven version value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property version
1460 1461 1462 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1460 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1467 1468 1469 1470 1471 1472 1473 1474 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1467 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder) @group_id = args[:group_id] if args.key?(:group_id) @path = args[:path] if args.key?(:path) @repository = args[:repository] if args.key?(:repository) @version = args[:version] if args.key?(:version) end |