Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Build

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A build resource in the Cloud Build API. At a high level, a Build describes where to find source code, how to build it (for example, the builder image to run on the source), and where to store the built artifacts. Fields can include the following variables, which will be expanded when the build is created: - $ PROJECT_ID: the project ID of the build. - $PROJECT_NUMBER: the project number of the build. - $LOCATION: the location/region of the build. - $BUILD_ID: the autogenerated ID of the build. - $REPO_NAME: the source repository name specified by RepoSource. - $BRANCH_NAME: the branch name specified by RepoSource. - $TAG_NAME: the tag name specified by RepoSource. - $REVISION_ID or $COMMIT_SHA: the commit SHA specified by RepoSource or resolved from the specified branch or tag. - $SHORT_SHA: first 7 characters of $REVISION_ID or $ COMMIT_SHA.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Build

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Build.



1853
1854
1855
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approvalGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildApproval

BuildApproval describes a build's approval configuration, state, and result. Corresponds to the JSON property approval



1673
1674
1675
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1673

def approval
  @approval
end

#artifactsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts

Artifacts produced by a build that should be uploaded upon successful completion of all build steps. Corresponds to the JSON property artifacts



1679
1680
1681
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1679

def artifacts
  @artifacts
end

#available_secretsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secrets

Secrets and secret environment variables. Corresponds to the JSON property availableSecrets



1684
1685
1686
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1684

def available_secrets
  @available_secrets
end

#build_trigger_idString

Output only. The ID of the BuildTrigger that triggered this build, if it was triggered automatically. Corresponds to the JSON property buildTriggerId

Returns:

  • (String)


1690
1691
1692
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1690

def build_trigger_id
  @build_trigger_id
end

#create_timeString

Output only. Time at which the request to create the build was received. Corresponds to the JSON property createTime

Returns:

  • (String)


1695
1696
1697
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1695

def create_time
  @create_time
end

#dependenciesArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency>

Optional. Dependencies that the Cloud Build worker will fetch before executing user steps. Corresponds to the JSON property dependencies



1701
1702
1703
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1701

def dependencies
  @dependencies
end

#failure_infoGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

A fatal problem encountered during the execution of the build. Corresponds to the JSON property failureInfo



1706
1707
1708
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1706

def failure_info
  @failure_info
end

#finish_timeString

Output only. Time at which execution of the build was finished. The difference between finish_time and start_time is the duration of the build's execution. Corresponds to the JSON property finishTime

Returns:

  • (String)


1712
1713
1714
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1712

def finish_time
  @finish_time
end

#git_configGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfig

GitConfig is a configuration for git operations. Corresponds to the JSON property gitConfig



1717
1718
1719
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1717

def git_config
  @git_config
end

#idString

Output only. Unique identifier of the build. Corresponds to the JSON property id

Returns:

  • (String)


1722
1723
1724
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1722

def id
  @id
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images are pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build status is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


1731
1732
1733
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1731

def images
  @images
end

#log_urlString

Output only. URL to logs for this build in Google Cloud Console. Corresponds to the JSON property logUrl

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1736

def log_url
  @log_url
end

#logs_bucketString

Cloud Storage bucket where logs should be written (see Bucket Name Requirements ). Logs file names will be of the format $logs_bucket/log-$build_id.txt. Corresponds to the JSON property logsBucket

Returns:

  • (String)


1743
1744
1745
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1743

def logs_bucket
  @logs_bucket
end

#nameString

Output only. The 'Build' name with format: projects/project/locations/ location/builds/build`, wherebuildis a unique identifier generated by the service. Corresponds to the JSON propertyname`

Returns:

  • (String)


1750
1751
1752
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1750

def name
  @name
end

#optionsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions

Optional arguments to enable specific features of builds. Corresponds to the JSON property options



1755
1756
1757
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1755

def options
  @options
end

#project_idString

Output only. ID of the project. Corresponds to the JSON property projectId

Returns:

  • (String)


1760
1761
1762
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1760

def project_id
  @project_id
end

#queue_ttlString

TTL in queue for this build. If provided and the build is enqueued longer than this value, the build will expire and the build status will be EXPIRED. The TTL starts ticking from create_time. Corresponds to the JSON property queueTtl

Returns:

  • (String)


1767
1768
1769
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1767

def queue_ttl
  @queue_ttl
end

#resultsGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results

Artifacts created by the build pipeline. Corresponds to the JSON property results



1772
1773
1774
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1772

def results
  @results
end

#secretsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secret>

Secrets to decrypt using Cloud Key Management Service. Note: Secret Manager is the recommended technique for managing sensitive data with Cloud Build. Use available_secrets to configure builds to access secrets from Secret Manager. For instructions, see: https://cloud.google.com/cloud-build/docs/securing- builds/use-secrets Corresponds to the JSON property secrets



1781
1782
1783
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1781

def secrets
  @secrets
end

#service_accountString

IAM service account whose credentials will be used at build runtime. Must be of the format projects/PROJECT_ID/serviceAccounts/ACCOUNT`. ACCOUNT can be email address or uniqueId of the service account. Corresponds to the JSON propertyserviceAccount`

Returns:

  • (String)


1788
1789
1790
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1788

def 
  @service_account
end

#sourceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source

Location of the source in a supported storage service. Corresponds to the JSON property source



1793
1794
1795
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1793

def source
  @source
end

#source_provenanceGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance

Provenance of the source. Ways to find the original source, or verify that some source was used for this build. Corresponds to the JSON property sourceProvenance



1799
1800
1801
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1799

def source_provenance
  @source_provenance
end

#start_timeString

Output only. Time at which execution of the build was started. Corresponds to the JSON property startTime

Returns:

  • (String)


1804
1805
1806
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1804

def start_time
  @start_time
end

#statusString

Output only. Status of the build. Corresponds to the JSON property status

Returns:

  • (String)


1809
1810
1811
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1809

def status
  @status
end

#status_detailString

Output only. Customer-readable message about the current status. Corresponds to the JSON property statusDetail

Returns:

  • (String)


1814
1815
1816
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1814

def status_detail
  @status_detail
end

#stepsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep>

Required. The operations to be performed on the workspace. Corresponds to the JSON property steps



1819
1820
1821
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1819

def steps
  @steps
end

#substitutionsHash<String,String>

Substitutions data for Build resource. Corresponds to the JSON property substitutions

Returns:

  • (Hash<String,String>)


1824
1825
1826
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1824

def substitutions
  @substitutions
end

#tagsArray<String>

Tags for annotation of a Build. These are not docker tags. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


1829
1830
1831
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1829

def tags
  @tags
end

#timeoutString

Amount of time that this build should be allowed to run, to second granularity. If this amount of time elapses, work on the build will cease and the build status will be TIMEOUT. timeout starts ticking from startTime. Default time is 60 minutes. Corresponds to the JSON property timeout

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1837

def timeout
  @timeout
end

#timingHash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan>

Output only. Stores timing information for phases of the build. Valid keys are:

  • BUILD: time to execute all build steps. * PUSH: time to push all artifacts including docker images and non docker artifacts. * FETCHSOURCE: time to fetch source. * SETUPBUILD: time to set up build. If the build does not specify source or images, these keys will not be included. Corresponds to the JSON property timing


1846
1847
1848
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1846

def timing
  @timing
end

#warningsArray<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildWarning>

Output only. Non-fatal problems encountered during the execution of the build. Corresponds to the JSON property warnings



1851
1852
1853
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1851

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1858

def update!(**args)
  @approval = args[:approval] if args.key?(:approval)
  @artifacts = args[:artifacts] if args.key?(:artifacts)
  @available_secrets = args[:available_secrets] if args.key?(:available_secrets)
  @build_trigger_id = args[:build_trigger_id] if args.key?(:build_trigger_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @failure_info = args[:failure_info] if args.key?(:failure_info)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @git_config = args[:git_config] if args.key?(:git_config)
  @id = args[:id] if args.key?(:id)
  @images = args[:images] if args.key?(:images)
  @log_url = args[:log_url] if args.key?(:log_url)
  @logs_bucket = args[:logs_bucket] if args.key?(:logs_bucket)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @project_id = args[:project_id] if args.key?(:project_id)
  @queue_ttl = args[:queue_ttl] if args.key?(:queue_ttl)
  @results = args[:results] if args.key?(:results)
  @secrets = args[:secrets] if args.key?(:secrets)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source = args[:source] if args.key?(:source)
  @source_provenance = args[:source_provenance] if args.key?(:source_provenance)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @steps = args[:steps] if args.key?(:steps)
  @substitutions = args[:substitutions] if args.key?(:substitutions)
  @tags = args[:tags] if args.key?(:tags)
  @timeout = args[:timeout] if args.key?(:timeout)
  @timing = args[:timing] if args.key?(:timing)
  @warnings = args[:warnings] if args.key?(:warnings)
end