Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Build
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Build
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A build resource in the Cloud Build API. At a high level, a Build describes
where to find source code, how to build it (for example, the builder image to
run on the source), and where to store the built artifacts. Fields can include
the following variables, which will be expanded when the build is created: - $
PROJECT_ID: the project ID of the build. - $PROJECT_NUMBER: the project number
of the build. - $LOCATION: the location/region of the build. - $BUILD_ID: the
autogenerated ID of the build. - $REPO_NAME: the source repository name
specified by RepoSource. - $BRANCH_NAME: the branch name specified by
RepoSource. - $TAG_NAME: the tag name specified by RepoSource. - $REVISION_ID
or $COMMIT_SHA: the commit SHA specified by RepoSource or resolved from the
specified branch or tag. - $SHORT_SHA: first 7 characters of $REVISION_ID or $
COMMIT_SHA.
Instance Attribute Summary collapse
-
#approval ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildApproval
BuildApproval describes a build's approval configuration, state, and result.
-
#artifacts ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
-
#available_secrets ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secrets
Secrets and secret environment variables.
-
#build_trigger_id ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#dependencies ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency>
Optional.
-
#failure_info ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
A fatal problem encountered during the execution of the build.
-
#finish_time ⇒ String
Output only.
-
#git_config ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfig
GitConfig is a configuration for git operations.
-
#id ⇒ String
Output only.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#log_url ⇒ String
Output only.
-
#logs_bucket ⇒ String
Cloud Storage bucket where logs should be written (see Bucket Name Requirements ).
-
#name ⇒ String
Output only.
-
#options ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
Optional arguments to enable specific features of builds.
-
#project_id ⇒ String
Output only.
-
#queue_ttl ⇒ String
TTL in queue for this build.
-
#results ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
Artifacts created by the build pipeline.
-
#secrets ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secret>
Secrets to decrypt using Cloud Key Management Service.
-
#service_account ⇒ String
IAM service account whose credentials will be used at build runtime.
-
#source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
Location of the source in a supported storage service.
-
#source_provenance ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
Provenance of the source.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#steps ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep>
Required.
-
#substitutions ⇒ Hash<String,String>
Substitutions data for
Buildresource. -
#tags ⇒ Array<String>
Tags for annotation of a
Build. -
#timeout ⇒ String
Amount of time that this build should be allowed to run, to second granularity.
-
#timing ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan>
Output only.
-
#warnings ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildWarning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Build
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Build.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Build
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Build.
1734 1735 1736 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildApproval
BuildApproval describes a build's approval configuration, state, and result.
Corresponds to the JSON property approval
1554 1555 1556 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1554 def approval @approval end |
#artifacts ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Artifacts
Artifacts produced by a build that should be uploaded upon successful
completion of all build steps.
Corresponds to the JSON property artifacts
1560 1561 1562 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1560 def artifacts @artifacts end |
#available_secrets ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secrets
Secrets and secret environment variables.
Corresponds to the JSON property availableSecrets
1565 1566 1567 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1565 def available_secrets @available_secrets end |
#build_trigger_id ⇒ String
Output only. The ID of the BuildTrigger that triggered this build, if it was
triggered automatically.
Corresponds to the JSON property buildTriggerId
1571 1572 1573 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1571 def build_trigger_id @build_trigger_id end |
#create_time ⇒ String
Output only. Time at which the request to create the build was received.
Corresponds to the JSON property createTime
1576 1577 1578 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1576 def create_time @create_time end |
#dependencies ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Dependency>
Optional. Dependencies that the Cloud Build worker will fetch before executing
user steps.
Corresponds to the JSON property dependencies
1582 1583 1584 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1582 def dependencies @dependencies end |
#failure_info ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo
A fatal problem encountered during the execution of the build.
Corresponds to the JSON property failureInfo
1587 1588 1589 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1587 def failure_info @failure_info end |
#finish_time ⇒ String
Output only. Time at which execution of the build was finished. The difference
between finish_time and start_time is the duration of the build's execution.
Corresponds to the JSON property finishTime
1593 1594 1595 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1593 def finish_time @finish_time end |
#git_config ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitConfig
GitConfig is a configuration for git operations.
Corresponds to the JSON property gitConfig
1598 1599 1600 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1598 def git_config @git_config end |
#id ⇒ String
Output only. Unique identifier of the build.
Corresponds to the JSON property id
1603 1604 1605 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1603 def id @id end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images are pushed using the builder service account's credentials.
The digests of the pushed images will be stored in the Build resource's
results field. If any of the images fail to be pushed, the build status is
marked FAILURE.
Corresponds to the JSON property images
1612 1613 1614 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1612 def images @images end |
#log_url ⇒ String
Output only. URL to logs for this build in Google Cloud Console.
Corresponds to the JSON property logUrl
1617 1618 1619 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1617 def log_url @log_url end |
#logs_bucket ⇒ String
Cloud Storage bucket where logs should be written (see Bucket Name
Requirements
). Logs file names will be of the format $logs_bucket/log-$build_id.txt.
Corresponds to the JSON property logsBucket
1624 1625 1626 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1624 def logs_bucket @logs_bucket end |
#name ⇒ String
Output only. The 'Build' name with format: projects/project/locations/
location/builds/build`, wherebuildis a unique identifier generated by
the service.
Corresponds to the JSON propertyname`
1631 1632 1633 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1631 def name @name end |
#options ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildOptions
Optional arguments to enable specific features of builds.
Corresponds to the JSON property options
1636 1637 1638 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1636 def @options end |
#project_id ⇒ String
Output only. ID of the project.
Corresponds to the JSON property projectId
1641 1642 1643 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1641 def project_id @project_id end |
#queue_ttl ⇒ String
TTL in queue for this build. If provided and the build is enqueued longer than
this value, the build will expire and the build status will be EXPIRED. The
TTL starts ticking from create_time.
Corresponds to the JSON property queueTtl
1648 1649 1650 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1648 def queue_ttl @queue_ttl end |
#results ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
Artifacts created by the build pipeline.
Corresponds to the JSON property results
1653 1654 1655 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1653 def results @results end |
#secrets ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Secret>
Secrets to decrypt using Cloud Key Management Service. Note: Secret Manager is
the recommended technique for managing sensitive data with Cloud Build. Use
available_secrets to configure builds to access secrets from Secret Manager.
For instructions, see: https://cloud.google.com/cloud-build/docs/securing-
builds/use-secrets
Corresponds to the JSON property secrets
1662 1663 1664 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1662 def secrets @secrets end |
#service_account ⇒ String
IAM service account whose credentials will be used at build runtime. Must be
of the format projects/PROJECT_ID/serviceAccounts/ACCOUNT`. ACCOUNT can
be email address or uniqueId of the service account.
Corresponds to the JSON propertyserviceAccount`
1669 1670 1671 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1669 def service_account @service_account end |
#source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
Location of the source in a supported storage service.
Corresponds to the JSON property source
1674 1675 1676 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1674 def source @source end |
#source_provenance ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1SourceProvenance
Provenance of the source. Ways to find the original source, or verify that
some source was used for this build.
Corresponds to the JSON property sourceProvenance
1680 1681 1682 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1680 def source_provenance @source_provenance end |
#start_time ⇒ String
Output only. Time at which execution of the build was started.
Corresponds to the JSON property startTime
1685 1686 1687 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1685 def start_time @start_time end |
#status ⇒ String
Output only. Status of the build.
Corresponds to the JSON property status
1690 1691 1692 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1690 def status @status end |
#status_detail ⇒ String
Output only. Customer-readable message about the current status.
Corresponds to the JSON property statusDetail
1695 1696 1697 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1695 def status_detail @status_detail end |
#steps ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep>
Required. The operations to be performed on the workspace.
Corresponds to the JSON property steps
1700 1701 1702 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1700 def steps @steps end |
#substitutions ⇒ Hash<String,String>
Substitutions data for Build resource.
Corresponds to the JSON property substitutions
1705 1706 1707 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1705 def substitutions @substitutions end |
#tags ⇒ Array<String>
Tags for annotation of a Build. These are not docker tags.
Corresponds to the JSON property tags
1710 1711 1712 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1710 def @tags end |
#timeout ⇒ String
Amount of time that this build should be allowed to run, to second granularity.
If this amount of time elapses, work on the build will cease and the build
status will be TIMEOUT. timeout starts ticking from startTime. Default
time is 60 minutes.
Corresponds to the JSON property timeout
1718 1719 1720 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1718 def timeout @timeout end |
#timing ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan>
Output only. Stores timing information for phases of the build. Valid keys are:
- BUILD: time to execute all build steps. * PUSH: time to push all artifacts
including docker images and non docker artifacts. * FETCHSOURCE: time to fetch
source. * SETUPBUILD: time to set up build. If the build does not specify
source or images, these keys will not be included.
Corresponds to the JSON property
timing
1727 1728 1729 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1727 def timing @timing end |
#warnings ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildWarning>
Output only. Non-fatal problems encountered during the execution of the build.
Corresponds to the JSON property warnings
1732 1733 1734 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1732 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1739 def update!(**args) @approval = args[:approval] if args.key?(:approval) @artifacts = args[:artifacts] if args.key?(:artifacts) @available_secrets = args[:available_secrets] if args.key?(:available_secrets) @build_trigger_id = args[:build_trigger_id] if args.key?(:build_trigger_id) @create_time = args[:create_time] if args.key?(:create_time) @dependencies = args[:dependencies] if args.key?(:dependencies) @failure_info = args[:failure_info] if args.key?(:failure_info) @finish_time = args[:finish_time] if args.key?(:finish_time) @git_config = args[:git_config] if args.key?(:git_config) @id = args[:id] if args.key?(:id) @images = args[:images] if args.key?(:images) @log_url = args[:log_url] if args.key?(:log_url) @logs_bucket = args[:logs_bucket] if args.key?(:logs_bucket) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @project_id = args[:project_id] if args.key?(:project_id) @queue_ttl = args[:queue_ttl] if args.key?(:queue_ttl) @results = args[:results] if args.key?(:results) @secrets = args[:secrets] if args.key?(:secrets) @service_account = args[:service_account] if args.key?(:service_account) @source = args[:source] if args.key?(:source) @source_provenance = args[:source_provenance] if args.key?(:source_provenance) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_detail = args[:status_detail] if args.key?(:status_detail) @steps = args[:steps] if args.key?(:steps) @substitutions = args[:substitutions] if args.key?(:substitutions) @tags = args[:tags] if args.key?(:tags) @timeout = args[:timeout] if args.key?(:timeout) @timing = args[:timing] if args.key?(:timing) @warnings = args[:warnings] if args.key?(:warnings) end |