Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildFailureInfo.



1820
1821
1822
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


1813
1814
1815
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1813

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


1818
1819
1820
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1818

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1825
1826
1827
1828
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1825

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end