Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A step in the build pipeline.
Instance Attribute Summary collapse
-
#allow_exit_codes ⇒ Array<Fixnum>
Allow this build step to fail without failing the entire build if and only if the exit code is one of the specified codes.
-
#allow_failure ⇒ Boolean
(also: #allow_failure?)
Allow this build step to fail without failing the entire build.
-
#args ⇒ Array<String>
A list of arguments that will be presented to the step when it is started.
-
#automap_substitutions ⇒ Boolean
(also: #automap_substitutions?)
Option to include built-in and custom substitutions as env variables for this build step.
-
#dir ⇒ String
Working directory to use when running this step's container.
-
#entrypoint ⇒ String
Entrypoint to be used instead of the build step image's default entrypoint.
-
#env ⇒ Array<String>
A list of environment variable definitions to be used when running a step.
-
#exit_code ⇒ Fixnum
Output only.
-
#id ⇒ String
Unique identifier for this build step, used in
wait_forto reference this build step as a dependency. -
#name ⇒ String
Required.
-
#pull_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#results ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StepResult>
Declaration of results for this build step.
-
#script ⇒ String
A shell script to be executed in the step.
-
#secret_env ⇒ Array<String>
A list of environment variables which are encrypted using a Cloud Key Management Service crypto key.
-
#status ⇒ String
Output only.
-
#timeout ⇒ String
Time limit for executing this build step.
-
#timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
List of volumes to mount into the build step.
-
#wait_for ⇒ Array<String>
The ID(s) of the step(s) that this build step depends on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStep.
2261 2262 2263 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_exit_codes ⇒ Array<Fixnum>
Allow this build step to fail without failing the entire build if and only if
the exit code is one of the specified codes. If allow_failure is also
specified, this field will take precedence.
Corresponds to the JSON property allowExitCodes
2125 2126 2127 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2125 def allow_exit_codes @allow_exit_codes end |
#allow_failure ⇒ Boolean Also known as: allow_failure?
Allow this build step to fail without failing the entire build. If false, the
entire build will fail if this step fails. Otherwise, the build will succeed,
but this step will still have a failure status. Error information will be
reported in the failure_detail field.
Corresponds to the JSON property allowFailure
2133 2134 2135 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2133 def allow_failure @allow_failure end |
#args ⇒ Array<String>
A list of arguments that will be presented to the step when it is started. If
the image used to run the step's container has an entrypoint, the args are
used as arguments to that entrypoint. If the image does not define an
entrypoint, the first element in args is used as the entrypoint, and the
remainder will be used as arguments.
Corresponds to the JSON property args
2143 2144 2145 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2143 def args @args end |
#automap_substitutions ⇒ Boolean Also known as: automap_substitutions?
Option to include built-in and custom substitutions as env variables for this
build step. This option will override the global option in BuildOption.
Corresponds to the JSON property automapSubstitutions
2149 2150 2151 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2149 def automap_substitutions @automap_substitutions end |
#dir ⇒ String
Working directory to use when running this step's container. If this value is
a relative path, it is relative to the build's working directory. If this
value is absolute, it may be outside the build's working directory, in which
case the contents of the path may not be persisted across build step
executions, unless a volume for that path is specified. If the build
specifies a RepoSource with dir and a step with a dir, which specifies
an absolute path, the RepoSource dir is ignored for the step's execution.
Corresponds to the JSON property dir
2161 2162 2163 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2161 def dir @dir end |
#entrypoint ⇒ String
Entrypoint to be used instead of the build step image's default entrypoint. If
unset, the image's default entrypoint is used.
Corresponds to the JSON property entrypoint
2167 2168 2169 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2167 def entrypoint @entrypoint end |
#env ⇒ Array<String>
A list of environment variable definitions to be used when running a step. The
elements are of the form "KEY=VALUE" for the environment variable "KEY" being
given the value "VALUE".
Corresponds to the JSON property env
2174 2175 2176 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2174 def env @env end |
#exit_code ⇒ Fixnum
Output only. Return code from running the step.
Corresponds to the JSON property exitCode
2179 2180 2181 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2179 def exit_code @exit_code end |
#id ⇒ String
Unique identifier for this build step, used in wait_for to reference this
build step as a dependency.
Corresponds to the JSON property id
2185 2186 2187 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2185 def id @id end |
#name ⇒ String
Required. The name of the container image that will run this particular build
step. If the image is available in the host's Docker daemon's cache, it will
be run directly. If not, the host will attempt to pull the image first, using
the builder service account's credentials if necessary. The Docker daemon's
cache will already have the latest versions of all of the officially supported
build steps (https://github.com/GoogleCloudPlatform/cloud-builders). The Docker daemon will also
have cached many of the layers for some popular images, like "ubuntu", "debian"
, but they will be refreshed at the time you attempt to use them. If you built
an image in a previous build step, it will be stored in the host's Docker
daemon's cache and is available to use as the name for a later build step.
Corresponds to the JSON property name
2200 2201 2202 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2200 def name @name end |
#pull_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pullTiming
2205 2206 2207 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2205 def pull_timing @pull_timing end |
#results ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StepResult>
Declaration of results for this build step.
Corresponds to the JSON property results
2210 2211 2212 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2210 def results @results end |
#script ⇒ String
A shell script to be executed in the step. When script is provided, the user
cannot specify the entrypoint or args.
Corresponds to the JSON property script
2216 2217 2218 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2216 def script @script end |
#secret_env ⇒ Array<String>
A list of environment variables which are encrypted using a Cloud Key
Management Service crypto key. These values must be specified in the build's
Secret.
Corresponds to the JSON property secretEnv
2223 2224 2225 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2223 def secret_env @secret_env end |
#status ⇒ String
Output only. Status of the build step. At this time, build step status is only
updated on build completion; step status is not updated in real-time as the
build progresses.
Corresponds to the JSON property status
2230 2231 2232 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2230 def status @status end |
#timeout ⇒ String
Time limit for executing this build step. If not defined, the step has no time
limit and will be allowed to continue to run until either it completes or the
build itself times out.
Corresponds to the JSON property timeout
2237 2238 2239 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2237 def timeout @timeout end |
#timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property timing
2242 2243 2244 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2242 def timing @timing end |
#volumes ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Volume>
List of volumes to mount into the build step. Each volume is created as an
empty volume prior to execution of the build step. Upon completion of the
build, volumes and their contents are discarded. Using a named volume in only
one step is not valid as it is indicative of a build request with an incorrect
configuration.
Corresponds to the JSON property volumes
2251 2252 2253 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2251 def volumes @volumes end |
#wait_for ⇒ Array<String>
The ID(s) of the step(s) that this build step depends on. This build step will
not start until all the build steps in wait_for have completed successfully.
If wait_for is empty, this build step will start when all previous build
steps in the Build.Steps list have completed successfully.
Corresponds to the JSON property waitFor
2259 2260 2261 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2259 def wait_for @wait_for end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2266 def update!(**args) @allow_exit_codes = args[:allow_exit_codes] if args.key?(:allow_exit_codes) @allow_failure = args[:allow_failure] if args.key?(:allow_failure) @args = args[:args] if args.key?(:args) @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions) @dir = args[:dir] if args.key?(:dir) @entrypoint = args[:entrypoint] if args.key?(:entrypoint) @env = args[:env] if args.key?(:env) @exit_code = args[:exit_code] if args.key?(:exit_code) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @pull_timing = args[:pull_timing] if args.key?(:pull_timing) @results = args[:results] if args.key?(:results) @script = args[:script] if args.key?(:script) @secret_env = args[:secret_env] if args.key?(:secret_env) @status = args[:status] if args.key?(:status) @timeout = args[:timeout] if args.key?(:timeout) @timing = args[:timing] if args.key?(:timing) @volumes = args[:volumes] if args.key?(:volumes) @wait_for = args[:wait_for] if args.key?(:wait_for) end |