Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceDependency.



2319
2320
2321
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2296
2297
2298
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2296

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2301
2302
2303
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2301

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2306
2307
2308
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2306

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DependencyGitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2312
2313
2314
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2312

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2317

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2324
2325
2326
2327
2328
2329
2330
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2324

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end