Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Location of the source in a Google Cloud Source Repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource.



2603
2604
2605
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branch_nameString

Regex matching branches to build. The syntax of the regular expressions accepted is the syntax accepted by RE2 and described at https://github.com/ google/re2/wiki/Syntax Corresponds to the JSON property branchName

Returns:

  • (String)


2558
2559
2560
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2558

def branch_name
  @branch_name
end

#commit_shaString

Explicit commit SHA to build. Corresponds to the JSON property commitSha

Returns:

  • (String)


2563
2564
2565
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2563

def commit_sha
  @commit_sha
end

#dirString

Optional. Directory, relative to the source root, in which to run the build. This must be a relative path. If a step's dir is specified and is an absolute path, this value is ignored for that step's execution. Corresponds to the JSON property dir

Returns:

  • (String)


2570
2571
2572
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2570

def dir
  @dir
end

#invert_regexBoolean Also known as: invert_regex?

Optional. Only trigger a build if the revision regex does NOT match the revision regex. Corresponds to the JSON property invertRegex

Returns:

  • (Boolean)


2576
2577
2578
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2576

def invert_regex
  @invert_regex
end

#project_idString

Optional. ID of the project that owns the Cloud Source Repository. If omitted, the project ID requesting the build is assumed. Corresponds to the JSON property projectId

Returns:

  • (String)


2583
2584
2585
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2583

def project_id
  @project_id
end

#repo_nameString

Required. Name of the Cloud Source Repository. Corresponds to the JSON property repoName

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2588

def repo_name
  @repo_name
end

#substitutionsHash<String,String>

Optional. Substitutions to use in a triggered build. Should only be used with RunBuildTrigger Corresponds to the JSON property substitutions

Returns:

  • (Hash<String,String>)


2594
2595
2596
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2594

def substitutions
  @substitutions
end

#tag_nameString

Regex matching tags to build. The syntax of the regular expressions accepted is the syntax accepted by RE2 and described at https://github.com/google/re2/ wiki/Syntax Corresponds to the JSON property tagName

Returns:

  • (String)


2601
2602
2603
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2601

def tag_name
  @tag_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2608

def update!(**args)
  @branch_name = args[:branch_name] if args.key?(:branch_name)
  @commit_sha = args[:commit_sha] if args.key?(:commit_sha)
  @dir = args[:dir] if args.key?(:dir)
  @invert_regex = args[:invert_regex] if args.key?(:invert_regex)
  @project_id = args[:project_id] if args.key?(:project_id)
  @repo_name = args[:repo_name] if args.key?(:repo_name)
  @substitutions = args[:substitutions] if args.key?(:substitutions)
  @tag_name = args[:tag_name] if args.key?(:tag_name)
end