Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Results
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#build_step_results ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps.
-
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Results
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Results.
2923 2924 2925 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
2859 2860 2861 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2859 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
2864 2865 2866 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2864 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
2869 2870 2871 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2869 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
2878 2879 2880 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2878 def build_step_outputs @build_step_outputs end |
#build_step_results ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps. step_id ->
Corresponds to the JSON property buildStepResults
2883 2884 2885 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2883 def build_step_results @build_step_results end |
#generic_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
2889 2890 2891 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2889 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
2895 2896 2897 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2895 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
2900 2901 2902 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2900 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
2905 2906 2907 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2905 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
2910 2911 2912 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2910 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
2916 2917 2918 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2916 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
2921 2922 2923 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2921 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2928 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @build_step_results = args[:build_step_results] if args.key?(:build_step_results) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |