Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Location of the source in a supported storage service.
Instance Attribute Summary collapse
-
#connected_repository ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#developer_connect_config ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
-
#git_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
-
#repo_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
-
#storage_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
-
#storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Source
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1Source
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1Source.
3022 3023 3024 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_repository ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property connectedRepository
2993 2994 2995 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2993 def connected_repository @connected_repository end |
#developer_connect_config ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
Corresponds to the JSON property developerConnectConfig
2998 2999 3000 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 2998 def developer_connect_config @developer_connect_config end |
#git_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property gitSource
3003 3004 3005 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3003 def git_source @git_source end |
#repo_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property repoSource
3008 3009 3010 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3008 def repo_source @repo_source end |
#storage_source ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property storageSource
3013 3014 3015 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3013 def storage_source @storage_source end |
#storage_source_manifest ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property storageSourceManifest
3020 3021 3022 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3020 def storage_source_manifest @storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3027 3028 3029 3030 3031 3032 3033 3034 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3027 def update!(**args) @connected_repository = args[:connected_repository] if args.key?(:connected_repository) @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config) @git_source = args[:git_source] if args.key?(:git_source) @repo_source = args[:repo_source] if args.key?(:repo_source) @storage_source = args[:storage_source] if args.key?(:storage_source) @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest) end |