Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.
Instance Attribute Summary collapse
-
#artifact_fingerprint ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only.
-
#push_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
constructor
A new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact
Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGenericArtifact.
3254 3255 3256 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_fingerprint ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property artifactFingerprint
3231 3232 3233 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3231 def artifact_fingerprint @artifact_fingerprint end |
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3236 3237 3238 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3236 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes>
Output only. The file hashes that make up the generic artifact.
Corresponds to the JSON property fileHashes
3241 3242 3243 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3241 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3246 3247 3248 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3246 def push_timing @push_timing end |
#uri ⇒ String
Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/
repositories/r1/packages/p1/versions/v1
Corresponds to the JSON property uri
3252 3253 3254 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3252 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3259 3260 3261 3262 3263 3264 3265 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3259 def update!(**args) @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |