Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A Go module artifact uploaded to Artifact Registry using the GoModule directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedGoModule.



3294
3295
3296
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3276

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3282
3283
3284
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3282

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3287
3288
3289
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3287

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3292
3293
3294
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3292

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3299
3300
3301
3302
3303
3304
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3299

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end