Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedNpmPackage.



3097
3098
3099
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3079

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3085
3086
3087
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3085

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3090
3091
3092
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3090

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


3095
3096
3097
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3095

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3102
3103
3104
3105
3106
3107
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3102

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end