Class: Google::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage

Returns a new instance of ContaineranalysisGoogleDevtoolsCloudbuildV1UploadedPythonPackage.



3462
3463
3464
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3444
3445
3446
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3444

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3450
3451
3452
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3450

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::ContaineranalysisV1beta1::ContaineranalysisGoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3455
3456
3457
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3455

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3460
3461
3462
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3460

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3467
3468
3469
3470
3471
3472
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3467

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end