Class: Google::Apis::ContaineranalysisV1beta1::CvsSv3
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::CvsSv3
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Deprecated. Common Vulnerability Scoring System version 3. For details, see https://www.first.org/cvss/specification-document
Instance Attribute Summary collapse
-
#attack_complexity ⇒ String
Corresponds to the JSON property
attackComplexity. -
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments.
-
#availability_impact ⇒ String
Corresponds to the JSON property
availabilityImpact. -
#base_score ⇒ Float
The base score is a function of the base metric scores.
-
#confidentiality_impact ⇒ String
Corresponds to the JSON property
confidentialityImpact. -
#exploitability_score ⇒ Float
Corresponds to the JSON property
exploitabilityScore. -
#impact_score ⇒ Float
Corresponds to the JSON property
impactScore. -
#integrity_impact ⇒ String
Corresponds to the JSON property
integrityImpact. -
#privileges_required ⇒ String
Corresponds to the JSON property
privilegesRequired. -
#scope ⇒ String
Corresponds to the JSON property
scope. -
#user_interaction ⇒ String
Corresponds to the JSON property
userInteraction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CvsSv3
constructor
A new instance of CvsSv3.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CvsSv3
Returns a new instance of CvsSv3.
1123 1124 1125 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attack_complexity ⇒ String
Corresponds to the JSON property attackComplexity
1070 1071 1072 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1070 def attack_complexity @attack_complexity end |
#attack_vector ⇒ String
Base Metrics Represents the intrinsic characteristics of a vulnerability that
are constant over time and across user environments.
Corresponds to the JSON property attackVector
1076 1077 1078 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1076 def attack_vector @attack_vector end |
#availability_impact ⇒ String
Corresponds to the JSON property availabilityImpact
1081 1082 1083 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1081 def availability_impact @availability_impact end |
#base_score ⇒ Float
The base score is a function of the base metric scores.
Corresponds to the JSON property baseScore
1086 1087 1088 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1086 def base_score @base_score end |
#confidentiality_impact ⇒ String
Corresponds to the JSON property confidentialityImpact
1091 1092 1093 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1091 def confidentiality_impact @confidentiality_impact end |
#exploitability_score ⇒ Float
Corresponds to the JSON property exploitabilityScore
1096 1097 1098 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1096 def exploitability_score @exploitability_score end |
#impact_score ⇒ Float
Corresponds to the JSON property impactScore
1101 1102 1103 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1101 def impact_score @impact_score end |
#integrity_impact ⇒ String
Corresponds to the JSON property integrityImpact
1106 1107 1108 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1106 def integrity_impact @integrity_impact end |
#privileges_required ⇒ String
Corresponds to the JSON property privilegesRequired
1111 1112 1113 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1111 def privileges_required @privileges_required end |
#scope ⇒ String
Corresponds to the JSON property scope
1116 1117 1118 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1116 def scope @scope end |
#user_interaction ⇒ String
Corresponds to the JSON property userInteraction
1121 1122 1123 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1121 def user_interaction @user_interaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 1128 def update!(**args) @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity) @attack_vector = args[:attack_vector] if args.key?(:attack_vector) @availability_impact = args[:availability_impact] if args.key?(:availability_impact) @base_score = args[:base_score] if args.key?(:base_score) @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact) @exploitability_score = args[:exploitability_score] if args.key?(:exploitability_score) @impact_score = args[:impact_score] if args.key?(:impact_score) @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact) @privileges_required = args[:privileges_required] if args.key?(:privileges_required) @scope = args[:scope] if args.key?(:scope) @user_interaction = args[:user_interaction] if args.key?(:user_interaction) end |