Class: Google::Apis::ContaineranalysisV1beta1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
The period during which some deployable was active in a runtime.
Instance Attribute Summary collapse
-
#address ⇒ String
Address of the runtime element hosting this deployment.
-
#config ⇒ String
Configuration used to create this deployment.
-
#deploy_time ⇒ String
Required.
-
#platform ⇒ String
Platform hosting this deployment.
-
#resource_uri ⇒ Array<String>
Output only.
-
#undeploy_time ⇒ String
End of the lifetime of this deployment.
-
#user_email ⇒ String
Identity of the user that triggered this deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
3237 3238 3239 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address of the runtime element hosting this deployment.
Corresponds to the JSON property address
3204 3205 3206 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3204 def address @address end |
#config ⇒ String
Configuration used to create this deployment.
Corresponds to the JSON property config
3209 3210 3211 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3209 def config @config end |
#deploy_time ⇒ String
Required. Beginning of the lifetime of this deployment.
Corresponds to the JSON property deployTime
3214 3215 3216 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3214 def deploy_time @deploy_time end |
#platform ⇒ String
Platform hosting this deployment.
Corresponds to the JSON property platform
3219 3220 3221 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3219 def platform @platform end |
#resource_uri ⇒ Array<String>
Output only. Resource URI for the artifact being deployed taken from the
deployable field with the same name.
Corresponds to the JSON property resourceUri
3225 3226 3227 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3225 def resource_uri @resource_uri end |
#undeploy_time ⇒ String
End of the lifetime of this deployment.
Corresponds to the JSON property undeployTime
3230 3231 3232 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3230 def undeploy_time @undeploy_time end |
#user_email ⇒ String
Identity of the user that triggered this deployment.
Corresponds to the JSON property userEmail
3235 3236 3237 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3235 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3242 3243 3244 3245 3246 3247 3248 3249 3250 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3242 def update!(**args) @address = args[:address] if args.key?(:address) @config = args[:config] if args.key?(:config) @deploy_time = args[:deploy_time] if args.key?(:deploy_time) @platform = args[:platform] if args.key?(:platform) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @undeploy_time = args[:undeploy_time] if args.key?(:undeploy_time) @user_email = args[:user_email] if args.key?(:user_email) end |