Class: Google::Apis::ContaineranalysisV1beta1::Detail

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Identifies all appearances of this vulnerability in the package for a specific distro/location. For example: glibc in cpe:/o:debian:debian_linux:8 for versions 2.1 - 2.2

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Detail

Returns a new instance of Detail.



3688
3689
3690
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

Required. The CPE URI in cpe format in which the vulnerability manifests. Examples include distro or storage location for vulnerable jar. Corresponds to the JSON property cpeUri

Returns:

  • (String)


3626
3627
3628
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3626

def cpe_uri
  @cpe_uri
end

#descriptionString

A vendor-specific description of this note. Corresponds to the JSON property description

Returns:

  • (String)


3631
3632
3633
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3631

def description
  @description
end

#fixed_locationGoogle::Apis::ContaineranalysisV1beta1::VulnerabilityLocation

The location of the vulnerability. Corresponds to the JSON property fixedLocation



3636
3637
3638
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3636

def fixed_location
  @fixed_location
end

#is_obsoleteBoolean Also known as: is_obsolete?

Whether this detail is obsolete. Occurrences are expected not to point to obsolete details. Corresponds to the JSON property isObsolete

Returns:

  • (Boolean)


3642
3643
3644
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3642

def is_obsolete
  @is_obsolete
end

#max_affected_versionGoogle::Apis::ContaineranalysisV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property maxAffectedVersion



3648
3649
3650
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3648

def max_affected_version
  @max_affected_version
end

#min_affected_versionGoogle::Apis::ContaineranalysisV1beta1::Version

Version contains structured information about the version of a package. Corresponds to the JSON property minAffectedVersion



3653
3654
3655
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3653

def min_affected_version
  @min_affected_version
end

#packageString

Required. The name of the package where the vulnerability was found. Corresponds to the JSON property package

Returns:

  • (String)


3658
3659
3660
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3658

def package
  @package
end

#package_typeString

The type of package; whether native or non native(ruby gems, node.js packages etc). Corresponds to the JSON property packageType

Returns:

  • (String)


3664
3665
3666
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3664

def package_type
  @package_type
end

#severity_nameString

The severity (eg: distro assigned severity) for this vulnerability. Corresponds to the JSON property severityName

Returns:

  • (String)


3669
3670
3671
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3669

def severity_name
  @severity_name
end

#sourceString

The source from which the information in this Detail was obtained. Corresponds to the JSON property source

Returns:

  • (String)


3674
3675
3676
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3674

def source
  @source
end

#source_update_timeString

The time this information was last changed at the source. This is an upstream timestamp from the underlying information source - e.g. Ubuntu security tracker. Corresponds to the JSON property sourceUpdateTime

Returns:

  • (String)


3681
3682
3683
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3681

def source_update_time
  @source_update_time
end

#vendorString

The name of the vendor of the product. Corresponds to the JSON property vendor

Returns:

  • (String)


3686
3687
3688
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3686

def vendor
  @vendor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3693

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @description = args[:description] if args.key?(:description)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @is_obsolete = args[:is_obsolete] if args.key?(:is_obsolete)
  @max_affected_version = args[:max_affected_version] if args.key?(:max_affected_version)
  @min_affected_version = args[:min_affected_version] if args.key?(:min_affected_version)
  @package = args[:package] if args.key?(:package)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
  @source = args[:source] if args.key?(:source)
  @source_update_time = args[:source_update_time] if args.key?(:source_update_time)
  @vendor = args[:vendor] if args.key?(:vendor)
end