Class: Google::Apis::ContaineranalysisV1beta1::Detail
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Detail
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Identifies all appearances of this vulnerability in the package for a specific distro/location. For example: glibc in cpe:/o:debian:debian_linux:8 for versions 2.1 - 2.2
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
Required.
-
#description ⇒ String
A vendor-specific description of this note.
-
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
-
#is_obsolete ⇒ Boolean
(also: #is_obsolete?)
Whether this detail is obsolete.
-
#max_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
-
#min_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
-
#package ⇒ String
Required.
-
#package_type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages etc).
-
#severity_name ⇒ String
The severity (eg: distro assigned severity) for this vulnerability.
-
#source ⇒ String
The source from which the information in this Detail was obtained.
-
#source_update_time ⇒ String
The time this information was last changed at the source.
-
#vendor ⇒ String
The name of the vendor of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Detail
constructor
A new instance of Detail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Detail
Returns a new instance of Detail.
3646 3647 3648 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
Required. The CPE URI in cpe format in
which the vulnerability manifests. Examples include distro or storage location
for vulnerable jar.
Corresponds to the JSON property cpeUri
3584 3585 3586 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3584 def cpe_uri @cpe_uri end |
#description ⇒ String
A vendor-specific description of this note.
Corresponds to the JSON property description
3589 3590 3591 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3589 def description @description end |
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
Corresponds to the JSON property fixedLocation
3594 3595 3596 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3594 def fixed_location @fixed_location end |
#is_obsolete ⇒ Boolean Also known as: is_obsolete?
Whether this detail is obsolete. Occurrences are expected not to point to
obsolete details.
Corresponds to the JSON property isObsolete
3600 3601 3602 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3600 def is_obsolete @is_obsolete end |
#max_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property maxAffectedVersion
3606 3607 3608 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3606 def max_affected_version @max_affected_version end |
#min_affected_version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property minAffectedVersion
3611 3612 3613 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3611 def min_affected_version @min_affected_version end |
#package ⇒ String
Required. The name of the package where the vulnerability was found.
Corresponds to the JSON property package
3616 3617 3618 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3616 def package @package end |
#package_type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages
etc).
Corresponds to the JSON property packageType
3622 3623 3624 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3622 def package_type @package_type end |
#severity_name ⇒ String
The severity (eg: distro assigned severity) for this vulnerability.
Corresponds to the JSON property severityName
3627 3628 3629 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3627 def severity_name @severity_name end |
#source ⇒ String
The source from which the information in this Detail was obtained.
Corresponds to the JSON property source
3632 3633 3634 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3632 def source @source end |
#source_update_time ⇒ String
The time this information was last changed at the source. This is an upstream
timestamp from the underlying information source - e.g. Ubuntu security
tracker.
Corresponds to the JSON property sourceUpdateTime
3639 3640 3641 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3639 def source_update_time @source_update_time end |
#vendor ⇒ String
The name of the vendor of the product.
Corresponds to the JSON property vendor
3644 3645 3646 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3644 def vendor @vendor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3651 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @description = args[:description] if args.key?(:description) @fixed_location = args[:fixed_location] if args.key?(:fixed_location) @is_obsolete = args[:is_obsolete] if args.key?(:is_obsolete) @max_affected_version = args[:max_affected_version] if args.key?(:max_affected_version) @min_affected_version = args[:min_affected_version] if args.key?(:min_affected_version) @package = args[:package] if args.key?(:package) @package_type = args[:package_type] if args.key?(:package_type) @severity_name = args[:severity_name] if args.key?(:severity_name) @source = args[:source] if args.key?(:source) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @vendor = args[:vendor] if args.key?(:vendor) end |