Class: Google::Apis::ContaineranalysisV1beta1::Details
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Details
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Details of an attestation occurrence.
Instance Attribute Summary collapse
-
#attestation ⇒ Google::Apis::ContaineranalysisV1beta1::Attestation
Occurrence that represents a single "attestation".
Instance Method Summary collapse
-
#initialize(**args) ⇒ Details
constructor
A new instance of Details.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Details
Returns a new instance of Details.
3730 3731 3732 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attestation ⇒ Google::Apis::ContaineranalysisV1beta1::Attestation
Occurrence that represents a single "attestation". The authenticity of an
attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the authority to which
this attestation is attached is primarily useful for look-up (how to find this
attestation if you already know the authority and artifact to be verified) and
intent (which authority was this attestation intended to sign for).
Corresponds to the JSON property attestation
3728 3729 3730 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3728 def attestation @attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3735 3736 3737 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3735 def update!(**args) @attestation = args[:attestation] if args.key?(:attestation) end |