Class: Google::Apis::ContaineranalysisV1beta1::Details

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Details of an attestation occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Details

Returns a new instance of Details.



3403
3404
3405
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestationGoogle::Apis::ContaineranalysisV1beta1::Attestation

Occurrence that represents a single "attestation". The authenticity of an attestation can be verified using the attached signature. If the verifier trusts the public key of the signer, then verifying the signature is sufficient to establish trust. In this circumstance, the authority to which this attestation is attached is primarily useful for look-up (how to find this attestation if you already know the authority and artifact to be verified) and intent (which authority was this attestation intended to sign for). Corresponds to the JSON property attestation



3401
3402
3403
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3401

def attestation
  @attestation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3408
3409
3410
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3408

def update!(**args)
  @attestation = args[:attestation] if args.key?(:attestation)
end