Class: Google::Apis::ContaineranalysisV1beta1::Discovered

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Provides information about the analysis status of a discovered resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Discovered

Returns a new instance of Discovered.



3822
3823
3824
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_completedGoogle::Apis::ContaineranalysisV1beta1::AnalysisCompleted

Indicates which analysis completed successfully. Multiple types of analysis can be performed on a single resource. Corresponds to the JSON property analysisCompleted



3768
3769
3770
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3768

def analysis_completed
  @analysis_completed
end

#analysis_errorArray<Google::Apis::ContaineranalysisV1beta1::Status>

Indicates any errors encountered during analysis of a resource. There could be 0 or more of these errors. Corresponds to the JSON property analysisError



3774
3775
3776
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3774

def analysis_error
  @analysis_error
end

#analysis_statusString

The status of discovery for the resource. Corresponds to the JSON property analysisStatus

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3779

def analysis_status
  @analysis_status
end

#analysis_status_errorGoogle::Apis::ContaineranalysisV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property analysisStatusError



3789
3790
3791
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3789

def analysis_status_error
  @analysis_status_error
end

#continuous_analysisString

Whether the resource is continuously analyzed. Corresponds to the JSON property continuousAnalysis

Returns:

  • (String)


3794
3795
3796
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3794

def continuous_analysis
  @continuous_analysis
end

#filesArray<Google::Apis::ContaineranalysisV1beta1::File>

Files that make up the resource described by the occurrence. Corresponds to the JSON property files



3799
3800
3801
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3799

def files
  @files
end

#last_analysis_timeString

The last time continuous analysis was done for this resource. Deprecated, do not use. Corresponds to the JSON property lastAnalysisTime

Returns:

  • (String)


3805
3806
3807
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3805

def last_analysis_time
  @last_analysis_time
end

#last_scan_timeString

The last time this resource was scanned. Corresponds to the JSON property lastScanTime

Returns:

  • (String)


3810
3811
3812
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3810

def last_scan_time
  @last_scan_time
end

#last_vulnerability_update_timeString

The last time vulnerability scan results changed. Corresponds to the JSON property lastVulnerabilityUpdateTime

Returns:

  • (String)


3815
3816
3817
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3815

def last_vulnerability_update_time
  @last_vulnerability_update_time
end

#sbom_statusGoogle::Apis::ContaineranalysisV1beta1::SbomStatus

The status of an SBOM generation. Corresponds to the JSON property sbomStatus



3820
3821
3822
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3820

def sbom_status
  @sbom_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3827

def update!(**args)
  @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed)
  @analysis_error = args[:analysis_error] if args.key?(:analysis_error)
  @analysis_status = args[:analysis_status] if args.key?(:analysis_status)
  @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error)
  @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis)
  @files = args[:files] if args.key?(:files)
  @last_analysis_time = args[:last_analysis_time] if args.key?(:last_analysis_time)
  @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time)
  @last_vulnerability_update_time = args[:last_vulnerability_update_time] if args.key?(:last_vulnerability_update_time)
  @sbom_status = args[:sbom_status] if args.key?(:sbom_status)
end