Class: Google::Apis::ContaineranalysisV1beta1::Discovered
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Discovered
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Provides information about the analysis status of a discovered resource.
Instance Attribute Summary collapse
-
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1beta1::AnalysisCompleted
Indicates which analysis completed successfully.
-
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Status>
Indicates any errors encountered during analysis of a resource.
-
#analysis_status ⇒ String
The status of discovery for the resource.
-
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
-
#files ⇒ Array<Google::Apis::ContaineranalysisV1beta1::File>
Files that make up the resource described by the occurrence.
-
#last_analysis_time ⇒ String
The last time continuous analysis was done for this resource.
-
#last_scan_time ⇒ String
The last time this resource was scanned.
-
#sbom_status ⇒ Google::Apis::ContaineranalysisV1beta1::SbomStatus
The status of an SBOM generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Discovered
constructor
A new instance of Discovered.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Discovered
Returns a new instance of Discovered.
3496 3497 3498 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_completed ⇒ Google::Apis::ContaineranalysisV1beta1::AnalysisCompleted
Indicates which analysis completed successfully. Multiple types of analysis
can be performed on a single resource.
Corresponds to the JSON property analysisCompleted
3447 3448 3449 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3447 def analysis_completed @analysis_completed end |
#analysis_error ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Status>
Indicates any errors encountered during analysis of a resource. There could be
0 or more of these errors.
Corresponds to the JSON property analysisError
3453 3454 3455 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3453 def analysis_error @analysis_error end |
#analysis_status ⇒ String
The status of discovery for the resource.
Corresponds to the JSON property analysisStatus
3458 3459 3460 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3458 def analysis_status @analysis_status end |
#analysis_status_error ⇒ Google::Apis::ContaineranalysisV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property analysisStatusError
3468 3469 3470 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3468 def analysis_status_error @analysis_status_error end |
#continuous_analysis ⇒ String
Whether the resource is continuously analyzed.
Corresponds to the JSON property continuousAnalysis
3473 3474 3475 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3473 def continuous_analysis @continuous_analysis end |
#files ⇒ Array<Google::Apis::ContaineranalysisV1beta1::File>
Files that make up the resource described by the occurrence.
Corresponds to the JSON property files
3478 3479 3480 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3478 def files @files end |
#last_analysis_time ⇒ String
The last time continuous analysis was done for this resource. Deprecated, do
not use.
Corresponds to the JSON property lastAnalysisTime
3484 3485 3486 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3484 def last_analysis_time @last_analysis_time end |
#last_scan_time ⇒ String
The last time this resource was scanned.
Corresponds to the JSON property lastScanTime
3489 3490 3491 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3489 def last_scan_time @last_scan_time end |
#sbom_status ⇒ Google::Apis::ContaineranalysisV1beta1::SbomStatus
The status of an SBOM generation.
Corresponds to the JSON property sbomStatus
3494 3495 3496 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3494 def sbom_status @sbom_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3501 def update!(**args) @analysis_completed = args[:analysis_completed] if args.key?(:analysis_completed) @analysis_error = args[:analysis_error] if args.key?(:analysis_error) @analysis_status = args[:analysis_status] if args.key?(:analysis_status) @analysis_status_error = args[:analysis_status_error] if args.key?(:analysis_status_error) @continuous_analysis = args[:continuous_analysis] if args.key?(:continuous_analysis) @files = args[:files] if args.key?(:files) @last_analysis_time = args[:last_analysis_time] if args.key?(:last_analysis_time) @last_scan_time = args[:last_scan_time] if args.key?(:last_scan_time) @sbom_status = args[:sbom_status] if args.key?(:sbom_status) end |