Class: Google::Apis::ContaineranalysisV1beta1::DocumentOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::DocumentOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/
Instance Attribute Summary collapse
-
#create_time ⇒ String
Identify when the SPDX file was originally created.
-
#creator_comment ⇒ String
A field for creators of the SPDX file to provide general comments about the creation of the SPDX file or any other relevant comment not included in the other fields Corresponds to the JSON property
creatorComment. -
#creators ⇒ Array<String>
Identify who (or what, in the case of a tool) created the SPDX file.
-
#document_comment ⇒ String
A field for creators of the SPDX file content to provide comments to the consumers of the SPDX document Corresponds to the JSON property
documentComment. -
#external_document_refs ⇒ Array<String>
Identify any external SPDX documents referenced within this SPDX document Corresponds to the JSON property
externalDocumentRefs. -
#id ⇒ String
Identify the current SPDX document which may be referenced in relationships by other files, packages internally and documents externally Corresponds to the JSON property
id. -
#license_list_version ⇒ String
A field for creators of the SPDX file to provide the version of the SPDX License List used when the SPDX file was created Corresponds to the JSON property
licenseListVersion. -
#namespace ⇒ String
Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘ #’ delimiter Corresponds to the JSON property
namespace. -
#title ⇒ String
Identify name of this document as designated by creator Corresponds to the JSON property
title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DocumentOccurrence
constructor
A new instance of DocumentOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DocumentOccurrence
Returns a new instance of DocumentOccurrence.
4002 4003 4004 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Identify when the SPDX file was originally created. The date is to be
specified according to combined date and time in UTC format as specified in
ISO 8601 standard
Corresponds to the JSON property createTime
3952 3953 3954 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3952 def create_time @create_time end |
#creator_comment ⇒ String
A field for creators of the SPDX file to provide general comments about the
creation of the SPDX file or any other relevant comment not included in the
other fields
Corresponds to the JSON property creatorComment
3959 3960 3961 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3959 def creator_comment @creator_comment end |
#creators ⇒ Array<String>
Identify who (or what, in the case of a tool) created the SPDX file. If the
SPDX file was created by an individual, indicate the person's name
Corresponds to the JSON property creators
3965 3966 3967 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3965 def creators @creators end |
#document_comment ⇒ String
A field for creators of the SPDX file content to provide comments to the
consumers of the SPDX document
Corresponds to the JSON property documentComment
3971 3972 3973 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3971 def document_comment @document_comment end |
#external_document_refs ⇒ Array<String>
Identify any external SPDX documents referenced within this SPDX document
Corresponds to the JSON property externalDocumentRefs
3976 3977 3978 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3976 def external_document_refs @external_document_refs end |
#id ⇒ String
Identify the current SPDX document which may be referenced in relationships by
other files, packages internally and documents externally
Corresponds to the JSON property id
3982 3983 3984 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3982 def id @id end |
#license_list_version ⇒ String
A field for creators of the SPDX file to provide the version of the SPDX
License List used when the SPDX file was created
Corresponds to the JSON property licenseListVersion
3988 3989 3990 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3988 def license_list_version @license_list_version end |
#namespace ⇒ String
Provide an SPDX document specific namespace as a unique absolute Uniform Resource Identifier (URI) as specified in RFC-3986, with the exception of the ‘
’ delimiter
Corresponds to the JSON property namespace
3995 3996 3997 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3995 def namespace @namespace end |
#title ⇒ String
Identify name of this document as designated by creator
Corresponds to the JSON property title
4000 4001 4002 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4000 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4007 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator_comment = args[:creator_comment] if args.key?(:creator_comment) @creators = args[:creators] if args.key?(:creators) @document_comment = args[:document_comment] if args.key?(:document_comment) @external_document_refs = args[:external_document_refs] if args.key?(:external_document_refs) @id = args[:id] if args.key?(:id) @license_list_version = args[:license_list_version] if args.key?(:license_list_version) @namespace = args[:namespace] if args.key?(:namespace) @title = args[:title] if args.key?(:title) end |