Class: Google::Apis::ContaineranalysisV1beta1::ExportSbomResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

The response from a call to ExportSBOM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportSbomResponse

Returns a new instance of ExportSbomResponse.



4091
4092
4093
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_occurrence_idString

The name of the discovery occurrence in the form "projects/project_id/ occurrences/OCCURRENCE_ID It can be used to track the progression of the SBOM export. Corresponds to the JSON property discoveryOccurrenceId

Returns:

  • (String)


4089
4090
4091
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4089

def discovery_occurrence_id
  @discovery_occurrence_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4096
4097
4098
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4096

def update!(**args)
  @discovery_occurrence_id = args[:discovery_occurrence_id] if args.key?(:discovery_occurrence_id)
end