Class: Google::Apis::ContaineranalysisV1beta1::ExternalRef

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalRef

Returns a new instance of ExternalRef.



3911
3912
3913
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package Corresponds to the JSON property category

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3893

def category
  @category
end

#commentString

Human-readable information about the purpose and target of the reference Corresponds to the JSON property comment

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3898

def comment
  @comment
end

#locatorString

The unique string with no spaces necessary to access the package-specific information, metadata, or content within the target location Corresponds to the JSON property locator

Returns:

  • (String)


3904
3905
3906
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3904

def locator
  @locator
end

#typeString

Type of category (e.g. 'npm' for the PACKAGE_MANAGER category) Corresponds to the JSON property type

Returns:

  • (String)


3909
3910
3911
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3909

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3916
3917
3918
3919
3920
3921
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3916

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @comment = args[:comment] if args.key?(:comment)
  @locator = args[:locator] if args.key?(:locator)
  @type = args[:type] if args.key?(:type)
end