Class: Google::Apis::ContaineranalysisV1beta1::ExternalRef
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::ExternalRef
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package
Instance Attribute Summary collapse
-
#category ⇒ String
An External Reference allows a Package to reference an external source of additional information, metadata, enumerations, asset identifiers, or downloadable content believed to be relevant to the Package Corresponds to the JSON property
category. -
#comment ⇒ String
Human-readable information about the purpose and target of the reference Corresponds to the JSON property
comment. -
#locator ⇒ String
The unique string with no spaces necessary to access the package-specific information, metadata, or content within the target location Corresponds to the JSON property
locator. -
#type ⇒ String
Type of category (e.g. 'npm' for the PACKAGE_MANAGER category) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalRef
constructor
A new instance of ExternalRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalRef
Returns a new instance of ExternalRef.
3905 3906 3907 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
An External Reference allows a Package to reference an external source of
additional information, metadata, enumerations, asset identifiers, or
downloadable content believed to be relevant to the Package
Corresponds to the JSON property category
3887 3888 3889 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3887 def category @category end |
#comment ⇒ String
Human-readable information about the purpose and target of the reference
Corresponds to the JSON property comment
3892 3893 3894 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3892 def comment @comment end |
#locator ⇒ String
The unique string with no spaces necessary to access the package-specific
information, metadata, or content within the target location
Corresponds to the JSON property locator
3898 3899 3900 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3898 def locator @locator end |
#type ⇒ String
Type of category (e.g. 'npm' for the PACKAGE_MANAGER category)
Corresponds to the JSON property type
3903 3904 3905 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3903 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3910 3911 3912 3913 3914 3915 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3910 def update!(**args) @category = args[:category] if args.key?(:category) @comment = args[:comment] if args.key?(:comment) @locator = args[:locator] if args.key?(:locator) @type = args[:type] if args.key?(:type) end |