Class: Google::Apis::ContaineranalysisV1beta1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::FileHashes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
4286 4287 4288 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::ContaineranalysisV1beta1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
4284 4285 4286 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4284 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4291 4292 4293 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4291 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |