Class: Google::Apis::ContaineranalysisV1beta1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::FileHashes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
4238 4239 4240 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::ContaineranalysisV1beta1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
4236 4237 4238 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4236 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4243 4244 4245 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4243 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |