Class: Google::Apis::ContaineranalysisV1beta1::FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::FileHashes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileHashes
constructor
A new instance of FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileHashes
Returns a new instance of FileHashes.
3959 3960 3961 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::ContaineranalysisV1beta1::HashProp>
Required. Collection of file hashes.
Corresponds to the JSON property fileHash
3957 3958 3959 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3957 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3964 3965 3966 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3964 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |