Class: Google::Apis::ContaineranalysisV1beta1::FileLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Indicates the location at which a package was found.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileLocation

Returns a new instance of FileLocation.



4258
4259
4260
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_pathString

For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file. Corresponds to the JSON property filePath

Returns:

  • (String)


4256
4257
4258
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4256

def file_path
  @file_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4263
4264
4265
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4263

def update!(**args)
  @file_path = args[:file_path] if args.key?(:file_path)
end