Class: Google::Apis::ContaineranalysisV1beta1::FileLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::FileLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileLocation
constructor
A new instance of FileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileLocation
Returns a new instance of FileLocation.
3979 3980 3981 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_path ⇒ String
For jars that are contained inside .war files, this filepath can indicate the
path to war file combined with the path to jar file.
Corresponds to the JSON property filePath
3977 3978 3979 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3977 def file_path @file_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3984 3985 3986 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 3984 def update!(**args) @file_path = args[:file_path] if args.key?(:file_path) end |