Class: Google::Apis::ContaineranalysisV1beta1::FileOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileOccurrence

Returns a new instance of FileOccurrence.



4352
4353
4354
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributionsArray<String>

This field provides a place for the SPDX data creator to record, at the file level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attributions

Returns:

  • (Array<String>)


4311
4312
4313
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4311

def attributions
  @attributions
end

#commentString

This field provides a place for the SPDX file creator to record any general comments about the file Corresponds to the JSON property comment

Returns:

  • (String)


4317
4318
4319
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4317

def comment
  @comment
end

#contributorsArray<String>

This field provides a place for the SPDX file creator to record file contributors Corresponds to the JSON property contributors

Returns:

  • (Array<String>)


4323
4324
4325
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4323

def contributors
  @contributors
end

Identify the copyright holder of the file, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


4328
4329
4330
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4328

def copyright
  @copyright
end

#files_license_infoArray<String>

This field contains the license information actually found in the file, if any Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


4333
4334
4335
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4333

def files_license_info
  @files_license_info
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


4339
4340
4341
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4339

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseConcluded



4344
4345
4346
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4344

def license_concluded
  @license_concluded
end

#noticeString

This field provides a place for the SPDX file creator to record license notices or other such related notices found in the file Corresponds to the JSON property notice

Returns:

  • (String)


4350
4351
4352
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4350

def notice
  @notice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4357

def update!(**args)
  @attributions = args[:attributions] if args.key?(:attributions)
  @comment = args[:comment] if args.key?(:comment)
  @contributors = args[:contributors] if args.key?(:contributors)
  @copyright = args[:copyright] if args.key?(:copyright)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @notice = args[:notice] if args.key?(:notice)
end