Class: Google::Apis::ContaineranalysisV1beta1::FileOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileOccurrence

Returns a new instance of FileOccurrence.



4067
4068
4069
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributionsArray<String>

This field provides a place for the SPDX data creator to record, at the file level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attributions

Returns:

  • (Array<String>)


4026
4027
4028
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4026

def attributions
  @attributions
end

#commentString

This field provides a place for the SPDX file creator to record any general comments about the file Corresponds to the JSON property comment

Returns:

  • (String)


4032
4033
4034
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4032

def comment
  @comment
end

#contributorsArray<String>

This field provides a place for the SPDX file creator to record file contributors Corresponds to the JSON property contributors

Returns:

  • (Array<String>)


4038
4039
4040
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4038

def contributors
  @contributors
end

Identify the copyright holder of the file, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


4043
4044
4045
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4043

def copyright
  @copyright
end

#files_license_infoArray<String>

This field contains the license information actually found in the file, if any Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


4048
4049
4050
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4048

def files_license_info
  @files_license_info
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4054

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseConcluded



4059
4060
4061
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4059

def license_concluded
  @license_concluded
end

#noticeString

This field provides a place for the SPDX file creator to record license notices or other such related notices found in the file Corresponds to the JSON property notice

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4065

def notice
  @notice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4072

def update!(**args)
  @attributions = args[:attributions] if args.key?(:attributions)
  @comment = args[:comment] if args.key?(:comment)
  @contributors = args[:contributors] if args.key?(:contributors)
  @copyright = args[:copyright] if args.key?(:copyright)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @notice = args[:notice] if args.key?(:notice)
end