Class: Google::Apis::ContaineranalysisV1beta1::Fingerprint
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Fingerprint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A set of properties that uniquely identify a given Docker image.
Instance Attribute Summary collapse
-
#v1_name ⇒ String
Required.
-
#v2_blob ⇒ Array<String>
Required.
-
#v2_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Fingerprint
constructor
A new instance of Fingerprint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Fingerprint
Returns a new instance of Fingerprint.
4106 4107 4108 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#v1_name ⇒ String
Required. The layer ID of the final layer in the Docker image's v1
representation.
Corresponds to the JSON property v1Name
4092 4093 4094 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4092 def v1_name @v1_name end |
#v2_blob ⇒ Array<String>
Required. The ordered list of v2 blobs that represent a given image.
Corresponds to the JSON property v2Blob
4097 4098 4099 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4097 def v2_blob @v2_blob end |
#v2_name ⇒ String
Output only. The name of the image's v2 blobs computed via: [bottom] :=
v2_blobbottom := sha256(v2_blob[N] + " " + v2_name[N+1]) Only the name of the
final blob is kept.
Corresponds to the JSON property v2Name
4104 4105 4106 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4104 def v2_name @v2_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4111 4112 4113 4114 4115 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4111 def update!(**args) @v1_name = args[:v1_name] if args.key?(:v1_name) @v2_blob = args[:v2_blob] if args.key?(:v2_blob) @v2_name = args[:v2_name] if args.key?(:v2_name) end |