Class: Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
An attestation wrapper that uses the Grafeas Signature message. This
attestation must define the serialized_payload that the signatures verify
and any metadata necessary to interpret that plaintext. The signatures should
always be over the serialized_payload bytestring.
Instance Attribute Summary collapse
-
#content_type ⇒ String
Type (for example schema) of the attestation payload that was signed.
-
#serialized_payload ⇒ String
The serialized payload that is verified by one or more
signatures. -
#signatures ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Signature>
One or more signatures over
serialized_payload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenericSignedAttestation
constructor
A new instance of GenericSignedAttestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenericSignedAttestation
Returns a new instance of GenericSignedAttestation.
4598 4599 4600 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
Type (for example schema) of the attestation payload that was signed. The
verifier must ensure that the provided type is one that the verifier supports,
and that the attestation payload is a valid instantiation of that type (for
example by validating a JSON schema).
Corresponds to the JSON property contentType
4580 4581 4582 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4580 def content_type @content_type end |
#serialized_payload ⇒ String
The serialized payload that is verified by one or more signatures. The
encoding and semantic meaning of this payload must match what is set in
content_type.
Corresponds to the JSON property serializedPayload
NOTE: Values are automatically base64 encoded/decoded in the client library.
4588 4589 4590 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4588 def serialized_payload @serialized_payload end |
#signatures ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Signature>
One or more signatures over serialized_payload. Verifier implementations
should consider this attestation message verified if at least one signature
verifies serialized_payload. See Signature in common.proto for more
details on signature structure and verification.
Corresponds to the JSON property signatures
4596 4597 4598 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4596 def signatures @signatures end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4603 4604 4605 4606 4607 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4603 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @serialized_payload = args[:serialized_payload] if args.key?(:serialized_payload) @signatures = args[:signatures] if args.key?(:signatures) end |