Class: Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::GenericSignedAttestation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
An attestation wrapper that uses the Grafeas Signature message. This
attestation must define the serialized_payload that the signatures verify
and any metadata necessary to interpret that plaintext. The signatures should
always be over the serialized_payload bytestring.
Instance Attribute Summary collapse
-
#content_type ⇒ String
Type (for example schema) of the attestation payload that was signed.
-
#serialized_payload ⇒ String
The serialized payload that is verified by one or more
signatures. -
#signatures ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Signature>
One or more signatures over
serialized_payload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenericSignedAttestation
constructor
A new instance of GenericSignedAttestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenericSignedAttestation
Returns a new instance of GenericSignedAttestation.
4537 4538 4539 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
Type (for example schema) of the attestation payload that was signed. The
verifier must ensure that the provided type is one that the verifier supports,
and that the attestation payload is a valid instantiation of that type (for
example by validating a JSON schema).
Corresponds to the JSON property contentType
4519 4520 4521 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4519 def content_type @content_type end |
#serialized_payload ⇒ String
The serialized payload that is verified by one or more signatures. The
encoding and semantic meaning of this payload must match what is set in
content_type.
Corresponds to the JSON property serializedPayload
NOTE: Values are automatically base64 encoded/decoded in the client library.
4527 4528 4529 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4527 def serialized_payload @serialized_payload end |
#signatures ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Signature>
One or more signatures over serialized_payload. Verifier implementations
should consider this attestation message verified if at least one signature
verifies serialized_payload. See Signature in common.proto for more
details on signature structure and verification.
Corresponds to the JSON property signatures
4535 4536 4537 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4535 def signatures @signatures end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4542 4543 4544 4545 4546 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4542 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @serialized_payload = args[:serialized_payload] if args.key?(:serialized_payload) @signatures = args[:signatures] if args.key?(:signatures) end |