Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Details of a build occurrence.
Instance Attribute Summary collapse
-
#in_toto_slsa_provenance_v1 ⇒ Google::Apis::ContaineranalysisV1beta1::InTotoSlsaProvenanceV1
Corresponds to the JSON property
inTotoSlsaProvenanceV1. -
#provenance ⇒ Google::Apis::ContaineranalysisV1beta1::BuildProvenance
Provenance of a build.
-
#provenance_bytes ⇒ String
Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1beta1BuildDetails
constructor
A new instance of GrafeasV1beta1BuildDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1beta1BuildDetails
Returns a new instance of GrafeasV1beta1BuildDetails.
4713 4714 4715 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#in_toto_slsa_provenance_v1 ⇒ Google::Apis::ContaineranalysisV1beta1::InTotoSlsaProvenanceV1
Corresponds to the JSON property inTotoSlsaProvenanceV1
4693 4694 4695 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4693 def in_toto_slsa_provenance_v1 @in_toto_slsa_provenance_v1 end |
#provenance ⇒ Google::Apis::ContaineranalysisV1beta1::BuildProvenance
Provenance of a build. Contains all information needed to verify the full
details about the build from source to completion.
Corresponds to the JSON property provenance
4699 4700 4701 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4699 def provenance @provenance end |
#provenance_bytes ⇒ String
Serialized JSON representation of the provenance, used in generating the build
signature in the corresponding build note. After verifying the signature,
provenance_bytes can be unmarshalled and compared to the provenance to
confirm that it is unchanged. A base64-encoded string representation of the
provenance bytes is used for the signature in order to interoperate with
openssl which expects this format for signature verification. The serialized
form is captured both to avoid ambiguity in how the provenance is marshalled
to json as well to prevent incompatibilities with future changes.
Corresponds to the JSON property provenanceBytes
4711 4712 4713 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4711 def provenance_bytes @provenance_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4718 4719 4720 4721 4722 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4718 def update!(**args) @in_toto_slsa_provenance_v1 = args[:in_toto_slsa_provenance_v1] if args.key?(:in_toto_slsa_provenance_v1) @provenance = args[:provenance] if args.key?(:provenance) @provenance_bytes = args[:provenance_bytes] if args.key?(:provenance_bytes) end |