Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Details of a build occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1beta1BuildDetails

Returns a new instance of GrafeasV1beta1BuildDetails.



4378
4379
4380
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#in_toto_slsa_provenance_v1Google::Apis::ContaineranalysisV1beta1::InTotoSlsaProvenanceV1

Corresponds to the JSON property inTotoSlsaProvenanceV1



4358
4359
4360
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4358

def in_toto_slsa_provenance_v1
  @in_toto_slsa_provenance_v1
end

#provenanceGoogle::Apis::ContaineranalysisV1beta1::BuildProvenance

Provenance of a build. Contains all information needed to verify the full details about the build from source to completion. Corresponds to the JSON property provenance



4364
4365
4366
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4364

def provenance
  @provenance
end

#provenance_bytesString

Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note. After verifying the signature, provenance_bytes can be unmarshalled and compared to the provenance to confirm that it is unchanged. A base64-encoded string representation of the provenance bytes is used for the signature in order to interoperate with openssl which expects this format for signature verification. The serialized form is captured both to avoid ambiguity in how the provenance is marshalled to json as well to prevent incompatibilities with future changes. Corresponds to the JSON property provenanceBytes

Returns:

  • (String)


4376
4377
4378
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4376

def provenance_bytes
  @provenance_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4383
4384
4385
4386
4387
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4383

def update!(**args)
  @in_toto_slsa_provenance_v1 = args[:in_toto_slsa_provenance_v1] if args.key?(:in_toto_slsa_provenance_v1)
  @provenance = args[:provenance] if args.key?(:provenance)
  @provenance_bytes = args[:provenance_bytes] if args.key?(:provenance_bytes)
end