Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Details of a vulnerability Occurrence.
Instance Attribute Summary collapse
-
#cvss_score ⇒ Float
Output only.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
Output only.
-
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when it is available, and note provider assigned severity when distro has not yet assigned a severity for this vulnerability.
-
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
-
#long_description ⇒ String
Output only.
-
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1beta1::PackageIssue>
Required.
-
#related_urls ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
Output only.
-
#severity ⇒ String
Output only.
-
#short_description ⇒ String
Output only.
-
#type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages etc) Corresponds to the JSON property
type. -
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1beta1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrafeasV1beta1VulnerabilityDetails
constructor
A new instance of GrafeasV1beta1VulnerabilityDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrafeasV1beta1VulnerabilityDetails
Returns a new instance of GrafeasV1beta1VulnerabilityDetails.
5050 5051 5052 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cvss_score ⇒ Float
Output only. The CVSS score of this vulnerability. CVSS score is on a scale of
0-10 where 0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssScore
4954 4955 4956 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4954 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2,
v3, and v4. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS
v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS
v3 details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV2
4965 4966 4967 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4965 def cvss_v2 @cvss_v2 end |
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2,
v3, and v4. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS
v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS
v3 details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV3
4976 4977 4978 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4976 def cvss_v3 @cvss_v3 end |
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2,
v3, and v4. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS
v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS
v3 details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV4
4987 4988 4989 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4987 def cvss_v4 @cvss_v4 end |
#cvss_version ⇒ String
Output only. CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
4992 4993 4994 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4992 def cvss_version @cvss_version end |
#effective_severity ⇒ String
The distro assigned severity for this vulnerability when it is available, and
note provider assigned severity when distro has not yet assigned a severity
for this vulnerability. When there are multiple PackageIssues for this
vulnerability, they can have different effective severities because some might
be provided by the distro while others are provided by the language ecosystem
for a language pack. For this reason, it is advised to use the effective
severity on the PackageIssue level. In the case where multiple PackageIssues
have differing effective severities, this field should be the highest severity
for any of the PackageIssues.
Corresponds to the JSON property effectiveSeverity
5005 5006 5007 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5005 def effective_severity @effective_severity end |
#extra_details ⇒ String
Occurrence-specific extra details about the vulnerability.
Corresponds to the JSON property extraDetails
5010 5011 5012 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5010 def extra_details @extra_details end |
#long_description ⇒ String
Output only. A detailed description of this vulnerability.
Corresponds to the JSON property longDescription
5015 5016 5017 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5015 def long_description @long_description end |
#package_issue ⇒ Array<Google::Apis::ContaineranalysisV1beta1::PackageIssue>
Required. The set of affected locations and their fixes (if available) within
the associated resource.
Corresponds to the JSON property packageIssue
5021 5022 5023 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5021 def package_issue @package_issue end |
#related_urls ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
Output only. URLs related to this vulnerability.
Corresponds to the JSON property relatedUrls
5026 5027 5028 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5026 def @related_urls end |
#severity ⇒ String
Output only. The note provider assigned Severity of the vulnerability.
Corresponds to the JSON property severity
5031 5032 5033 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5031 def severity @severity end |
#short_description ⇒ String
Output only. A one sentence description of this vulnerability.
Corresponds to the JSON property shortDescription
5036 5037 5038 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5036 def short_description @short_description end |
#type ⇒ String
The type of package; whether native or non native(ruby gems, node.js packages
etc)
Corresponds to the JSON property type
5042 5043 5044 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5042 def type @type end |
#vex_assessment ⇒ Google::Apis::ContaineranalysisV1beta1::VexAssessment
VexAssessment provides all publisher provided Vex information that is related
to this vulnerability.
Corresponds to the JSON property vexAssessment
5048 5049 5050 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5048 def vex_assessment @vex_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5055 def update!(**args) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @cvss_v4 = args[:cvss_v4] if args.key?(:cvss_v4) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @extra_details = args[:extra_details] if args.key?(:extra_details) @long_description = args[:long_description] if args.key?(:long_description) @package_issue = args[:package_issue] if args.key?(:package_issue) @related_urls = args[:related_urls] if args.key?(:related_urls) @severity = args[:severity] if args.key?(:severity) @short_description = args[:short_description] if args.key?(:short_description) @type = args[:type] if args.key?(:type) @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment) end |