Class: Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Details of a vulnerability Occurrence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrafeasV1beta1VulnerabilityDetails

Returns a new instance of GrafeasV1beta1VulnerabilityDetails.



4633
4634
4635
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvss_scoreFloat

Output only. The CVSS score of this vulnerability. CVSS score is on a scale of 0-10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssScore

Returns:

  • (Float)


4552
4553
4554
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4552

def cvss_score
  @cvss_score
end

#cvss_v2Google::Apis::ContaineranalysisV1beta1::Cvss

Common Vulnerability Scoring System. This message is compatible with CVSS v2 and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3 details, see https://www.first.org/cvss/specification-document CVSS v3 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator Corresponds to the JSON property cvssV2



4561
4562
4563
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4561

def cvss_v2
  @cvss_v2
end

#cvss_v3Google::Apis::ContaineranalysisV1beta1::Cvss

Common Vulnerability Scoring System. This message is compatible with CVSS v2 and v3. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS v3 details, see https://www.first.org/cvss/specification-document CVSS v3 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator Corresponds to the JSON property cvssV3



4570
4571
4572
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4570

def cvss_v3
  @cvss_v3
end

#cvss_versionString

Output only. CVSS version used to populate cvss_score and severity. Corresponds to the JSON property cvssVersion

Returns:

  • (String)


4575
4576
4577
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4575

def cvss_version
  @cvss_version
end

#effective_severityString

The distro assigned severity for this vulnerability when it is available, and note provider assigned severity when distro has not yet assigned a severity for this vulnerability. When there are multiple PackageIssues for this vulnerability, they can have different effective severities because some might be provided by the distro while others are provided by the language ecosystem for a language pack. For this reason, it is advised to use the effective severity on the PackageIssue level. In the case where multiple PackageIssues have differing effective severities, this field should be the highest severity for any of the PackageIssues. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


4588
4589
4590
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4588

def effective_severity
  @effective_severity
end

#extra_detailsString

Occurrence-specific extra details about the vulnerability. Corresponds to the JSON property extraDetails

Returns:

  • (String)


4593
4594
4595
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4593

def extra_details
  @extra_details
end

#long_descriptionString

Output only. A detailed description of this vulnerability. Corresponds to the JSON property longDescription

Returns:

  • (String)


4598
4599
4600
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4598

def long_description
  @long_description
end

#package_issueArray<Google::Apis::ContaineranalysisV1beta1::PackageIssue>

Required. The set of affected locations and their fixes (if available) within the associated resource. Corresponds to the JSON property packageIssue



4604
4605
4606
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4604

def package_issue
  @package_issue
end

Output only. URLs related to this vulnerability. Corresponds to the JSON property relatedUrls



4609
4610
4611
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4609

def related_urls
  @related_urls
end

#severityString

Output only. The note provider assigned Severity of the vulnerability. Corresponds to the JSON property severity

Returns:

  • (String)


4614
4615
4616
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4614

def severity
  @severity
end

#short_descriptionString

Output only. A one sentence description of this vulnerability. Corresponds to the JSON property shortDescription

Returns:

  • (String)


4619
4620
4621
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4619

def short_description
  @short_description
end

#typeString

The type of package; whether native or non native(ruby gems, node.js packages etc) Corresponds to the JSON property type

Returns:

  • (String)


4625
4626
4627
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4625

def type
  @type
end

#vex_assessmentGoogle::Apis::ContaineranalysisV1beta1::VexAssessment

VexAssessment provides all publisher provided Vex information that is related to this vulnerability. Corresponds to the JSON property vexAssessment



4631
4632
4633
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4631

def vex_assessment
  @vex_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4638
4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
4649
4650
4651
4652
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4638

def update!(**args)
  @cvss_score = args[:cvss_score] if args.key?(:cvss_score)
  @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2)
  @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3)
  @cvss_version = args[:cvss_version] if args.key?(:cvss_version)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @extra_details = args[:extra_details] if args.key?(:extra_details)
  @long_description = args[:long_description] if args.key?(:long_description)
  @package_issue = args[:package_issue] if args.key?(:package_issue)
  @related_urls = args[:related_urls] if args.key?(:related_urls)
  @severity = args[:severity] if args.key?(:severity)
  @short_description = args[:short_description] if args.key?(:short_description)
  @type = args[:type] if args.key?(:type)
  @vex_assessment = args[:vex_assessment] if args.key?(:vex_assessment)
end