Class: Google::Apis::ContaineranalysisV1beta1::Hint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This submessage provides human-readable hints about the purpose of the authority. Because the name of a note acts as its resource reference, it is important to disambiguate the canonical name of the Note (which might be a UUID for security purposes) from "readable" names more suitable for debug output. Note that these hints should not be used to look up authorities in security sensitive contexts, such as when looking up attestations to verify.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hint

Returns a new instance of Hint.



4702
4703
4704
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#human_readable_nameString

Required. The human readable name of this attestation authority, for example " qa". Corresponds to the JSON property humanReadableName

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4700

def human_readable_name
  @human_readable_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4707
4708
4709
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4707

def update!(**args)
  @human_readable_name = args[:human_readable_name] if args.key?(:human_readable_name)
end