Class: Google::Apis::ContaineranalysisV1beta1::InToto
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::InToto
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This contains the fields corresponding to the definition of a software supply chain step in an in-toto layout. This information goes into a Grafeas note.
Instance Attribute Summary collapse
-
#expected_command ⇒ Array<String>
This field contains the expected command used to perform the step.
-
#expected_materials ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>
The following fields contain in-toto artifact rules identifying the artifacts that enter this supply chain step, and exit the supply chain step, i.e.
-
#expected_products ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>
Corresponds to the JSON property
expectedProducts. -
#signing_keys ⇒ Array<Google::Apis::ContaineranalysisV1beta1::SigningKey>
This field contains the public keys that can be used to verify the signatures on the step metadata.
-
#step_name ⇒ String
This field identifies the name of the step in the supply chain.
-
#threshold ⇒ Fixnum
This field contains a value that indicates the minimum number of keys that need to be used to sign the step's in-toto link.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InToto
constructor
A new instance of InToto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InToto
Returns a new instance of InToto.
5080 5081 5082 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expected_command ⇒ Array<String>
This field contains the expected command used to perform the step.
Corresponds to the JSON property expectedCommand
5049 5050 5051 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5049 def expected_command @expected_command end |
#expected_materials ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>
The following fields contain in-toto artifact rules identifying the artifacts
that enter this supply chain step, and exit the supply chain step, i.e.
materials and products of the step.
Corresponds to the JSON property expectedMaterials
5056 5057 5058 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5056 def expected_materials @expected_materials end |
#expected_products ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>
Corresponds to the JSON property expectedProducts
5061 5062 5063 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5061 def expected_products @expected_products end |
#signing_keys ⇒ Array<Google::Apis::ContaineranalysisV1beta1::SigningKey>
This field contains the public keys that can be used to verify the signatures
on the step metadata.
Corresponds to the JSON property signingKeys
5067 5068 5069 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5067 def signing_keys @signing_keys end |
#step_name ⇒ String
This field identifies the name of the step in the supply chain.
Corresponds to the JSON property stepName
5072 5073 5074 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5072 def step_name @step_name end |
#threshold ⇒ Fixnum
This field contains a value that indicates the minimum number of keys that
need to be used to sign the step's in-toto link.
Corresponds to the JSON property threshold
5078 5079 5080 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5078 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5085 5086 5087 5088 5089 5090 5091 5092 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5085 def update!(**args) @expected_command = args[:expected_command] if args.key?(:expected_command) @expected_materials = args[:expected_materials] if args.key?(:expected_materials) @expected_products = args[:expected_products] if args.key?(:expected_products) @signing_keys = args[:signing_keys] if args.key?(:signing_keys) @step_name = args[:step_name] if args.key?(:step_name) @threshold = args[:threshold] if args.key?(:threshold) end |