Class: Google::Apis::ContaineranalysisV1beta1::InToto

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This contains the fields corresponding to the definition of a software supply chain step in an in-toto layout. This information goes into a Grafeas note.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InToto

Returns a new instance of InToto.



4745
4746
4747
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expected_commandArray<String>

This field contains the expected command used to perform the step. Corresponds to the JSON property expectedCommand

Returns:

  • (Array<String>)


4714
4715
4716
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4714

def expected_command
  @expected_command
end

#expected_materialsArray<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>

The following fields contain in-toto artifact rules identifying the artifacts that enter this supply chain step, and exit the supply chain step, i.e. materials and products of the step. Corresponds to the JSON property expectedMaterials



4721
4722
4723
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4721

def expected_materials
  @expected_materials
end

#expected_productsArray<Google::Apis::ContaineranalysisV1beta1::ArtifactRule>

Corresponds to the JSON property expectedProducts



4726
4727
4728
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4726

def expected_products
  @expected_products
end

#signing_keysArray<Google::Apis::ContaineranalysisV1beta1::SigningKey>

This field contains the public keys that can be used to verify the signatures on the step metadata. Corresponds to the JSON property signingKeys



4732
4733
4734
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4732

def signing_keys
  @signing_keys
end

#step_nameString

This field identifies the name of the step in the supply chain. Corresponds to the JSON property stepName

Returns:

  • (String)


4737
4738
4739
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4737

def step_name
  @step_name
end

#thresholdFixnum

This field contains a value that indicates the minimum number of keys that need to be used to sign the step's in-toto link. Corresponds to the JSON property threshold

Returns:

  • (Fixnum)


4743
4744
4745
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4743

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4750
4751
4752
4753
4754
4755
4756
4757
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4750

def update!(**args)
  @expected_command = args[:expected_command] if args.key?(:expected_command)
  @expected_materials = args[:expected_materials] if args.key?(:expected_materials)
  @expected_products = args[:expected_products] if args.key?(:expected_products)
  @signing_keys = args[:signing_keys] if args.key?(:signing_keys)
  @step_name = args[:step_name] if args.key?(:step_name)
  @threshold = args[:threshold] if args.key?(:threshold)
end