Class: Google::Apis::ContaineranalysisV1beta1::Installation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Installation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This represents how a particular software package may be installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
-
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Installation
constructor
A new instance of Installation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Installation
Returns a new instance of Installation.
5262 5263 5264 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5226 5227 5228 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5226 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
5233 5234 5235 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5233 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
Corresponds to the JSON property license
5238 5239 5240 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5238 def license @license end |
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
5244 5245 5246 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5244 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
5249 5250 5251 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5249 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
5255 5256 5257 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5255 def package_type @package_type end |
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
5260 5261 5262 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5260 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5267 5268 5269 5270 5271 5272 5273 5274 5275 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5267 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |