Class: Google::Apis::ContaineranalysisV1beta1::Installation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Installation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This represents how a particular software package may be installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
-
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Installation
constructor
A new instance of Installation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Installation
Returns a new instance of Installation.
5179 5180 5181 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
5143 5144 5145 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5143 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
5150 5151 5152 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5150 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
Corresponds to the JSON property license
5155 5156 5157 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5155 def license @license end |
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
5161 5162 5163 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5161 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
5166 5167 5168 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5166 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
5172 5173 5174 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5172 def package_type @package_type end |
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
5177 5178 5179 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5177 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5184 5185 5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5184 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |