Class: Google::Apis::ContaineranalysisV1beta1::Installation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Installation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This represents how a particular software package may be installed on a system.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#cpe_uri ⇒ String
Output only.
-
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
-
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been found.
-
#name ⇒ String
Required.
-
#package_type ⇒ String
Output only.
-
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Installation
constructor
A new instance of Installation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Installation
Returns a new instance of Installation.
4844 4845 4846 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture for which packages in this distribution
channel were built. Architecture will be blank for language packages.
Corresponds to the JSON property architecture
4808 4809 4810 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4808 def architecture @architecture end |
#cpe_uri ⇒ String
Output only. The cpe_uri in CPE format
denoting the package manager version distributing a package. The cpe_uri will
be blank for language packages.
Corresponds to the JSON property cpeUri
4815 4816 4817 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4815 def cpe_uri @cpe_uri end |
#license ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
Corresponds to the JSON property license
4820 4821 4822 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4820 def license @license end |
#location ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Location>
All of the places within the filesystem versions of this package have been
found.
Corresponds to the JSON property location
4826 4827 4828 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4826 def location @location end |
#name ⇒ String
Required. Output only. The name of the installed package.
Corresponds to the JSON property name
4831 4832 4833 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4831 def name @name end |
#package_type ⇒ String
Output only. The type of package; whether native or non native (e.g., ruby
gems, node.js packages, etc.).
Corresponds to the JSON property packageType
4837 4838 4839 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4837 def package_type @package_type end |
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
4842 4843 4844 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4842 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4849 4850 4851 4852 4853 4854 4855 4856 4857 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 4849 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @license = args[:license] if args.key?(:license) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @package_type = args[:package_type] if args.key?(:package_type) @version = args[:version] if args.key?(:version) end |