Class: Google::Apis::ContaineranalysisV1beta1::Link
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Link
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This corresponds to an in-toto link.
Instance Attribute Summary collapse
-
#byproducts ⇒ Google::Apis::ContaineranalysisV1beta1::ByProducts
Defines an object for the byproducts field in in-toto links.
-
#command ⇒ Array<String>
This field contains the full command executed for the step.
-
#environment ⇒ Google::Apis::ContaineranalysisV1beta1::Environment
Defines an object for the environment field in in-toto links.
-
#materials ⇒ Array<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>
Materials are the supply chain artifacts that go into the step and are used for the operation performed.
-
#products ⇒ Array<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>
Products are the supply chain artifacts generated as a result of the step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Link
constructor
A new instance of Link.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Link
Returns a new instance of Link.
5450 5451 5452 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#byproducts ⇒ Google::Apis::ContaineranalysisV1beta1::ByProducts
Defines an object for the byproducts field in in-toto links. The suggested
fields are "stderr", "stdout", and "return-value".
Corresponds to the JSON property byproducts
5418 5419 5420 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5418 def byproducts @byproducts end |
#command ⇒ Array<String>
This field contains the full command executed for the step. This can also be
empty if links are generated for operations that aren't directly mapped to a
specific command. Each term in the command is an independent string in the
list. An example of a command in the in-toto metadata field is: "command": ["
git", "clone", "https://github.com/in-toto/demo-project.git"]
Corresponds to the JSON property command
5427 5428 5429 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5427 def command @command end |
#environment ⇒ Google::Apis::ContaineranalysisV1beta1::Environment
Defines an object for the environment field in in-toto links. The suggested
fields are "variables", "filesystem", and "workdir".
Corresponds to the JSON property environment
5433 5434 5435 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5433 def environment @environment end |
#materials ⇒ Array<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>
Materials are the supply chain artifacts that go into the step and are used
for the operation performed. The key of the map is the path of the artifact
and the structure contains the recorded hash information. An example is: "
materials": [ "resource_uri": "foo/bar", "hashes": "sha256": "ebebf...", :
]
Corresponds to the JSON property materials
5442 5443 5444 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5442 def materials @materials end |
#products ⇒ Array<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>
Products are the supply chain artifacts generated as a result of the step. The
structure is identical to that of materials.
Corresponds to the JSON property products
5448 5449 5450 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5448 def products @products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5455 5456 5457 5458 5459 5460 5461 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5455 def update!(**args) @byproducts = args[:byproducts] if args.key?(:byproducts) @command = args[:command] if args.key?(:command) @environment = args[:environment] if args.key?(:environment) @materials = args[:materials] if args.key?(:materials) @products = args[:products] if args.key?(:products) end |