Class: Google::Apis::ContaineranalysisV1beta1::Link

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This corresponds to an in-toto link.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Link

Returns a new instance of Link.



5032
5033
5034
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byproductsGoogle::Apis::ContaineranalysisV1beta1::ByProducts

Defines an object for the byproducts field in in-toto links. The suggested fields are "stderr", "stdout", and "return-value". Corresponds to the JSON property byproducts



5000
5001
5002
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5000

def byproducts
  @byproducts
end

#commandArray<String>

This field contains the full command executed for the step. This can also be empty if links are generated for operations that aren't directly mapped to a specific command. Each term in the command is an independent string in the list. An example of a command in the in-toto metadata field is: "command": [" git", "clone", "https://github.com/in-toto/demo-project.git"] Corresponds to the JSON property command

Returns:

  • (Array<String>)


5009
5010
5011
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5009

def command
  @command
end

#environmentGoogle::Apis::ContaineranalysisV1beta1::Environment

Defines an object for the environment field in in-toto links. The suggested fields are "variables", "filesystem", and "workdir". Corresponds to the JSON property environment



5015
5016
5017
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5015

def environment
  @environment
end

#materialsArray<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>

Materials are the supply chain artifacts that go into the step and are used for the operation performed. The key of the map is the path of the artifact and the structure contains the recorded hash information. An example is: " materials": [ "resource_uri": "foo/bar", "hashes": "sha256": "ebebf...", : ] Corresponds to the JSON property materials



5024
5025
5026
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5024

def materials
  @materials
end

#productsArray<Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoArtifact>

Products are the supply chain artifacts generated as a result of the step. The structure is identical to that of materials. Corresponds to the JSON property products



5030
5031
5032
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5030

def products
  @products
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5037
5038
5039
5040
5041
5042
5043
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5037

def update!(**args)
  @byproducts = args[:byproducts] if args.key?(:byproducts)
  @command = args[:command] if args.key?(:command)
  @environment = args[:environment] if args.key?(:environment)
  @materials = args[:materials] if args.key?(:materials)
  @products = args[:products] if args.key?(:products)
end