Class: Google::Apis::ContaineranalysisV1beta1::Location
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Location
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
An occurrence of a particular package installation found within a system's
filesystem. E.g., glibc was found in /var/lib/dpkg/status.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
Deprecated.
-
#path ⇒ String
The path from which we gathered that this package/version is installed.
-
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
5572 5573 5574 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
Deprecated. The CPE URI in CPE format
denoting the package manager version distributing a package.
Corresponds to the JSON property cpeUri
5560 5561 5562 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5560 def cpe_uri @cpe_uri end |
#path ⇒ String
The path from which we gathered that this package/version is installed.
Corresponds to the JSON property path
5565 5566 5567 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5565 def path @path end |
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
5570 5571 5572 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5570 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5577 5578 5579 5580 5581 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5577 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @path = args[:path] if args.key?(:path) @version = args[:version] if args.key?(:version) end |