Class: Google::Apis::ContaineranalysisV1beta1::Note
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Note
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A type of analysis that can be done for a resource.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1beta1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
-
#attestation_authority ⇒ Google::Apis::ContaineranalysisV1beta1::Authority
Note kind that represents a logical attestation "role" or "authority".
-
#base_image ⇒ Google::Apis::ContaineranalysisV1beta1::Basis
Basis describes the base image portion (Note) of the DockerImage relationship.
-
#build ⇒ Google::Apis::ContaineranalysisV1beta1::Build
Note holding the version of the provider's builder and the signature of the provenance message in the build details occurrence.
-
#create_time ⇒ String
Output only.
-
#deployable ⇒ Google::Apis::ContaineranalysisV1beta1::Deployable
An artifact that can be deployed in some runtime.
-
#discovery ⇒ Google::Apis::ContaineranalysisV1beta1::Discovery
A note that indicates a type of analysis a provider would perform.
-
#expiration_time ⇒ String
Time of expiration for this note.
-
#intoto ⇒ Google::Apis::ContaineranalysisV1beta1::InToto
This contains the fields corresponding to the definition of a software supply chain step in an in-toto layout.
-
#kind ⇒ String
Output only.
-
#long_description ⇒ String
A detailed description of this note.
-
#name ⇒ String
Output only.
-
#package ⇒ Google::Apis::ContaineranalysisV1beta1::Package
Package represents a particular package version.
-
#related_note_names ⇒ Array<String>
Other notes related to this note.
-
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
URLs associated with this note.
-
#sbom ⇒ Google::Apis::ContaineranalysisV1beta1::DocumentNote
DocumentNote represents an SPDX Document Creation Information section: https:// spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property
sbom. -
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceNote
The note representing an SBOM reference.
-
#secret ⇒ Google::Apis::ContaineranalysisV1beta1::SecretNote
The note representing a secret.
-
#short_description ⇒ String
A one sentence description of this note.
-
#spdx_file ⇒ Google::Apis::ContaineranalysisV1beta1::FileNote
FileNote represents an SPDX File Information section: https://spdx.github.io/ spdx-spec/4-file-information/ Corresponds to the JSON property
spdxFile. -
#spdx_package ⇒ Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
PackageInfoNote represents an SPDX Package Information section: https://spdx.
-
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1beta1::RelationshipNote
RelationshipNote represents an SPDX Relationship section: https://spdx.github.
-
#update_time ⇒ String
Output only.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1beta1::Vulnerability
Vulnerability provides metadata about a security vulnerability in a Note.
-
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Note
constructor
A new instance of Note.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Note
Returns a new instance of Note.
5822 5823 5824 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1beta1::AiSkillAnalysisNote
AISkillAnalysisNote provides the metadata of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5678 5679 5680 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5678 def ai_skill_analysis @ai_skill_analysis end |
#attestation_authority ⇒ Google::Apis::ContaineranalysisV1beta1::Authority
Note kind that represents a logical attestation "role" or "authority". For
example, an organization might have one Authority for "QA" and one for "
build". This note is intended to act strictly as a grouping mechanism for the
attached occurrences (Attestations). This grouping mechanism also provides a
security boundary, since IAM ACLs gate the ability for a principle to attach
an occurrence to a given note. It also provides a single point of lookup to
find all attached attestation occurrences, even if they don't all live in the
same project.
Corresponds to the JSON property attestationAuthority
5690 5691 5692 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5690 def @attestation_authority end |
#base_image ⇒ Google::Apis::ContaineranalysisV1beta1::Basis
Basis describes the base image portion (Note) of the DockerImage relationship.
Linked occurrences are derived from this or an equivalent image via: FROM Or
an equivalent reference, e.g. a tag of the resource_url.
Corresponds to the JSON property baseImage
5697 5698 5699 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5697 def base_image @base_image end |
#build ⇒ Google::Apis::ContaineranalysisV1beta1::Build
Note holding the version of the provider's builder and the signature of the
provenance message in the build details occurrence.
Corresponds to the JSON property build
5703 5704 5705 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5703 def build @build end |
#create_time ⇒ String
Output only. The time this note was created. This field can be used as a
filter in list requests.
Corresponds to the JSON property createTime
5709 5710 5711 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5709 def create_time @create_time end |
#deployable ⇒ Google::Apis::ContaineranalysisV1beta1::Deployable
An artifact that can be deployed in some runtime.
Corresponds to the JSON property deployable
5714 5715 5716 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5714 def deployable @deployable end |
#discovery ⇒ Google::Apis::ContaineranalysisV1beta1::Discovery
A note that indicates a type of analysis a provider would perform. This note
exists in a provider's project. A Discovery occurrence is created in a
consumer's project at the start of analysis.
Corresponds to the JSON property discovery
5721 5722 5723 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5721 def discovery @discovery end |
#expiration_time ⇒ String
Time of expiration for this note. Empty if note does not expire.
Corresponds to the JSON property expirationTime
5726 5727 5728 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5726 def expiration_time @expiration_time end |
#intoto ⇒ Google::Apis::ContaineranalysisV1beta1::InToto
This contains the fields corresponding to the definition of a software supply
chain step in an in-toto layout. This information goes into a Grafeas note.
Corresponds to the JSON property intoto
5732 5733 5734 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5732 def intoto @intoto end |
#kind ⇒ String
Output only. The type of analysis. This field can be used as a filter in list
requests.
Corresponds to the JSON property kind
5738 5739 5740 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5738 def kind @kind end |
#long_description ⇒ String
A detailed description of this note.
Corresponds to the JSON property longDescription
5743 5744 5745 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5743 def long_description @long_description end |
#name ⇒ String
Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/
[NOTE_ID].
Corresponds to the JSON property name
5749 5750 5751 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5749 def name @name end |
#package ⇒ Google::Apis::ContaineranalysisV1beta1::Package
Package represents a particular package version.
Corresponds to the JSON property package
5754 5755 5756 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5754 def package @package end |
#related_note_names ⇒ Array<String>
Other notes related to this note.
Corresponds to the JSON property relatedNoteNames
5759 5760 5761 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5759 def @related_note_names end |
#related_url ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
URLs associated with this note.
Corresponds to the JSON property relatedUrl
5764 5765 5766 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5764 def @related_url end |
#sbom ⇒ Google::Apis::ContaineranalysisV1beta1::DocumentNote
DocumentNote represents an SPDX Document Creation Information section: https://
spdx.github.io/spdx-spec/2-document-creation-information/
Corresponds to the JSON property sbom
5770 5771 5772 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5770 def sbom @sbom end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceNote
The note representing an SBOM reference.
Corresponds to the JSON property sbomReference
5775 5776 5777 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5775 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1beta1::SecretNote
The note representing a secret.
Corresponds to the JSON property secret
5780 5781 5782 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5780 def secret @secret end |
#short_description ⇒ String
A one sentence description of this note.
Corresponds to the JSON property shortDescription
5785 5786 5787 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5785 def short_description @short_description end |
#spdx_file ⇒ Google::Apis::ContaineranalysisV1beta1::FileNote
FileNote represents an SPDX File Information section: https://spdx.github.io/
spdx-spec/4-file-information/
Corresponds to the JSON property spdxFile
5791 5792 5793 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5791 def spdx_file @spdx_file end |
#spdx_package ⇒ Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
PackageInfoNote represents an SPDX Package Information section: https://spdx.
github.io/spdx-spec/3-package-information/
Corresponds to the JSON property spdxPackage
5797 5798 5799 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5797 def spdx_package @spdx_package end |
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1beta1::RelationshipNote
RelationshipNote represents an SPDX Relationship section: https://spdx.github.
io/spdx-spec/7-relationships-between-SPDX-elements/
Corresponds to the JSON property spdxRelationship
5803 5804 5805 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5803 def spdx_relationship @spdx_relationship end |
#update_time ⇒ String
Output only. The time this note was last updated. This field can be used as a
filter in list requests.
Corresponds to the JSON property updateTime
5809 5810 5811 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5809 def update_time @update_time end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1beta1::Vulnerability
Vulnerability provides metadata about a security vulnerability in a Note.
Corresponds to the JSON property vulnerability
5814 5815 5816 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5814 def vulnerability @vulnerability end |
#vulnerability_assessment ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityAssessmentNote
A single VulnerabilityAssessmentNote represents one particular product's
vulnerability assessment for one CVE.
Corresponds to the JSON property vulnerabilityAssessment
5820 5821 5822 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5820 def vulnerability_assessment @vulnerability_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 5853 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5827 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation_authority = args[:attestation_authority] if args.key?(:attestation_authority) @base_image = args[:base_image] if args.key?(:base_image) @build = args[:build] if args.key?(:build) @create_time = args[:create_time] if args.key?(:create_time) @deployable = args[:deployable] if args.key?(:deployable) @discovery = args[:discovery] if args.key?(:discovery) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @intoto = args[:intoto] if args.key?(:intoto) @kind = args[:kind] if args.key?(:kind) @long_description = args[:long_description] if args.key?(:long_description) @name = args[:name] if args.key?(:name) @package = args[:package] if args.key?(:package) @related_note_names = args[:related_note_names] if args.key?(:related_note_names) @related_url = args[:related_url] if args.key?(:related_url) @sbom = args[:sbom] if args.key?(:sbom) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @short_description = args[:short_description] if args.key?(:short_description) @spdx_file = args[:spdx_file] if args.key?(:spdx_file) @spdx_package = args[:spdx_package] if args.key?(:spdx_package) @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship) @update_time = args[:update_time] if args.key?(:update_time) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) @vulnerability_assessment = args[:vulnerability_assessment] if args.key?(:vulnerability_assessment) end |