Class: Google::Apis::ContaineranalysisV1beta1::Occurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Occurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
An instance of an analysis type that has been found on a resource.
Instance Attribute Summary collapse
-
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1beta1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
-
#attestation ⇒ Google::Apis::ContaineranalysisV1beta1::Details
Details of an attestation occurrence.
-
#build ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails
Details of a build occurrence.
-
#create_time ⇒ String
Output only.
-
#deployment ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DeploymentDetails
Details of a deployment occurrence.
-
#derived_image ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1ImageDetails
Details of an image occurrence.
-
#discovered ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DiscoveryDetails
Details of a discovery occurrence.
- #envelope ⇒ Google::Apis::ContaineranalysisV1beta1::Envelope
-
#installation ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1PackageDetails
Details of a package occurrence.
-
#intoto ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoDetails
This corresponds to a signed in-toto link - it is made up of one or more signatures and the in-toto link itself.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#note_name ⇒ String
Required.
-
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
-
#resource ⇒ Google::Apis::ContaineranalysisV1beta1::Resource
An entity that can have metadata.
-
#sbom ⇒ Google::Apis::ContaineranalysisV1beta1::DocumentOccurrence
DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property
sbom. -
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific resource.
-
#secret ⇒ Google::Apis::ContaineranalysisV1beta1::SecretOccurrence
The occurrence provides details of a secret.
-
#spdx_file ⇒ Google::Apis::ContaineranalysisV1beta1::FileOccurrence
FileOccurrence represents an SPDX File Information section: https://spdx.
-
#spdx_package ⇒ Google::Apis::ContaineranalysisV1beta1::PackageInfoOccurrence
PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/ Corresponds to the JSON property
spdxPackage. -
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1beta1::RelationshipOccurrence
RelationshipOccurrence represents an SPDX Relationship section: https://spdx.
-
#update_time ⇒ String
Output only.
-
#vulnerability ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails
Details of a vulnerability Occurrence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Occurrence
constructor
A new instance of Occurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Occurrence
Returns a new instance of Occurrence.
5837 5838 5839 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_skill_analysis ⇒ Google::Apis::ContaineranalysisV1beta1::AiSkillAnalysisOccurrence
AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.
Corresponds to the JSON property aiSkillAnalysis
5712 5713 5714 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5712 def ai_skill_analysis @ai_skill_analysis end |
#attestation ⇒ Google::Apis::ContaineranalysisV1beta1::Details
Details of an attestation occurrence.
Corresponds to the JSON property attestation
5717 5718 5719 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5717 def attestation @attestation end |
#build ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails
Details of a build occurrence.
Corresponds to the JSON property build
5722 5723 5724 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5722 def build @build end |
#create_time ⇒ String
Output only. The time this occurrence was created.
Corresponds to the JSON property createTime
5727 5728 5729 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5727 def create_time @create_time end |
#deployment ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DeploymentDetails
Details of a deployment occurrence.
Corresponds to the JSON property deployment
5732 5733 5734 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5732 def deployment @deployment end |
#derived_image ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1ImageDetails
Details of an image occurrence.
Corresponds to the JSON property derivedImage
5737 5738 5739 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5737 def derived_image @derived_image end |
#discovered ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DiscoveryDetails
Details of a discovery occurrence.
Corresponds to the JSON property discovered
5742 5743 5744 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5742 def discovered @discovered end |
#envelope ⇒ Google::Apis::ContaineranalysisV1beta1::Envelope
MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope.
proto. An authenticated message of arbitrary type.
Corresponds to the JSON property envelope
5748 5749 5750 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5748 def envelope @envelope end |
#installation ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1PackageDetails
Details of a package occurrence.
Corresponds to the JSON property installation
5753 5754 5755 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5753 def installation @installation end |
#intoto ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoDetails
This corresponds to a signed in-toto link - it is made up of one or more
signatures and the in-toto link itself. This is used for occurrences of a
Grafeas in-toto note.
Corresponds to the JSON property intoto
5760 5761 5762 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5760 def intoto @intoto end |
#kind ⇒ String
Output only. This explicitly denotes which of the occurrence details are
specified. This field can be used as a filter in list requests.
Corresponds to the JSON property kind
5766 5767 5768 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5766 def kind @kind end |
#name ⇒ String
Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/
occurrences/[OCCURRENCE_ID].
Corresponds to the JSON property name
5772 5773 5774 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5772 def name @name end |
#note_name ⇒ String
Required. Immutable. The analysis note associated with this occurrence, in the
form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a
filter in list requests.
Corresponds to the JSON property noteName
5779 5780 5781 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5779 def note_name @note_name end |
#remediation ⇒ String
A description of actions that can be taken to remedy the note.
Corresponds to the JSON property remediation
5784 5785 5786 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5784 def remediation @remediation end |
#resource ⇒ Google::Apis::ContaineranalysisV1beta1::Resource
An entity that can have metadata. For example, a Docker image.
Corresponds to the JSON property resource
5789 5790 5791 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5789 def resource @resource end |
#sbom ⇒ Google::Apis::ContaineranalysisV1beta1::DocumentOccurrence
DocumentOccurrence represents an SPDX Document Creation Information section:
https://spdx.github.io/spdx-spec/2-document-creation-information/
Corresponds to the JSON property sbom
5795 5796 5797 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5795 def sbom @sbom end |
#sbom_reference ⇒ Google::Apis::ContaineranalysisV1beta1::SbomReferenceOccurrence
The occurrence representing an SBOM reference as applied to a specific
resource. The occurrence follows the DSSE specification. See https://github.
com/secure-systems-lab/dsse/blob/master/envelope.md for more details.
Corresponds to the JSON property sbomReference
5802 5803 5804 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5802 def sbom_reference @sbom_reference end |
#secret ⇒ Google::Apis::ContaineranalysisV1beta1::SecretOccurrence
The occurrence provides details of a secret.
Corresponds to the JSON property secret
5807 5808 5809 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5807 def secret @secret end |
#spdx_file ⇒ Google::Apis::ContaineranalysisV1beta1::FileOccurrence
FileOccurrence represents an SPDX File Information section: https://spdx.
github.io/spdx-spec/4-file-information/
Corresponds to the JSON property spdxFile
5813 5814 5815 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5813 def spdx_file @spdx_file end |
#spdx_package ⇒ Google::Apis::ContaineranalysisV1beta1::PackageInfoOccurrence
PackageInfoOccurrence represents an SPDX Package Information section: https://
spdx.github.io/spdx-spec/3-package-information/
Corresponds to the JSON property spdxPackage
5819 5820 5821 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5819 def spdx_package @spdx_package end |
#spdx_relationship ⇒ Google::Apis::ContaineranalysisV1beta1::RelationshipOccurrence
RelationshipOccurrence represents an SPDX Relationship section: https://spdx.
github.io/spdx-spec/7-relationships-between-SPDX-elements/
Corresponds to the JSON property spdxRelationship
5825 5826 5827 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5825 def spdx_relationship @spdx_relationship end |
#update_time ⇒ String
Output only. The time this occurrence was last updated.
Corresponds to the JSON property updateTime
5830 5831 5832 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5830 def update_time @update_time end |
#vulnerability ⇒ Google::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails
Details of a vulnerability Occurrence.
Corresponds to the JSON property vulnerability
5835 5836 5837 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5835 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5842 def update!(**args) @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis) @attestation = args[:attestation] if args.key?(:attestation) @build = args[:build] if args.key?(:build) @create_time = args[:create_time] if args.key?(:create_time) @deployment = args[:deployment] if args.key?(:deployment) @derived_image = args[:derived_image] if args.key?(:derived_image) @discovered = args[:discovered] if args.key?(:discovered) @envelope = args[:envelope] if args.key?(:envelope) @installation = args[:installation] if args.key?(:installation) @intoto = args[:intoto] if args.key?(:intoto) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @note_name = args[:note_name] if args.key?(:note_name) @remediation = args[:remediation] if args.key?(:remediation) @resource = args[:resource] if args.key?(:resource) @sbom = args[:sbom] if args.key?(:sbom) @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference) @secret = args[:secret] if args.key?(:secret) @spdx_file = args[:spdx_file] if args.key?(:spdx_file) @spdx_package = args[:spdx_package] if args.key?(:spdx_package) @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship) @update_time = args[:update_time] if args.key?(:update_time) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |