Class: Google::Apis::ContaineranalysisV1beta1::Occurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

An instance of an analysis type that has been found on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Occurrence

Returns a new instance of Occurrence.



5824
5825
5826
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_skill_analysisGoogle::Apis::ContaineranalysisV1beta1::AiSkillAnalysisOccurrence

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis. Corresponds to the JSON property aiSkillAnalysis



5699
5700
5701
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5699

def ai_skill_analysis
  @ai_skill_analysis
end

#attestationGoogle::Apis::ContaineranalysisV1beta1::Details

Details of an attestation occurrence. Corresponds to the JSON property attestation



5704
5705
5706
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5704

def attestation
  @attestation
end

#buildGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1BuildDetails

Details of a build occurrence. Corresponds to the JSON property build



5709
5710
5711
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5709

def build
  @build
end

#create_timeString

Output only. The time this occurrence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5714
5715
5716
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5714

def create_time
  @create_time
end

#deploymentGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DeploymentDetails

Details of a deployment occurrence. Corresponds to the JSON property deployment



5719
5720
5721
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5719

def deployment
  @deployment
end

#derived_imageGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1ImageDetails

Details of an image occurrence. Corresponds to the JSON property derivedImage



5724
5725
5726
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5724

def derived_image
  @derived_image
end

#discoveredGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1DiscoveryDetails

Details of a discovery occurrence. Corresponds to the JSON property discovered



5729
5730
5731
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5729

def discovered
  @discovered
end

#envelopeGoogle::Apis::ContaineranalysisV1beta1::Envelope

MUST match https://github.com/secure-systems-lab/dsse/blob/master/envelope. proto. An authenticated message of arbitrary type. Corresponds to the JSON property envelope



5735
5736
5737
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5735

def envelope
  @envelope
end

#installationGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1PackageDetails

Details of a package occurrence. Corresponds to the JSON property installation



5740
5741
5742
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5740

def installation
  @installation
end

#intotoGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1IntotoDetails

This corresponds to a signed in-toto link - it is made up of one or more signatures and the in-toto link itself. This is used for occurrences of a Grafeas in-toto note. Corresponds to the JSON property intoto



5747
5748
5749
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5747

def intoto
  @intoto
end

#kindString

Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests. Corresponds to the JSON property kind

Returns:

  • (String)


5753
5754
5755
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5753

def kind
  @kind
end

#nameString

Output only. The name of the occurrence in the form of projects/[PROJECT_ID]/ occurrences/[OCCURRENCE_ID]. Corresponds to the JSON property name

Returns:

  • (String)


5759
5760
5761
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5759

def name
  @name
end

#note_nameString

Required. Immutable. The analysis note associated with this occurrence, in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be used as a filter in list requests. Corresponds to the JSON property noteName

Returns:

  • (String)


5766
5767
5768
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5766

def note_name
  @note_name
end

#remediationString

A description of actions that can be taken to remedy the note. Corresponds to the JSON property remediation

Returns:

  • (String)


5771
5772
5773
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5771

def remediation
  @remediation
end

#resourceGoogle::Apis::ContaineranalysisV1beta1::Resource

An entity that can have metadata. For example, a Docker image. Corresponds to the JSON property resource



5776
5777
5778
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5776

def resource
  @resource
end

#sbomGoogle::Apis::ContaineranalysisV1beta1::DocumentOccurrence

DocumentOccurrence represents an SPDX Document Creation Information section: https://spdx.github.io/spdx-spec/2-document-creation-information/ Corresponds to the JSON property sbom



5782
5783
5784
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5782

def sbom
  @sbom
end

#sbom_referenceGoogle::Apis::ContaineranalysisV1beta1::SbomReferenceOccurrence

The occurrence representing an SBOM reference as applied to a specific resource. The occurrence follows the DSSE specification. See https://github. com/secure-systems-lab/dsse/blob/master/envelope.md for more details. Corresponds to the JSON property sbomReference



5789
5790
5791
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5789

def sbom_reference
  @sbom_reference
end

#secretGoogle::Apis::ContaineranalysisV1beta1::SecretOccurrence

The occurrence provides details of a secret. Corresponds to the JSON property secret



5794
5795
5796
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5794

def secret
  @secret
end

#spdx_fileGoogle::Apis::ContaineranalysisV1beta1::FileOccurrence

FileOccurrence represents an SPDX File Information section: https://spdx. github.io/spdx-spec/4-file-information/ Corresponds to the JSON property spdxFile



5800
5801
5802
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5800

def spdx_file
  @spdx_file
end

#spdx_packageGoogle::Apis::ContaineranalysisV1beta1::PackageInfoOccurrence

PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/ Corresponds to the JSON property spdxPackage



5806
5807
5808
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5806

def spdx_package
  @spdx_package
end

#spdx_relationshipGoogle::Apis::ContaineranalysisV1beta1::RelationshipOccurrence

RelationshipOccurrence represents an SPDX Relationship section: https://spdx. github.io/spdx-spec/7-relationships-between-SPDX-elements/ Corresponds to the JSON property spdxRelationship



5812
5813
5814
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5812

def spdx_relationship
  @spdx_relationship
end

#update_timeString

Output only. The time this occurrence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5817
5818
5819
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5817

def update_time
  @update_time
end

#vulnerabilityGoogle::Apis::ContaineranalysisV1beta1::GrafeasV1beta1VulnerabilityDetails

Details of a vulnerability Occurrence. Corresponds to the JSON property vulnerability



5822
5823
5824
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5822

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5829

def update!(**args)
  @ai_skill_analysis = args[:ai_skill_analysis] if args.key?(:ai_skill_analysis)
  @attestation = args[:attestation] if args.key?(:attestation)
  @build = args[:build] if args.key?(:build)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment = args[:deployment] if args.key?(:deployment)
  @derived_image = args[:derived_image] if args.key?(:derived_image)
  @discovered = args[:discovered] if args.key?(:discovered)
  @envelope = args[:envelope] if args.key?(:envelope)
  @installation = args[:installation] if args.key?(:installation)
  @intoto = args[:intoto] if args.key?(:intoto)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @note_name = args[:note_name] if args.key?(:note_name)
  @remediation = args[:remediation] if args.key?(:remediation)
  @resource = args[:resource] if args.key?(:resource)
  @sbom = args[:sbom] if args.key?(:sbom)
  @sbom_reference = args[:sbom_reference] if args.key?(:sbom_reference)
  @secret = args[:secret] if args.key?(:secret)
  @spdx_file = args[:spdx_file] if args.key?(:spdx_file)
  @spdx_package = args[:spdx_package] if args.key?(:spdx_package)
  @spdx_relationship = args[:spdx_relationship] if args.key?(:spdx_relationship)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end