Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/
Instance Attribute Summary collapse
-
#analyzed ⇒ Boolean
(also: #analyzed?)
Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property
analyzed. -
#attribution ⇒ String
A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property
attribution. -
#checksum ⇒ String
Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property
checksum. -
#copyright ⇒ String
Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property
copyright. -
#detailed_description ⇒ String
A more detailed description of the package Corresponds to the JSON property
detailedDescription. -
#download_location ⇒ String
This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property
downloadLocation. -
#external_refs ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ExternalRef>
ExternalRef Corresponds to the JSON property
externalRefs. -
#files_license_info ⇒ Array<String>
Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package.
-
#home_page ⇒ String
Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property
homePage. -
#license_declared ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
-
#originator ⇒ String
If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property
originator. -
#package_type ⇒ String
The type of package: OS, MAVEN, GO, GO_STDLIB, etc.
-
#summary_description ⇒ String
A short description of the package Corresponds to the JSON property
summaryDescription. -
#supplier ⇒ String
Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property
supplier. -
#title ⇒ String
Identify the full name of the package as given by the Package Originator Corresponds to the JSON property
title. -
#verification_code ⇒ String
This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property
verificationCode. -
#version ⇒ String
Identify the version of the package Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageInfoNote
constructor
A new instance of PackageInfoNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageInfoNote
Returns a new instance of PackageInfoNote.
6130 6131 6132 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analyzed ⇒ Boolean Also known as: analyzed?
Indicates whether the file content of this package has been available for or
subjected to analysis when creating the SPDX document
Corresponds to the JSON property analyzed
6032 6033 6034 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6032 def analyzed @analyzed end |
#attribution ⇒ String
A place for the SPDX data creator to record, at the package level,
acknowledgements that may be needed to be communicated in some contexts
Corresponds to the JSON property attribution
6039 6040 6041 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6039 def attribution @attribution end |
#checksum ⇒ String
Provide an independently reproducible mechanism that permits unique
identification of a specific package that correlates to the data in this SPDX
file
Corresponds to the JSON property checksum
6046 6047 6048 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6046 def checksum @checksum end |
#copyright ⇒ String
Identify the copyright holders of the package, as well as any dates present
Corresponds to the JSON property copyright
6051 6052 6053 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6051 def copyright @copyright end |
#detailed_description ⇒ String
A more detailed description of the package
Corresponds to the JSON property detailedDescription
6056 6057 6058 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6056 def detailed_description @detailed_description end |
#download_location ⇒ String
This section identifies the download Universal Resource Locator (URL), or a
specific location within a version control system (VCS) for the package at the
time that the SPDX file was created
Corresponds to the JSON property downloadLocation
6063 6064 6065 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6063 def download_location @download_location end |
#external_refs ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ExternalRef>
ExternalRef
Corresponds to the JSON property externalRefs
6068 6069 6070 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6068 def external_refs @external_refs end |
#files_license_info ⇒ Array<String>
Contain the license the SPDX file creator has concluded as governing the This
field is to contain a list of all licenses found in the package. The
relationship between licenses (i.e., conjunctive, disjunctive) is not
specified in this field – it is simply a listing of all licenses found
Corresponds to the JSON property filesLicenseInfo
6076 6077 6078 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6076 def files_license_info @files_license_info end |
#home_page ⇒ String
Provide a place for the SPDX file creator to record a web site that serves as
the package's home page
Corresponds to the JSON property homePage
6082 6083 6084 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6082 def home_page @home_page end |
#license_declared ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
Corresponds to the JSON property licenseDeclared
6087 6088 6089 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6087 def license_declared @license_declared end |
#originator ⇒ String
If the package identified in the SPDX file originated from a different person
or organization than identified as Package Supplier, this field identifies
from where or whom the package originally came
Corresponds to the JSON property originator
6094 6095 6096 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6094 def originator @originator end |
#package_type ⇒ String
The type of package: OS, MAVEN, GO, GO_STDLIB, etc.
Corresponds to the JSON property packageType
6099 6100 6101 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6099 def package_type @package_type end |
#summary_description ⇒ String
A short description of the package
Corresponds to the JSON property summaryDescription
6104 6105 6106 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6104 def summary_description @summary_description end |
#supplier ⇒ String
Identify the actual distribution source for the package/directory identified
in the SPDX file
Corresponds to the JSON property supplier
6110 6111 6112 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6110 def supplier @supplier end |
#title ⇒ String
Identify the full name of the package as given by the Package Originator
Corresponds to the JSON property title
6115 6116 6117 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6115 def title @title end |
#verification_code ⇒ String
This field provides an independently reproducible mechanism identifying
specific contents of a package based on the actual files (except the SPDX file
itself, if it is included in the package) that make up each package and that
correlates to the data in this SPDX file
Corresponds to the JSON property verificationCode
6123 6124 6125 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6123 def verification_code @verification_code end |
#version ⇒ String
Identify the version of the package
Corresponds to the JSON property version
6128 6129 6130 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6128 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6135 6136 6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6135 def update!(**args) @analyzed = args[:analyzed] if args.key?(:analyzed) @attribution = args[:attribution] if args.key?(:attribution) @checksum = args[:checksum] if args.key?(:checksum) @copyright = args[:copyright] if args.key?(:copyright) @detailed_description = args[:detailed_description] if args.key?(:detailed_description) @download_location = args[:download_location] if args.key?(:download_location) @external_refs = args[:external_refs] if args.key?(:external_refs) @files_license_info = args[:files_license_info] if args.key?(:files_license_info) @home_page = args[:home_page] if args.key?(:home_page) @license_declared = args[:license_declared] if args.key?(:license_declared) @originator = args[:originator] if args.key?(:originator) @package_type = args[:package_type] if args.key?(:package_type) @summary_description = args[:summary_description] if args.key?(:summary_description) @supplier = args[:supplier] if args.key?(:supplier) @title = args[:title] if args.key?(:title) @verification_code = args[:verification_code] if args.key?(:verification_code) @version = args[:version] if args.key?(:version) end |