Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoNote

Returns a new instance of PackageInfoNote.



6124
6125
6126
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzedBoolean Also known as: analyzed?

Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property analyzed

Returns:

  • (Boolean)


6026
6027
6028
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6026

def analyzed
  @analyzed
end

#attributionString

A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attribution

Returns:

  • (String)


6033
6034
6035
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6033

def attribution
  @attribution
end

#checksumString

Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property checksum

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6040

def checksum
  @checksum
end

Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


6045
6046
6047
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6045

def copyright
  @copyright
end

#detailed_descriptionString

A more detailed description of the package Corresponds to the JSON property detailedDescription

Returns:

  • (String)


6050
6051
6052
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6050

def detailed_description
  @detailed_description
end

#download_locationString

This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property downloadLocation

Returns:

  • (String)


6057
6058
6059
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6057

def download_location
  @download_location
end

#external_refsArray<Google::Apis::ContaineranalysisV1beta1::ExternalRef>

ExternalRef Corresponds to the JSON property externalRefs



6062
6063
6064
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6062

def external_refs
  @external_refs
end

#files_license_infoArray<String>

Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package. The relationship between licenses (i.e., conjunctive, disjunctive) is not specified in this field – it is simply a listing of all licenses found Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


6070
6071
6072
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6070

def files_license_info
  @files_license_info
end

#home_pageString

Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6076
6077
6078
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6076

def home_page
  @home_page
end

#license_declaredGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseDeclared



6081
6082
6083
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6081

def license_declared
  @license_declared
end

#originatorString

If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property originator

Returns:

  • (String)


6088
6089
6090
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6088

def originator
  @originator
end

#package_typeString

The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6093
6094
6095
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6093

def package_type
  @package_type
end

#summary_descriptionString

A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6098
6099
6100
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6098

def summary_description
  @summary_description
end

#supplierString

Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property supplier

Returns:

  • (String)


6104
6105
6106
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6104

def supplier
  @supplier
end

#titleString

Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6109
6110
6111
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6109

def title
  @title
end

#verification_codeString

This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property verificationCode

Returns:

  • (String)


6117
6118
6119
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6117

def verification_code
  @verification_code
end

#versionString

Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6122
6123
6124
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6122

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6129
6130
6131
6132
6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6129

def update!(**args)
  @analyzed = args[:analyzed] if args.key?(:analyzed)
  @attribution = args[:attribution] if args.key?(:attribution)
  @checksum = args[:checksum] if args.key?(:checksum)
  @copyright = args[:copyright] if args.key?(:copyright)
  @detailed_description = args[:detailed_description] if args.key?(:detailed_description)
  @download_location = args[:download_location] if args.key?(:download_location)
  @external_refs = args[:external_refs] if args.key?(:external_refs)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @home_page = args[:home_page] if args.key?(:home_page)
  @license_declared = args[:license_declared] if args.key?(:license_declared)
  @originator = args[:originator] if args.key?(:originator)
  @package_type = args[:package_type] if args.key?(:package_type)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @supplier = args[:supplier] if args.key?(:supplier)
  @title = args[:title] if args.key?(:title)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
  @version = args[:version] if args.key?(:version)
end