Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoNote

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoNote

Returns a new instance of PackageInfoNote.



6106
6107
6108
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzedBoolean Also known as: analyzed?

Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property analyzed

Returns:

  • (Boolean)


6008
6009
6010
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6008

def analyzed
  @analyzed
end

#attributionString

A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property attribution

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6015

def attribution
  @attribution
end

#checksumString

Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property checksum

Returns:

  • (String)


6022
6023
6024
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6022

def checksum
  @checksum
end

Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property copyright

Returns:

  • (String)


6027
6028
6029
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6027

def copyright
  @copyright
end

#detailed_descriptionString

A more detailed description of the package Corresponds to the JSON property detailedDescription

Returns:

  • (String)


6032
6033
6034
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6032

def detailed_description
  @detailed_description
end

#download_locationString

This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property downloadLocation

Returns:

  • (String)


6039
6040
6041
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6039

def download_location
  @download_location
end

#external_refsArray<Google::Apis::ContaineranalysisV1beta1::ExternalRef>

ExternalRef Corresponds to the JSON property externalRefs



6044
6045
6046
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6044

def external_refs
  @external_refs
end

#files_license_infoArray<String>

Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package. The relationship between licenses (i.e., conjunctive, disjunctive) is not specified in this field – it is simply a listing of all licenses found Corresponds to the JSON property filesLicenseInfo

Returns:

  • (Array<String>)


6052
6053
6054
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6052

def files_license_info
  @files_license_info
end

#home_pageString

Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6058
6059
6060
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6058

def home_page
  @home_page
end

#license_declaredGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseDeclared



6063
6064
6065
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6063

def license_declared
  @license_declared
end

#originatorString

If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property originator

Returns:

  • (String)


6070
6071
6072
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6070

def originator
  @originator
end

#package_typeString

The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6075
6076
6077
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6075

def package_type
  @package_type
end

#summary_descriptionString

A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6080
6081
6082
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6080

def summary_description
  @summary_description
end

#supplierString

Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property supplier

Returns:

  • (String)


6086
6087
6088
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6086

def supplier
  @supplier
end

#titleString

Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6091
6092
6093
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6091

def title
  @title
end

#verification_codeString

This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property verificationCode

Returns:

  • (String)


6099
6100
6101
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6099

def verification_code
  @verification_code
end

#versionString

Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6104
6105
6106
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6104

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6111
6112
6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6111

def update!(**args)
  @analyzed = args[:analyzed] if args.key?(:analyzed)
  @attribution = args[:attribution] if args.key?(:attribution)
  @checksum = args[:checksum] if args.key?(:checksum)
  @copyright = args[:copyright] if args.key?(:copyright)
  @detailed_description = args[:detailed_description] if args.key?(:detailed_description)
  @download_location = args[:download_location] if args.key?(:download_location)
  @external_refs = args[:external_refs] if args.key?(:external_refs)
  @files_license_info = args[:files_license_info] if args.key?(:files_license_info)
  @home_page = args[:home_page] if args.key?(:home_page)
  @license_declared = args[:license_declared] if args.key?(:license_declared)
  @originator = args[:originator] if args.key?(:originator)
  @package_type = args[:package_type] if args.key?(:package_type)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @supplier = args[:supplier] if args.key?(:supplier)
  @title = args[:title] if args.key?(:title)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
  @version = args[:version] if args.key?(:version)
end