Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::PackageInfoNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
PackageInfoNote represents an SPDX Package Information section: https://spdx. github.io/spdx-spec/3-package-information/
Instance Attribute Summary collapse
-
#analyzed ⇒ Boolean
(also: #analyzed?)
Indicates whether the file content of this package has been available for or subjected to analysis when creating the SPDX document Corresponds to the JSON property
analyzed. -
#attribution ⇒ String
A place for the SPDX data creator to record, at the package level, acknowledgements that may be needed to be communicated in some contexts Corresponds to the JSON property
attribution. -
#checksum ⇒ String
Provide an independently reproducible mechanism that permits unique identification of a specific package that correlates to the data in this SPDX file Corresponds to the JSON property
checksum. -
#copyright ⇒ String
Identify the copyright holders of the package, as well as any dates present Corresponds to the JSON property
copyright. -
#detailed_description ⇒ String
A more detailed description of the package Corresponds to the JSON property
detailedDescription. -
#download_location ⇒ String
This section identifies the download Universal Resource Locator (URL), or a specific location within a version control system (VCS) for the package at the time that the SPDX file was created Corresponds to the JSON property
downloadLocation. -
#external_refs ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ExternalRef>
ExternalRef Corresponds to the JSON property
externalRefs. -
#files_license_info ⇒ Array<String>
Contain the license the SPDX file creator has concluded as governing the This field is to contain a list of all licenses found in the package.
-
#home_page ⇒ String
Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property
homePage. -
#license_declared ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
-
#originator ⇒ String
If the package identified in the SPDX file originated from a different person or organization than identified as Package Supplier, this field identifies from where or whom the package originally came Corresponds to the JSON property
originator. -
#package_type ⇒ String
The type of package: OS, MAVEN, GO, GO_STDLIB, etc.
-
#summary_description ⇒ String
A short description of the package Corresponds to the JSON property
summaryDescription. -
#supplier ⇒ String
Identify the actual distribution source for the package/directory identified in the SPDX file Corresponds to the JSON property
supplier. -
#title ⇒ String
Identify the full name of the package as given by the Package Originator Corresponds to the JSON property
title. -
#verification_code ⇒ String
This field provides an independently reproducible mechanism identifying specific contents of a package based on the actual files (except the SPDX file itself, if it is included in the package) that make up each package and that correlates to the data in this SPDX file Corresponds to the JSON property
verificationCode. -
#version ⇒ String
Identify the version of the package Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageInfoNote
constructor
A new instance of PackageInfoNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageInfoNote
Returns a new instance of PackageInfoNote.
5700 5701 5702 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analyzed ⇒ Boolean Also known as: analyzed?
Indicates whether the file content of this package has been available for or
subjected to analysis when creating the SPDX document
Corresponds to the JSON property analyzed
5602 5603 5604 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5602 def analyzed @analyzed end |
#attribution ⇒ String
A place for the SPDX data creator to record, at the package level,
acknowledgements that may be needed to be communicated in some contexts
Corresponds to the JSON property attribution
5609 5610 5611 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5609 def attribution @attribution end |
#checksum ⇒ String
Provide an independently reproducible mechanism that permits unique
identification of a specific package that correlates to the data in this SPDX
file
Corresponds to the JSON property checksum
5616 5617 5618 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5616 def checksum @checksum end |
#copyright ⇒ String
Identify the copyright holders of the package, as well as any dates present
Corresponds to the JSON property copyright
5621 5622 5623 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5621 def copyright @copyright end |
#detailed_description ⇒ String
A more detailed description of the package
Corresponds to the JSON property detailedDescription
5626 5627 5628 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5626 def detailed_description @detailed_description end |
#download_location ⇒ String
This section identifies the download Universal Resource Locator (URL), or a
specific location within a version control system (VCS) for the package at the
time that the SPDX file was created
Corresponds to the JSON property downloadLocation
5633 5634 5635 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5633 def download_location @download_location end |
#external_refs ⇒ Array<Google::Apis::ContaineranalysisV1beta1::ExternalRef>
ExternalRef
Corresponds to the JSON property externalRefs
5638 5639 5640 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5638 def external_refs @external_refs end |
#files_license_info ⇒ Array<String>
Contain the license the SPDX file creator has concluded as governing the This
field is to contain a list of all licenses found in the package. The
relationship between licenses (i.e., conjunctive, disjunctive) is not
specified in this field – it is simply a listing of all licenses found
Corresponds to the JSON property filesLicenseInfo
5646 5647 5648 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5646 def files_license_info @files_license_info end |
#home_page ⇒ String
Provide a place for the SPDX file creator to record a web site that serves as
the package's home page
Corresponds to the JSON property homePage
5652 5653 5654 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5652 def home_page @home_page end |
#license_declared ⇒ Google::Apis::ContaineranalysisV1beta1::License
License information.
Corresponds to the JSON property licenseDeclared
5657 5658 5659 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5657 def license_declared @license_declared end |
#originator ⇒ String
If the package identified in the SPDX file originated from a different person
or organization than identified as Package Supplier, this field identifies
from where or whom the package originally came
Corresponds to the JSON property originator
5664 5665 5666 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5664 def originator @originator end |
#package_type ⇒ String
The type of package: OS, MAVEN, GO, GO_STDLIB, etc.
Corresponds to the JSON property packageType
5669 5670 5671 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5669 def package_type @package_type end |
#summary_description ⇒ String
A short description of the package
Corresponds to the JSON property summaryDescription
5674 5675 5676 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5674 def summary_description @summary_description end |
#supplier ⇒ String
Identify the actual distribution source for the package/directory identified
in the SPDX file
Corresponds to the JSON property supplier
5680 5681 5682 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5680 def supplier @supplier end |
#title ⇒ String
Identify the full name of the package as given by the Package Originator
Corresponds to the JSON property title
5685 5686 5687 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5685 def title @title end |
#verification_code ⇒ String
This field provides an independently reproducible mechanism identifying
specific contents of a package based on the actual files (except the SPDX file
itself, if it is included in the package) that make up each package and that
correlates to the data in this SPDX file
Corresponds to the JSON property verificationCode
5693 5694 5695 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5693 def verification_code @verification_code end |
#version ⇒ String
Identify the version of the package
Corresponds to the JSON property version
5698 5699 5700 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5698 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 5716 5717 5718 5719 5720 5721 5722 5723 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5705 def update!(**args) @analyzed = args[:analyzed] if args.key?(:analyzed) @attribution = args[:attribution] if args.key?(:attribution) @checksum = args[:checksum] if args.key?(:checksum) @copyright = args[:copyright] if args.key?(:copyright) @detailed_description = args[:detailed_description] if args.key?(:detailed_description) @download_location = args[:download_location] if args.key?(:download_location) @external_refs = args[:external_refs] if args.key?(:external_refs) @files_license_info = args[:files_license_info] if args.key?(:files_license_info) @home_page = args[:home_page] if args.key?(:home_page) @license_declared = args[:license_declared] if args.key?(:license_declared) @originator = args[:originator] if args.key?(:originator) @package_type = args[:package_type] if args.key?(:package_type) @summary_description = args[:summary_description] if args.key?(:summary_description) @supplier = args[:supplier] if args.key?(:supplier) @title = args[:title] if args.key?(:title) @verification_code = args[:verification_code] if args.key?(:verification_code) @version = args[:version] if args.key?(:version) end |