Class: Google::Apis::ContaineranalysisV1beta1::PackageInfoOccurrence

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

PackageInfoOccurrence represents an SPDX Package Information section: https:// spdx.github.io/spdx-spec/3-package-information/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageInfoOccurrence

Returns a new instance of PackageInfoOccurrence.



6217
6218
6219
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

A place for the SPDX file creator to record any general comments about the package being described Corresponds to the JSON property comment

Returns:

  • (String)


6165
6166
6167
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6165

def comment
  @comment
end

#filenameString

Provide the actual file name of the package, or path of the directory being treated as a package Corresponds to the JSON property filename

Returns:

  • (String)


6171
6172
6173
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6171

def filename
  @filename
end

#home_pageString

Output only. Provide a place for the SPDX file creator to record a web site that serves as the package's home page Corresponds to the JSON property homePage

Returns:

  • (String)


6177
6178
6179
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6177

def home_page
  @home_page
end

#idString

Uniquely identify any element in an SPDX document which may be referenced by other elements Corresponds to the JSON property id

Returns:

  • (String)


6183
6184
6185
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6183

def id
  @id
end

#license_concludedGoogle::Apis::ContaineranalysisV1beta1::License

License information. Corresponds to the JSON property licenseConcluded



6188
6189
6190
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6188

def license_concluded
  @license_concluded
end

#package_typeString

Output only. The type of package: OS, MAVEN, GO, GO_STDLIB, etc. Corresponds to the JSON property packageType

Returns:

  • (String)


6193
6194
6195
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6193

def package_type
  @package_type
end

#source_infoString

Provide a place for the SPDX file creator to record any relevant background information or additional comments about the origin of the package Corresponds to the JSON property sourceInfo

Returns:

  • (String)


6199
6200
6201
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6199

def source_info
  @source_info
end

#summary_descriptionString

Output only. A short description of the package Corresponds to the JSON property summaryDescription

Returns:

  • (String)


6204
6205
6206
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6204

def summary_description
  @summary_description
end

#titleString

Output only. Identify the full name of the package as given by the Package Originator Corresponds to the JSON property title

Returns:

  • (String)


6210
6211
6212
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6210

def title
  @title
end

#versionString

Output only. Identify the version of the package Corresponds to the JSON property version

Returns:

  • (String)


6215
6216
6217
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6215

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6222

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @filename = args[:filename] if args.key?(:filename)
  @home_page = args[:home_page] if args.key?(:home_page)
  @id = args[:id] if args.key?(:id)
  @license_concluded = args[:license_concluded] if args.key?(:license_concluded)
  @package_type = args[:package_type] if args.key?(:package_type)
  @source_info = args[:source_info] if args.key?(:source_info)
  @summary_description = args[:summary_description] if args.key?(:summary_description)
  @title = args[:title] if args.key?(:title)
  @version = args[:version] if args.key?(:version)
end