Class: Google::Apis::ContaineranalysisV1beta1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



6263
6264
6265
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1beta1::VulnerabilityLocation

The location of the vulnerability. Corresponds to the JSON property affectedLocation



6238
6239
6240
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6238

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


6245
6246
6247
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6245

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1beta1::VulnerabilityLocation

The location of the vulnerability. Corresponds to the JSON property fixedLocation



6250
6251
6252
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6250

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6255

def package_type
  @package_type
end

#severity_nameString

Deprecated, use Details.effective_severity instead The severity (e.g., distro assigned severity) for this vulnerability. Corresponds to the JSON property severityName

Returns:

  • (String)


6261
6262
6263
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6261

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6268
6269
6270
6271
6272
6273
6274
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6268

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end