Class: Google::Apis::ContaineranalysisV1beta1::PackageIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::PackageIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
This message wraps a location affected by a vulnerability and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
-
#effective_severity ⇒ String
Output only.
-
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
-
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
-
#severity_name ⇒ String
Deprecated, use Details.effective_severity instead The severity (e.g., distro assigned severity) for this vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageIssue
constructor
A new instance of PackageIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageIssue
Returns a new instance of PackageIssue.
6245 6246 6247 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
Corresponds to the JSON property affectedLocation
6220 6221 6222 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6220 def affected_location @affected_location end |
#effective_severity ⇒ String
Output only. The distro or language system assigned severity for this
vulnerability when that is available and note provider assigned severity when
it is not available.
Corresponds to the JSON property effectiveSeverity
6227 6228 6229 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6227 def effective_severity @effective_severity end |
#fixed_location ⇒ Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
The location of the vulnerability.
Corresponds to the JSON property fixedLocation
6232 6233 6234 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6232 def fixed_location @fixed_location end |
#package_type ⇒ String
The type of package (e.g. OS, MAVEN, GO).
Corresponds to the JSON property packageType
6237 6238 6239 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6237 def package_type @package_type end |
#severity_name ⇒ String
Deprecated, use Details.effective_severity instead The severity (e.g., distro
assigned severity) for this vulnerability.
Corresponds to the JSON property severityName
6243 6244 6245 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6243 def severity_name @severity_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6250 6251 6252 6253 6254 6255 6256 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6250 def update!(**args) @affected_location = args[:affected_location] if args.key?(:affected_location) @effective_severity = args[:effective_severity] if args.key?(:effective_severity) @fixed_location = args[:fixed_location] if args.key?(:fixed_location) @package_type = args[:package_type] if args.key?(:package_type) @severity_name = args[:severity_name] if args.key?(:severity_name) end |