Class: Google::Apis::ContaineranalysisV1beta1::PackageIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

This message wraps a location affected by a vulnerability and its associated fix (if one is available).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageIssue

Returns a new instance of PackageIssue.



5851
5852
5853
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_locationGoogle::Apis::ContaineranalysisV1beta1::VulnerabilityLocation

The location of the vulnerability. Corresponds to the JSON property affectedLocation



5826
5827
5828
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5826

def affected_location
  @affected_location
end

#effective_severityString

Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available. Corresponds to the JSON property effectiveSeverity

Returns:

  • (String)


5833
5834
5835
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5833

def effective_severity
  @effective_severity
end

#fixed_locationGoogle::Apis::ContaineranalysisV1beta1::VulnerabilityLocation

The location of the vulnerability. Corresponds to the JSON property fixedLocation



5838
5839
5840
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5838

def fixed_location
  @fixed_location
end

#package_typeString

The type of package (e.g. OS, MAVEN, GO). Corresponds to the JSON property packageType

Returns:

  • (String)


5843
5844
5845
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5843

def package_type
  @package_type
end

#severity_nameString

Deprecated, use Details.effective_severity instead The severity (e.g., distro assigned severity) for this vulnerability. Corresponds to the JSON property severityName

Returns:

  • (String)


5849
5850
5851
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5849

def severity_name
  @severity_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5856
5857
5858
5859
5860
5861
5862
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 5856

def update!(**args)
  @affected_location = args[:affected_location] if args.key?(:affected_location)
  @effective_severity = args[:effective_severity] if args.key?(:effective_severity)
  @fixed_location = args[:fixed_location] if args.key?(:fixed_location)
  @package_type = args[:package_type] if args.key?(:package_type)
  @severity_name = args[:severity_name] if args.key?(:severity_name)
end