Class: Google::Apis::ContaineranalysisV1beta1::PackagesSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A summary of the packages found within the given resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackagesSummaryResponse

Returns a new instance of PackagesSummaryResponse.



6214
6215
6216
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#licenses_summaryArray<Google::Apis::ContaineranalysisV1beta1::LicensesSummary>

A listing by license name of each of the licenses and their counts. Corresponds to the JSON property licensesSummary



6207
6208
6209
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6207

def licenses_summary
  @licenses_summary
end

#resource_urlString

The unique URL of the image or the container for which this summary applies. Corresponds to the JSON property resourceUrl

Returns:

  • (String)


6212
6213
6214
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6212

def resource_url
  @resource_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6219
6220
6221
6222
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6219

def update!(**args)
  @licenses_summary = args[:licenses_summary] if args.key?(:licenses_summary)
  @resource_url = args[:resource_url] if args.key?(:resource_url)
end