Class: Google::Apis::ContaineranalysisV1beta1::Publisher
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Publisher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Publisher contains information about the publisher of this Note.
Instance Attribute Summary collapse
-
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the document, in particular, the party's constituency and responsibilities or other obligations.
-
#name ⇒ String
Name of the publisher.
-
#publisher_namespace ⇒ String
The context or namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publisher
constructor
A new instance of Publisher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publisher
Returns a new instance of Publisher.
6540 6541 6542 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issuing_authority ⇒ String
Provides information about the authority of the issuing party to release the
document, in particular, the party's constituency and responsibilities or
other obligations.
Corresponds to the JSON property issuingAuthority
6526 6527 6528 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6526 def @issuing_authority end |
#name ⇒ String
Name of the publisher. Examples: 'Google', 'Google Cloud Platform'.
Corresponds to the JSON property name
6531 6532 6533 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6531 def name @name end |
#publisher_namespace ⇒ String
The context or namespace. Contains a URL which is under control of the issuing
party and can be used as a globally unique identifier for that issuing party.
Example: https://csaf.io
Corresponds to the JSON property publisherNamespace
6538 6539 6540 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6538 def publisher_namespace @publisher_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6545 6546 6547 6548 6549 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6545 def update!(**args) @issuing_authority = args[:issuing_authority] if args.key?(:issuing_authority) @name = args[:name] if args.key?(:name) @publisher_namespace = args[:publisher_namespace] if args.key?(:publisher_namespace) end |