Class: Google::Apis::ContaineranalysisV1beta1::Publisher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Publisher contains information about the publisher of this Note.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publisher

Returns a new instance of Publisher.



6146
6147
6148
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#issuing_authorityString

Provides information about the authority of the issuing party to release the document, in particular, the party's constituency and responsibilities or other obligations. Corresponds to the JSON property issuingAuthority

Returns:

  • (String)


6132
6133
6134
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6132

def issuing_authority
  @issuing_authority
end

#nameString

Name of the publisher. Examples: 'Google', 'Google Cloud Platform'. Corresponds to the JSON property name

Returns:

  • (String)


6137
6138
6139
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6137

def name
  @name
end

#publisher_namespaceString

The context or namespace. Contains a URL which is under control of the issuing party and can be used as a globally unique identifier for that issuing party. Example: https://csaf.io Corresponds to the JSON property publisherNamespace

Returns:

  • (String)


6144
6145
6146
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6144

def publisher_namespace
  @publisher_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6151
6152
6153
6154
6155
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6151

def update!(**args)
  @issuing_authority = args[:issuing_authority] if args.key?(:issuing_authority)
  @name = args[:name] if args.key?(:name)
  @publisher_namespace = args[:publisher_namespace] if args.key?(:publisher_namespace)
end