Class: Google::Apis::ContaineranalysisV1beta1::RelationshipOccurrence
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::RelationshipOccurrence
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
RelationshipOccurrence represents an SPDX Relationship section: https://spdx. github.io/spdx-spec/7-relationships-between-SPDX-elements/
Instance Attribute Summary collapse
-
#comment ⇒ String
A place for the SPDX file creator to record any general comments about the relationship Corresponds to the JSON property
comment. -
#source ⇒ String
Also referred to as SPDXRef-A The source SPDX element (file, package, etc) Corresponds to the JSON property
source. -
#target ⇒ String
Also referred to as SPDXRef-B The target SPDC element (file, package, etc) In cases where there are "known unknowns", the use of the keyword NOASSERTION can be used The keywords NONE can be used to indicate that an SPDX element ( package/file/snippet) has no other elements connected by some relationship to it Corresponds to the JSON property
target. -
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelationshipOccurrence
constructor
A new instance of RelationshipOccurrence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelationshipOccurrence
Returns a new instance of RelationshipOccurrence.
6569 6570 6571 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
A place for the SPDX file creator to record any general comments about the
relationship
Corresponds to the JSON property comment
6547 6548 6549 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6547 def comment @comment end |
#source ⇒ String
Also referred to as SPDXRef-A The source SPDX element (file, package, etc)
Corresponds to the JSON property source
6552 6553 6554 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6552 def source @source end |
#target ⇒ String
Also referred to as SPDXRef-B The target SPDC element (file, package, etc) In
cases where there are "known unknowns", the use of the keyword NOASSERTION can
be used The keywords NONE can be used to indicate that an SPDX element (
package/file/snippet) has no other elements connected by some relationship to
it
Corresponds to the JSON property target
6561 6562 6563 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6561 def target @target end |
#type ⇒ String
Output only. The type of relationship between the source and target SPDX
elements
Corresponds to the JSON property type
6567 6568 6569 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6567 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6574 6575 6576 6577 6578 6579 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6574 def update!(**args) @comment = args[:comment] if args.key?(:comment) @source = args[:source] if args.key?(:source) @target = args[:target] if args.key?(:target) @type = args[:type] if args.key?(:type) end |