Class: Google::Apis::ContaineranalysisV1beta1::SbomReferenceIntotoPredicate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A predicate which describes the SBOM being referenced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SbomReferenceIntotoPredicate

Returns a new instance of SbomReferenceIntotoPredicate.



6924
6925
6926
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#digestHash<String,String>

A map of algorithm to digest of the contents of the SBOM. Corresponds to the JSON property digest

Returns:

  • (Hash<String,String>)


6907
6908
6909
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6907

def digest
  @digest
end

#locationString

The location of the SBOM. Corresponds to the JSON property location

Returns:

  • (String)


6912
6913
6914
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6912

def location
  @location
end

#mime_typeString

The mime type of the SBOM. Corresponds to the JSON property mimeType

Returns:

  • (String)


6917
6918
6919
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6917

def mime_type
  @mime_type
end

#referrer_idString

The person or system referring this predicate to the consumer. Corresponds to the JSON property referrerId

Returns:

  • (String)


6922
6923
6924
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6922

def referrer_id
  @referrer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6929
6930
6931
6932
6933
6934
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 6929

def update!(**args)
  @digest = args[:digest] if args.key?(:digest)
  @location = args[:location] if args.key?(:location)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @referrer_id = args[:referrer_id] if args.key?(:referrer_id)
end