Class: Google::Apis::ContaineranalysisV1beta1::Source
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Source
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Source describes the location of the source used for the build.
Instance Attribute Summary collapse
-
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::SourceContext>
If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules.
-
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
-
#context ⇒ Google::Apis::ContaineranalysisV1beta1::SourceContext
A SourceContext is a reference to a tree of files.
-
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
7423 7424 7425 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_contexts ⇒ Array<Google::Apis::ContaineranalysisV1beta1::SourceContext>
If provided, some of the source code used for the build may be found in these
locations, in the case where the source repository had multiple remotes or
submodules. This list will not include the context specified in the context
field.
Corresponds to the JSON property additionalContexts
7401 7402 7403 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7401 def additional_contexts @additional_contexts end |
#artifact_storage_source_uri ⇒ String
If provided, the input binary artifacts for the build came from this location.
Corresponds to the JSON property artifactStorageSourceUri
7406 7407 7408 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7406 def artifact_storage_source_uri @artifact_storage_source_uri end |
#context ⇒ Google::Apis::ContaineranalysisV1beta1::SourceContext
A SourceContext is a reference to a tree of files. A SourceContext together
with a path point to a unique revision of a single file or directory.
Corresponds to the JSON property context
7412 7413 7414 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7412 def context @context end |
#file_hashes ⇒ Hash<String,Google::Apis::ContaineranalysisV1beta1::FileHashes>
Hash(es) of the build source, which can be used to verify that the original
source integrity was maintained in the build. The keys to this map are file
paths used as build source and the values contain the hash values for those
files. If the build source came in a single package such as a gzipped tarfile (
.tar.gz), the FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
7421 7422 7423 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7421 def file_hashes @file_hashes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7428 7429 7430 7431 7432 7433 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7428 def update!(**args) @additional_contexts = args[:additional_contexts] if args.key?(:additional_contexts) @artifact_storage_source_uri = args[:artifact_storage_source_uri] if args.key?(:artifact_storage_source_uri) @context = args[:context] if args.key?(:context) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) end |