Class: Google::Apis::ContaineranalysisV1beta1::Version

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

Version contains structured information about the version of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



7549
7550
7551
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#epochFixnum

Used to correct mistakes in the version numbering scheme. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


7521
7522
7523
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7521

def epoch
  @epoch
end

#inclusiveBoolean Also known as: inclusive?

Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range. Corresponds to the JSON property inclusive

Returns:

  • (Boolean)


7531
7532
7533
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7531

def inclusive
  @inclusive
end

#kindString

Required. Distinguishes between sentinel MIN/MAX versions and normal versions. Corresponds to the JSON property kind

Returns:

  • (String)


7537
7538
7539
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7537

def kind
  @kind
end

#nameString

Required only when version kind is NORMAL. The main part of the version name. Corresponds to the JSON property name

Returns:

  • (String)


7542
7543
7544
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7542

def name
  @name
end

#revisionString

The iteration of the package build from the above version. Corresponds to the JSON property revision

Returns:

  • (String)


7547
7548
7549
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7547

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7554
7555
7556
7557
7558
7559
7560
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7554

def update!(**args)
  @epoch = args[:epoch] if args.key?(:epoch)
  @inclusive = args[:inclusive] if args.key?(:inclusive)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
end