Class: Google::Apis::ContaineranalysisV1beta1::Version
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Version
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Version contains structured information about the version of a package.
Instance Attribute Summary collapse
-
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
-
#inclusive ⇒ Boolean
(also: #inclusive?)
Whether this version is specifying part of an inclusive range.
-
#kind ⇒ String
Required.
-
#name ⇒ String
Required only when version kind is NORMAL.
-
#revision ⇒ String
The iteration of the package build from the above version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
7531 7532 7533 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
Corresponds to the JSON property epoch
7503 7504 7505 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7503 def epoch @epoch end |
#inclusive ⇒ Boolean Also known as: inclusive?
Whether this version is specifying part of an inclusive range. Grafeas does
not have the capability to specify version ranges; instead we have fields that
specify start version and end versions. At times this is insufficient - we
also need to specify whether the version is included in the range or is
excluded from the range. This boolean is expected to be set to true when the
version is included in a range.
Corresponds to the JSON property inclusive
7513 7514 7515 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7513 def inclusive @inclusive end |
#kind ⇒ String
Required. Distinguishes between sentinel MIN/MAX versions and normal versions.
Corresponds to the JSON property kind
7519 7520 7521 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7519 def kind @kind end |
#name ⇒ String
Required only when version kind is NORMAL. The main part of the version name.
Corresponds to the JSON property name
7524 7525 7526 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7524 def name @name end |
#revision ⇒ String
The iteration of the package build from the above version.
Corresponds to the JSON property revision
7529 7530 7531 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7529 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7536 def update!(**args) @epoch = args[:epoch] if args.key?(:epoch) @inclusive = args[:inclusive] if args.key?(:inclusive) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @revision = args[:revision] if args.key?(:revision) end |