Class: Google::Apis::ContaineranalysisV1beta1::Version
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Version
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Version contains structured information about the version of a package.
Instance Attribute Summary collapse
-
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
-
#inclusive ⇒ Boolean
(also: #inclusive?)
Whether this version is specifying part of an inclusive range.
-
#kind ⇒ String
Required.
-
#name ⇒ String
Required only when version kind is NORMAL.
-
#revision ⇒ String
The iteration of the package build from the above version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
7485 7486 7487 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#epoch ⇒ Fixnum
Used to correct mistakes in the version numbering scheme.
Corresponds to the JSON property epoch
7457 7458 7459 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7457 def epoch @epoch end |
#inclusive ⇒ Boolean Also known as: inclusive?
Whether this version is specifying part of an inclusive range. Grafeas does
not have the capability to specify version ranges; instead we have fields that
specify start version and end versions. At times this is insufficient - we
also need to specify whether the version is included in the range or is
excluded from the range. This boolean is expected to be set to true when the
version is included in a range.
Corresponds to the JSON property inclusive
7467 7468 7469 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7467 def inclusive @inclusive end |
#kind ⇒ String
Required. Distinguishes between sentinel MIN/MAX versions and normal versions.
Corresponds to the JSON property kind
7473 7474 7475 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7473 def kind @kind end |
#name ⇒ String
Required only when version kind is NORMAL. The main part of the version name.
Corresponds to the JSON property name
7478 7479 7480 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7478 def name @name end |
#revision ⇒ String
The iteration of the package build from the above version.
Corresponds to the JSON property revision
7483 7484 7485 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7483 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7490 7491 7492 7493 7494 7495 7496 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7490 def update!(**args) @epoch = args[:epoch] if args.key?(:epoch) @inclusive = args[:inclusive] if args.key?(:inclusive) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @revision = args[:revision] if args.key?(:revision) end |