Class: Google::Apis::ContaineranalysisV1beta1::VexAssessment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

VexAssessment provides all publisher provided Vex information that is related to this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VexAssessment

Returns a new instance of VexAssessment.



7597
7598
7599
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs. Corresponds to the JSON property cve

Returns:

  • (String)


7555
7556
7557
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7555

def cve
  @cve
end

#impactsArray<String>

Contains information about the impact of this vulnerability, this will change with time. Corresponds to the JSON property impacts

Returns:

  • (Array<String>)


7561
7562
7563
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7561

def impacts
  @impacts
end

#justificationGoogle::Apis::ContaineranalysisV1beta1::Justification

Justification provides the justification when the state of the assessment if NOT_AFFECTED. Corresponds to the JSON property justification



7567
7568
7569
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7567

def justification
  @justification
end

#note_nameString

The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID]. Corresponds to the JSON property noteName

Returns:

  • (String)


7573
7574
7575
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7573

def note_name
  @note_name
end

Holds a list of references associated with this vulnerability item and assessment. Corresponds to the JSON property relatedUris



7579
7580
7581
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7579

def related_uris
  @related_uris
end

#remediationsArray<Google::Apis::ContaineranalysisV1beta1::Remediation>

Specifies details on how to handle (and presumably, fix) a vulnerability. Corresponds to the JSON property remediations



7584
7585
7586
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7584

def remediations
  @remediations
end

#stateString

Provides the state of this Vulnerability assessment. Corresponds to the JSON property state

Returns:

  • (String)


7589
7590
7591
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7589

def state
  @state
end

#vulnerability_idString

The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc. Corresponds to the JSON property vulnerabilityId

Returns:

  • (String)


7595
7596
7597
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7595

def vulnerability_id
  @vulnerability_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7602

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @impacts = args[:impacts] if args.key?(:impacts)
  @justification = args[:justification] if args.key?(:justification)
  @note_name = args[:note_name] if args.key?(:note_name)
  @related_uris = args[:related_uris] if args.key?(:related_uris)
  @remediations = args[:remediations] if args.key?(:remediations)
  @state = args[:state] if args.key?(:state)
  @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id)
end