Class: Google::Apis::ContaineranalysisV1beta1::VexAssessment
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::VexAssessment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
Instance Attribute Summary collapse
-
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability.
-
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change with time.
-
#justification ⇒ Google::Apis::ContaineranalysisV1beta1::Justification
Justification provides the justification when the state of the assessment if NOT_AFFECTED.
-
#note_name ⇒ String
The VulnerabilityAssessment note from which this VexAssessment was generated.
-
#related_uris ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
Holds a list of references associated with this vulnerability item and assessment.
-
#remediations ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
-
#state ⇒ String
Provides the state of this Vulnerability assessment.
-
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VexAssessment
constructor
A new instance of VexAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VexAssessment
Returns a new instance of VexAssessment.
7191 7192 7193 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cve ⇒ String
Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking
number for the vulnerability. Deprecated: Use vulnerability_id instead to
denote CVEs.
Corresponds to the JSON property cve
7149 7150 7151 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7149 def cve @cve end |
#impacts ⇒ Array<String>
Contains information about the impact of this vulnerability, this will change
with time.
Corresponds to the JSON property impacts
7155 7156 7157 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7155 def impacts @impacts end |
#justification ⇒ Google::Apis::ContaineranalysisV1beta1::Justification
Justification provides the justification when the state of the assessment if
NOT_AFFECTED.
Corresponds to the JSON property justification
7161 7162 7163 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7161 def justification @justification end |
#note_name ⇒ String
The VulnerabilityAssessment note from which this VexAssessment was generated.
This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID].
Corresponds to the JSON property noteName
7167 7168 7169 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7167 def note_name @note_name end |
#related_uris ⇒ Array<Google::Apis::ContaineranalysisV1beta1::RelatedUrl>
Holds a list of references associated with this vulnerability item and
assessment.
Corresponds to the JSON property relatedUris
7173 7174 7175 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7173 def @related_uris end |
#remediations ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Remediation>
Specifies details on how to handle (and presumably, fix) a vulnerability.
Corresponds to the JSON property remediations
7178 7179 7180 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7178 def remediations @remediations end |
#state ⇒ String
Provides the state of this Vulnerability assessment.
Corresponds to the JSON property state
7183 7184 7185 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7183 def state @state end |
#vulnerability_id ⇒ String
The vulnerability identifier for this Assessment. Will hold one of common
identifiers e.g. CVE, GHSA etc.
Corresponds to the JSON property vulnerabilityId
7189 7190 7191 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7189 def vulnerability_id @vulnerability_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7196 def update!(**args) @cve = args[:cve] if args.key?(:cve) @impacts = args[:impacts] if args.key?(:impacts) @justification = args[:justification] if args.key?(:justification) @note_name = args[:note_name] if args.key?(:note_name) @related_uris = args[:related_uris] if args.key?(:related_uris) @remediations = args[:remediations] if args.key?(:remediations) @state = args[:state] if args.key?(:state) @vulnerability_id = args[:vulnerability_id] if args.key?(:vulnerability_id) end |