Class: Google::Apis::ContaineranalysisV1beta1::Vulnerability
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::Vulnerability
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
Vulnerability provides metadata about a security vulnerability in a Note.
Instance Attribute Summary collapse
-
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
-
#cvss_score ⇒ Float
The CVSS score for this vulnerability.
-
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System.
-
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1beta1::CvsSv3
Deprecated.
-
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System.
-
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
-
#cwe ⇒ Array<String>
A list of CWE for this vulnerability.
-
#details ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Detail>
All information about the package to specifically identify this vulnerability.
-
#severity ⇒ String
Note provider assigned impact of the vulnerability.
-
#source_update_time ⇒ String
The time this information was last changed at the source.
-
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1beta1::WindowsDetail>
Windows details get their own format because the information format and model don't match a normal detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Vulnerability
constructor
A new instance of Vulnerability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Vulnerability
Returns a new instance of Vulnerability.
7742 7743 7744 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advisory_publish_time ⇒ String
The time this advisory was published by the source.
Corresponds to the JSON property advisoryPublishTime
7669 7670 7671 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7669 def advisory_publish_time @advisory_publish_time end |
#cvss_score ⇒ Float
The CVSS score for this vulnerability.
Corresponds to the JSON property cvssScore
7674 7675 7676 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7674 def cvss_score @cvss_score end |
#cvss_v2 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2,
v3, and v4. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS
v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS
v3 details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV2
7685 7686 7687 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7685 def cvss_v2 @cvss_v2 end |
#cvss_v3 ⇒ Google::Apis::ContaineranalysisV1beta1::CvsSv3
Deprecated. Common Vulnerability Scoring System version 3. For details, see
https://www.first.org/cvss/specification-document
Corresponds to the JSON property cvssV3
7691 7692 7693 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7691 def cvss_v3 @cvss_v3 end |
#cvss_v4 ⇒ Google::Apis::ContaineranalysisV1beta1::Cvss
Common Vulnerability Scoring System. This message is compatible with CVSS v2,
v3, and v4. For CVSS v2 details, see https://www.first.org/cvss/v2/guide CVSS
v2 calculator: https://nvd.nist.gov/vuln-metrics/cvss/v2-calculator For CVSS
v3 details, see https://www.first.org/cvss/specification-document CVSS v3
calculator: https://nvd.nist.gov/vuln-metrics/cvss/v3-calculator For CVSS v4
details, see https://www.first.org/cvss/v4.0/user-guide CVSS v4 calculator:
https://nvd.nist.gov/vuln-metrics/cvss/v4-calculator
Corresponds to the JSON property cvssV4
7702 7703 7704 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7702 def cvss_v4 @cvss_v4 end |
#cvss_version ⇒ String
CVSS version used to populate cvss_score and severity.
Corresponds to the JSON property cvssVersion
7707 7708 7709 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7707 def cvss_version @cvss_version end |
#cwe ⇒ Array<String>
A list of CWE for this vulnerability. For details, see: https://cwe.mitre.org/
index.html
Corresponds to the JSON property cwe
7713 7714 7715 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7713 def cwe @cwe end |
#details ⇒ Array<Google::Apis::ContaineranalysisV1beta1::Detail>
All information about the package to specifically identify this vulnerability.
One entry per (version range and cpe_uri) the package vulnerability has
manifested in.
Corresponds to the JSON property details
7720 7721 7722 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7720 def details @details end |
#severity ⇒ String
Note provider assigned impact of the vulnerability.
Corresponds to the JSON property severity
7725 7726 7727 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7725 def severity @severity end |
#source_update_time ⇒ String
The time this information was last changed at the source. This is an upstream
timestamp from the underlying information source - e.g. Ubuntu security
tracker.
Corresponds to the JSON property sourceUpdateTime
7732 7733 7734 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7732 def source_update_time @source_update_time end |
#windows_details ⇒ Array<Google::Apis::ContaineranalysisV1beta1::WindowsDetail>
Windows details get their own format because the information format and model
don't match a normal detail. Specifically Windows updates are done as patches,
thus Windows vulnerabilities really are a missing package, rather than a
package being at an incorrect version.
Corresponds to the JSON property windowsDetails
7740 7741 7742 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7740 def windows_details @windows_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7747 def update!(**args) @advisory_publish_time = args[:advisory_publish_time] if args.key?(:advisory_publish_time) @cvss_score = args[:cvss_score] if args.key?(:cvss_score) @cvss_v2 = args[:cvss_v2] if args.key?(:cvss_v2) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @cvss_v4 = args[:cvss_v4] if args.key?(:cvss_v4) @cvss_version = args[:cvss_version] if args.key?(:cvss_version) @cwe = args[:cwe] if args.key?(:cwe) @details = args[:details] if args.key?(:details) @severity = args[:severity] if args.key?(:severity) @source_update_time = args[:source_update_time] if args.key?(:source_update_time) @windows_details = args[:windows_details] if args.key?(:windows_details) end |