Class: Google::Apis::ContaineranalysisV1beta1::VulnerabilityAssessmentNote
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::VulnerabilityAssessmentNote
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
A single VulnerabilityAssessmentNote represents one particular product's vulnerability assessment for one CVE.
Instance Attribute Summary collapse
-
#assessment ⇒ Google::Apis::ContaineranalysisV1beta1::Assessment
Assessment provides all information that is related to a single vulnerability for this product.
-
#language_code ⇒ String
Identifies the language used by this document, corresponding to IETF BCP 47 / RFC 5646.
-
#long_description ⇒ String
A detailed description of this Vex.
-
#product ⇒ Google::Apis::ContaineranalysisV1beta1::Product
Product contains information about a product and how to uniquely identify it.
-
#publisher ⇒ Google::Apis::ContaineranalysisV1beta1::Publisher
Publisher contains information about the publisher of this Note.
-
#short_description ⇒ String
A one sentence description of this Vex.
-
#title ⇒ String
The title of the note.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityAssessmentNote
constructor
A new instance of VulnerabilityAssessmentNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityAssessmentNote
Returns a new instance of VulnerabilityAssessmentNote.
7774 7775 7776 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assessment ⇒ Google::Apis::ContaineranalysisV1beta1::Assessment
Assessment provides all information that is related to a single vulnerability
for this product.
Corresponds to the JSON property assessment
7741 7742 7743 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7741 def assessment @assessment end |
#language_code ⇒ String
Identifies the language used by this document, corresponding to IETF BCP 47 /
RFC 5646.
Corresponds to the JSON property languageCode
7747 7748 7749 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7747 def language_code @language_code end |
#long_description ⇒ String
A detailed description of this Vex.
Corresponds to the JSON property longDescription
7752 7753 7754 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7752 def long_description @long_description end |
#product ⇒ Google::Apis::ContaineranalysisV1beta1::Product
Product contains information about a product and how to uniquely identify it.
Corresponds to the JSON property product
7757 7758 7759 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7757 def product @product end |
#publisher ⇒ Google::Apis::ContaineranalysisV1beta1::Publisher
Publisher contains information about the publisher of this Note.
Corresponds to the JSON property publisher
7762 7763 7764 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7762 def publisher @publisher end |
#short_description ⇒ String
A one sentence description of this Vex.
Corresponds to the JSON property shortDescription
7767 7768 7769 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7767 def short_description @short_description end |
#title ⇒ String
The title of the note. E.g. Vex-Debian-11.4
Corresponds to the JSON property title
7772 7773 7774 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7772 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7779 7780 7781 7782 7783 7784 7785 7786 7787 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7779 def update!(**args) @assessment = args[:assessment] if args.key?(:assessment) @language_code = args[:language_code] if args.key?(:language_code) @long_description = args[:long_description] if args.key?(:long_description) @product = args[:product] if args.key?(:product) @publisher = args[:publisher] if args.key?(:publisher) @short_description = args[:short_description] if args.key?(:short_description) @title = args[:title] if args.key?(:title) end |