Class: Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
- Inherits:
-
Object
- Object
- Google::Apis::ContaineranalysisV1beta1::VulnerabilityLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb
Overview
The location of the vulnerability.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
Required.
-
#package ⇒ String
Required.
-
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityLocation
constructor
A new instance of VulnerabilityLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityLocation
Returns a new instance of VulnerabilityLocation.
7810 7811 7812 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
Required. The CPE URI in cpe format
format. Examples include distro or storage location for vulnerable jar.
Corresponds to the JSON property cpeUri
7798 7799 7800 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7798 def cpe_uri @cpe_uri end |
#package ⇒ String
Required. The package being described.
Corresponds to the JSON property package
7803 7804 7805 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7803 def package @package end |
#version ⇒ Google::Apis::ContaineranalysisV1beta1::Version
Version contains structured information about the version of a package.
Corresponds to the JSON property version
7808 7809 7810 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7808 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7815 7816 7817 7818 7819 |
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7815 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @package = args[:package] if args.key?(:package) @version = args[:version] if args.key?(:version) end |