Class: Google::Apis::ContaineranalysisV1beta1::VulnerabilityOccurrencesSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/containeranalysis_v1beta1/classes.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb,
lib/google/apis/containeranalysis_v1beta1/representations.rb

Overview

A summary of how many vulnerability occurrences there are per resource and severity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityOccurrencesSummary

Returns a new instance of VulnerabilityOccurrencesSummary.



7425
7426
7427
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countsArray<Google::Apis::ContaineranalysisV1beta1::FixableTotalByDigest>

A listing by resource of the number of fixable and total vulnerabilities. Corresponds to the JSON property counts



7416
7417
7418
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7416

def counts
  @counts
end

#unreachableArray<String>

Unordered list. Unreachable regions. Populated for requests from the global region when return_partial_success is set. Format: projects/[PROJECT_ID]/ locations/[LOCATION] Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


7423
7424
7425
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7423

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7430
7431
7432
7433
# File 'lib/google/apis/containeranalysis_v1beta1/classes.rb', line 7430

def update!(**args)
  @counts = args[:counts] if args.key?(:counts)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end